@@ -1,6 +1,5 @@
-from ..modeler.Circuit import ModelerEmit
-from ..modules.PostProcessor import PostProcessor
-from .Design import Design
+from pyaedt.modeler.Circuit import ModelerEmit
+from pyaedt.application.Design import Design
 
 
 class FieldAnalysisEmit(Design):
@@ -13,24 +12,6 @@ class FieldAnalysisEmit(Design):
 
     """
 
-    @property
-    def solution_type(self):
-        """Solution type.
-
-        Parameters
-        ----------
-        soltype :
-            SolutionType object.
-        """
-        return self._solution_type
-
-    @solution_type.setter
-    def solution_type(self, soltype):
-        if soltype:
-            self._solution_type = "EMIT"
-        else:
-            self._solution_type = "EMIT"
-
     @property
     def existing_analysis_setups(self):
         """Existing analysis setups."""
@@ -54,7 +35,6 @@ class FieldAnalysisEmit(Design):
         close_on_exit=True,
         student_version=False,
     ):
-        self.solution_type = solution_type
         Design.__init__(
             self,
             application,
@@ -67,8 +47,9 @@ class FieldAnalysisEmit(Design):
             close_on_exit,
             student_version,
         )
+        self.solution_type = solution_type
+        self.oanalysis = None
         self._modeler = ModelerEmit(self)
-        self._post = PostProcessor(self)
 
     @property
     def modeler(self):
@@ -80,14 +61,3 @@ class FieldAnalysisEmit(Design):
             Design oModeler
         """
         return self._modeler
-
-    @property
-    def oanalysis(self):
-        """Analysis object.
-
-        Returns
-        -------
-        int
-           Design module ``"SimSetup"``
-        """
-        return None
