@@ -2,10 +2,15 @@ import ntpath
 import os
 import warnings
 
-from ..generic.general_methods import aedt_exception_handler, retry_ntimes
-from ..modeler.Model3D import Modeler3D
-from ..modules.Mesh import Mesh
-from .Analysis import Analysis
+from pyaedt.generic.general_methods import aedt_exception_handler, _retry_ntimes, is_ironpython
+from pyaedt.modeler.Model3D import Modeler3D
+from pyaedt.modules.Mesh import Mesh
+from pyaedt.application.Analysis import Analysis
+
+if is_ironpython:
+    from pyaedt.modules.PostProcessor import PostProcessor
+else:
+    from pyaedt.modules.AdvancedPostProcessing import PostProcessor
 
 
 class FieldAnalysis3D(Analysis, object):
@@ -37,7 +42,7 @@ class FieldAnalysis3D(Analysis, object):
     specified_version : str, optional
         Version of AEDT  to use. The default is ``None``, in which case
         the active version or latest installed version is used.
-    NG : bool, optional
+    non_graphical : bool, optional
         Whether to run AEDT in the non-graphical mode. The default
         is ``False``, in which case AEDT is launched in the graphical mode.
     new_desktop_session : bool, optional
@@ -78,8 +83,33 @@ class FieldAnalysis3D(Analysis, object):
             close_on_exit,
             student_version,
         )
+        self._osolution = self._odesign.GetModule("Solutions")
+        self._oboundary = self._odesign.GetModule("BoundarySetup")
         self._modeler = Modeler3D(self)
         self._mesh = Mesh(self)
+        self._post = PostProcessor(self)
+
+    @property
+    def osolution(self):
+        """Solution Module.
+
+        References
+        ----------
+
+        >>> oModule = oDesign.GetModule("Solutions")
+        """
+        return self._osolution
+
+    @property
+    def oboundary(self):
+        """Boundary Module.
+
+        References
+        ----------
+
+        >>> oModule = oDesign.GetModule("BoundarySetup")
+        """
+        return self._oboundary
 
     @property
     def modeler(self):
@@ -136,6 +166,86 @@ class FieldAnalysis3D(Analysis, object):
                 components_dict[tail[:-8]] = el
         return components_dict
 
+    @aedt_exception_handler
+    def plot(
+        self,
+        objects=None,
+        show=True,
+        export_path=None,
+        plot_as_separate_objects=True,
+        plot_air_objects=True,
+        force_opacity_value=None,
+        clean_files=False,
+    ):
+        """Plot the model or a substet of objects.
+
+        Parameters
+        ----------
+        objects : list, optional
+            Optional list of objects to plot. If `None` all objects will be exported.
+        show : bool, optional
+            Show the plot after generation or simply return the
+            generated Class for more customization before plot.
+        export_path : str, optional
+            If available, an image is saved to file. If `None` no image will be saved.
+        plot_as_separate_objects : bool, optional
+            Plot each object separately. It may require more time to export from AEDT.
+        plot_air_objects : bool, optional
+            Plot also air and vacuum objects.
+        force_opacity_value : float, optional
+            Opacity value between 0 and 1 to be applied to all model.
+            If `None` aedt opacity will be applied to each object.
+        clean_files : bool, optional
+            Clean created files after plot. Cache is mainteined into the model object returned.
+
+        Returns
+        -------
+        :class:`pyaedt.modules.AdvancedPostProcessing.ModelPlotter`
+            Model Object.
+        """
+        if is_ironpython:
+            self.logger.warning("Plot is available only on CPython")
+        elif self._aedt_version < "2021.2":
+            self.logger.warning("Plot is supported from AEDT 2021 R2.")
+        else:
+            return self.post.plot_model_obj(
+                objects=objects,
+                show=show,
+                export_path=export_path,
+                plot_as_separate_objects=plot_as_separate_objects,
+                plot_air_objects=plot_air_objects,
+                force_opacity_value=force_opacity_value,
+                clean_files=clean_files,
+            )
+
+    @aedt_exception_handler
+    def export_mesh_stats(self, setup_name, variation_string="", mesh_path=None):
+        """Export mesh statistics to a file.
+
+        Parameters
+        ----------
+        setup_name :str
+            Setup name.
+        variation_string : str, optional
+            Variation List.
+        mesh_path : str, optional
+            Full path to mesh statistics file. If `None` working_directory will be used.
+
+        Returns
+        -------
+        str
+            File Path.
+
+        References
+        ----------
+
+        >>> oDesign.ExportMeshStats
+        """
+        if not mesh_path:
+            mesh_path = os.path.join(self.working_directory, "meshstats.ms")
+        self.odesign.ExportMeshStats(setup_name, variation_string, mesh_path)
+        return mesh_path
+
     @aedt_exception_handler
     def get_components3d_vars(self, component3dname):
         """Read the A3DCOMP file and check for variables.
@@ -202,6 +312,10 @@ class FieldAnalysis3D(Analysis, object):
         type
             Value of the property.
 
+        References
+        ----------
+
+        >>> oDesign.GetPropertyValue
         """
 
         boundary = {"HFSS": "HfssTab", "Icepak": "Icepak", "Q3D": "Q3D", "Maxwell3D": "Maxwell3D"}
@@ -216,28 +330,28 @@ class FieldAnalysis3D(Analysis, object):
         }
         if type == "Boundary":
             propserv = boundary[self._design_type]
-            val = retry_ntimes(10, self.odesign.GetPropertyValue, propserv, objectname, property)
+            val = _retry_ntimes(10, self.odesign.GetPropertyValue, propserv, objectname, property)
             return val
         elif type == "Setup":
             propserv = setup[self._design_type]
-            val = retry_ntimes(10, self.odesign.GetPropertyValue, propserv, objectname, property)
+            val = _retry_ntimes(10, self.odesign.GetPropertyValue, propserv, objectname, property)
             return val
 
         elif type == "Excitation":
             propserv = excitation[self._design_type]
-            val = retry_ntimes(10, self.odesign.GetPropertyValue, propserv, objectname, property)
+            val = _retry_ntimes(10, self.odesign.GetPropertyValue, propserv, objectname, property)
             return val
 
         elif type == "Mesh":
             propserv = mesh[self._design_type]
-            val = retry_ntimes(10, self.odesign.GetPropertyValue, propserv, objectname, property)
+            val = _retry_ntimes(10, self.odesign.GetPropertyValue, propserv, objectname, property)
             return val
         else:
             propservs = all[self._design_type]
             for propserv in propservs:
                 properties = list(self.odesign.GetProperties(propserv, objectname))
                 if property in properties:
-                    val = retry_ntimes(10, self.odesign.GetPropertyValue, propserv, objectname, property)
+                    val = _retry_ntimes(10, self.odesign.GetPropertyValue, propserv, objectname, property)
                     return val
         return None
 
@@ -267,28 +381,131 @@ class FieldAnalysis3D(Analysis, object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.Copy
+        >>> oEditor.Paste
         """
         body_list = design.modeler.primitives.solid_names
         if include_sheets:
             body_list += design.modeler.primitives.sheet_names
         selection_list = []
         material_properties = design.modeler.primitives.objects
-        for body in body_list:
-            include_object = True
-            if object_list:
-                if body not in object_list:
-                    include_object = False
-            for key, val in material_properties.items():
-                if val.name == body:
-                    if no_vacuum and val.material_name == "Vacuum":
-                        include_object = False
-                    if no_pec and val.material_name == "pec":
-                        include_object = False
-            if include_object:
-                selection_list.append(body)
+        if object_list:
+            selection_list = [i for i in object_list if i in body_list]
+        else:
+            for body in body_list:
+                include_object = True
+                for key, val in material_properties.items():
+                    if val.name == body:
+                        if no_vacuum and val.material_name.lower() == "vacuum":
+                            include_object = False
+                        if no_pec and val.material_name == "pec":
+                            include_object = False
+                if include_object:
+                    selection_list.append(body)
         design.modeler.oeditor.Copy(["NAME:Selections", "Selections:=", ",".join(selection_list)])
         self.modeler.oeditor.Paste()
+        self.modeler.primitives.refresh_all_ids()
+        return True
 
+    @aedt_exception_handler
+    def export3DModel(self, fileName, filePath, fileFormat=".step", object_list=[], removed_objects=[]):
+        """Export the 3D model.
+
+        .. deprecated:: 0.5.0
+           Use :func:`pyaedt.application.Analysis3D.modeler.export_3d_model` instead.
+
+        Parameters
+        ----------
+        fileName : str
+            Name of the file.
+        filePath : str
+            Path for the file.
+        fileFormat : str, optional
+             Format of the file. The default is ``".step"``.
+        object_list : list, optional
+             List of objects to export. The default is ``[]``.
+        removed_objects : list, optional
+             The default is ``[]``.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oEditor.Export
+        """
+        warnings.warn("`export3DModel` is deprecated. Use `export_3d_model` instead.", DeprecationWarning)
+        return self.export_3d_model(fileName, filePath, fileFormat, object_list, removed_objects)
+
+    @aedt_exception_handler
+    def export_3d_model(self, fileName, filePath, fileFormat=".step", object_list=[], removed_objects=[]):
+        """Export the 3D model.
+
+        Parameters
+        ----------
+        fileName : str
+            Name of the file.
+        filePath : str
+            Path for the file.
+        fileFormat : str, optional
+             Format of the file. The default is ``".step"``.
+        object_list : list, optional
+             List of objects to export. The default is ``[]``.
+        removed_objects : list, optional
+             The default is ``[]``.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oEditor.Export
+        """
+        if not object_list:
+            allObjects = self.modeler.primitives.object_names
+            if removed_objects:
+                for rem in removed_objects:
+                    allObjects.remove(rem)
+            else:
+                if "Region" in allObjects:
+                    allObjects.remove("Region")
+        else:
+            allObjects = object_list[:]
+
+        self.logger.info("Exporting {} objects".format(len(allObjects)))
+        major = -1
+        minor = -1
+        # actual version supported by AEDT is 29.0
+        if fileFormat in [".step", ".stp", ".sm3", ".sat", ".sab"]:
+            major = 29
+            minor = 0
+        stringa = ",".join(allObjects)
+        arg = [
+            "NAME:ExportParameters",
+            "AllowRegionDependentPartSelectionForPMLCreation:=",
+            True,
+            "AllowRegionSelectionForPMLCreation:=",
+            True,
+            "Selections:=",
+            stringa,
+            "File Name:=",
+            os.path.join(filePath, fileName + fileFormat),
+            "Major Version:=",
+            major,
+            "Minor Version:=",
+            minor,
+        ]
+
+        self.modeler.oeditor.Export(arg)
         return True
 
     @aedt_exception_handler
@@ -297,8 +514,13 @@ class FieldAnalysis3D(Analysis, object):
 
         Returns
         -------
-        list
+        list of str
             List of setup sources.
+
+        References
+        ----------
+
+        >>> oModule.GetAllSources
         """
         return list(self.osolution.GetAllSources())
 
@@ -318,6 +540,10 @@ class FieldAnalysis3D(Analysis, object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.SetSourceContexts
         """
 
         contexts = []
@@ -326,17 +552,6 @@ class FieldAnalysis3D(Analysis, object):
         self.osolution.SetSourceContexts(contexts)
         return True
 
-    @aedt_exception_handler
-    def assignmaterial(self, obj, mat):
-        """Assign a material to one or more objects.
-
-        .. deprecated:: 0.3.1
-           Use :func:`FieldAnalysis3D.assign_material` instead.
-
-        """
-        warnings.warn("assignmaterial is deprecated. Use assign_material instead.", DeprecationWarning)
-        self.assign_material(obj, mat)
-
     @aedt_exception_handler
     def assign_material(self, obj, mat):
         """Assign a material to one or more objects.
@@ -354,6 +569,11 @@ class FieldAnalysis3D(Analysis, object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.AssignMaterial
+
         Examples
         --------
         The method :func:`assign_material` is used to assign a material to a list of objects.
@@ -378,44 +598,26 @@ class FieldAnalysis3D(Analysis, object):
         >>> hfss.assign_material(obj_names_list, "aluminum")
         """
         mat = mat.lower()
-        selections = self.modeler.convert_to_selections(obj)
-        arg1 = ["NAME:Selections"]
-        arg1.append("Selections:="), arg1.append(selections)
-        arg2 = ["NAME:Attributes"]
-        arg2.append("MaterialValue:="), arg2.append(chr(34) + mat + chr(34))
-        if mat in self.materials.material_keys:
-            Mat = self.materials.material_keys[mat]
-            Mat.update()
-            if Mat.is_dielectric():
-                arg2.append("SolveInside:="), arg2.append(True)
-            else:
-                arg2.append("SolveInside:="), arg2.append(False)
-            self.modeler.oeditor.AssignMaterial(arg1, arg2)
-            self._messenger.add_info_message("Assign Material " + mat + " to object " + selections)
-            if type(obj) is list:
-                for el in obj:
-                    self.modeler.primitives[el].material_name = mat
-            else:
-                self.modeler.primitives[obj].material_name = mat
-            return True
-        elif self.materials.checkifmaterialexists(mat):
-            self.materials._aedmattolibrary(mat)
-            Mat = self.materials.material_keys[mat]
-            if Mat.is_dielectric():
-                arg2.append("SolveInside:="), arg2.append(True)
-            else:
-                arg2.append("SolveInside:="), arg2.append(False)
-            self.modeler.oeditor.AssignMaterial(arg1, arg2)
-            self._messenger.add_info_message("Assign Material " + mat + " to object " + selections)
-            if type(obj) is list:
-                for el in obj:
-                    self.modeler.primitives[el].material_name = mat
-            else:
-                self.modeler.primitives[obj].material_name = mat
+        selections = self.modeler.convert_to_selections(obj, True)
 
+        mat_exists = False
+        if mat in self.materials.material_keys:
+            mat_exists = True
+        if mat_exists or self.materials.checkifmaterialexists(mat):
+            Mat = self.materials.material_keys[mat]
+            if mat_exists:
+                Mat.update()
+            self.logger.info("Assign Material " + mat + " to object " + str(selections))
+            for el in selections:
+                self.modeler.primitives[el].material_name = mat
+                self.modeler.primitives[el].color = self.materials.material_keys[mat].material_appearance
+                if Mat.is_dielectric():
+                    self.modeler.primitives[el].solve_inside = True
+                else:
+                    self.modeler.primitives[el].solve_inside = False
             return True
         else:
-            self._messenger.add_error_message("Material Does Not Exists")
+            self.logger.error("Material does not exist.")
             return False
 
     @aedt_exception_handler
@@ -424,17 +626,19 @@ class FieldAnalysis3D(Analysis, object):
 
         Returns
         -------
-        list
+        list of str
             List of all conductors.
 
+        References
+        ----------
+
+        >>> oEditor.GetObjectsByMaterial
         """
         cond = self.materials.conductors
         cond = [i.lower() for i in cond]
         obj_names = []
-        for el, obj in self.modeler.primitives.objects.items():
-            if obj.object_type == "Solid":
-                if obj.material_name.lower() in cond:
-                    obj_names.append(obj.name)
+        for el in cond:
+            obj_names += list(self._modeler.oeditor.GetObjectsByMaterial(el))
         return obj_names
 
     @aedt_exception_handler
@@ -443,16 +647,17 @@ class FieldAnalysis3D(Analysis, object):
 
         Returns
         -------
-        List
+        list of str
            List of all dielectrics.
 
+        References
+        ----------
+
+        >>> oEditor.GetObjectsByMaterial
         """
         diel = self.materials.dielectrics
         diel = [i.lower() for i in diel]
         obj_names = []
-        for name in self.modeler.primitives.solid_names:
-            id = self.modeler.primitives.object_id_dict[name]
-            obj = self.modeler.primitives.objects[id]
-            if obj.material_name.lower() in diel:
-                obj_names.append(obj.name)
+        for el in diel:
+            obj_names += list(self._modeler.oeditor.GetObjectsByMaterial(el))
         return obj_names
