@@ -1,9 +1,15 @@
-from ..generic.general_methods import aedt_exception_handler
-from ..modeler.Model3DLayout import Modeler3DLayout
-from ..modules.Mesh3DLayout import Mesh
-from ..modules.SetupTemplates import SetupKeys
-from ..modules.SolveSetup import Setup3DLayout
-from .Analysis import Analysis
+import os
+
+from pyaedt.generic.general_methods import aedt_exception_handler, is_ironpython
+from pyaedt.modeler.Model3DLayout import Modeler3DLayout
+from pyaedt.modules.Mesh3DLayout import Mesh3d
+from pyaedt.modules.SolveSetup import Setup3DLayout
+from pyaedt.application.Analysis import Analysis
+
+if is_ironpython:
+    from pyaedt.modules.PostProcessor import PostProcessor
+else:
+    from pyaedt.modules.AdvancedPostProcessing import PostProcessor
 
 
 class FieldAnalysis3DLayout(Analysis):
@@ -63,7 +69,6 @@ class FieldAnalysis3DLayout(Analysis):
         close_on_exit=False,
         student_version=False,
     ):
-
         Analysis.__init__(
             self,
             application,
@@ -77,24 +82,49 @@ class FieldAnalysis3DLayout(Analysis):
             close_on_exit,
             student_version,
         )
-        self._messenger.add_info_message("Analysis Loaded")
+        self._osolution = self._odesign.GetModule("SolveSetups")
+        self._oexcitation = self._odesign.GetModule("Excitations")
+        self._oboundary = self._odesign.GetModule("Excitations")
+        self.logger.info("Analysis Loaded")
         self._modeler = Modeler3DLayout(self)
         self._modeler.primitives.init_padstacks()
-        self._messenger.add_info_message("Modeler Loaded")
-        self._mesh = Mesh(self)
+        self.logger.info("Modeler Loaded")
+        self._mesh = Mesh3d(self)
+        self._post = PostProcessor(self)
         # self._post = PostProcessor(self)
 
     @property
-    def oboundary(self):
-        """Boundary.
+    def osolution(self):
+        """Solution Module.
 
-        Returns
-        -------
-        AEDT object
-            Boundaries module object.
+        References
+        ----------
 
+        >>> oModule = oDesign.GetModule("SolveSetups")
         """
-        return self._odesign.GetModule("Excitations")
+        return self._osolution
+
+    @property
+    def oexcitation(self):
+        """Solution Module.
+
+        References
+        ----------
+
+        >>> oModule = oDesign.GetModule("Excitations")
+        """
+        return self._oexcitation
+
+    @property
+    def oboundary(self):
+        """Boundary Module.
+
+        References
+        ----------
+
+        >>> oModule = oDesign.GetModule("Excitations")
+        """
+        return self._oboundary
 
     @property
     def mesh(self):
@@ -102,7 +132,7 @@ class FieldAnalysis3DLayout(Analysis):
 
         Returns
         -------
-        :class:`pyaedt.modules.Mesh3DLayout.Mesh`
+        :class:`pyaedt.modules.Mesh3DLayout.Mesh3d`
         """
         return self._mesh
 
@@ -115,6 +145,10 @@ class FieldAnalysis3DLayout(Analysis):
         list
             list of all excitation
 
+        References
+        ----------
+
+        >>> oModule.GetAllPortsList
         """
         return list(self.oboundary.GetAllPortsList())
 
@@ -147,6 +181,34 @@ class FieldAnalysis3DLayout(Analysis):
                 k += 1
         return spar
 
+    @aedt_exception_handler
+    def export_mesh_stats(self, setup_name, variation_string="", mesh_path=None):
+        """Export mesh statistics to a file.
+
+        Parameters
+        ----------
+        setup_name :str
+            Setup name.
+        variation_string : str, optional
+            Variation List.
+        mesh_path : str, optional
+            Full path to mesh statistics file. If `None` working_directory will be used.
+
+        Returns
+        -------
+        str
+            File Path.
+
+        References
+        ----------
+
+        >>> oModule.ExportMeshStats
+        """
+        if not mesh_path:
+            mesh_path = os.path.join(self.working_directory, "meshstats.ms")
+        self.odesign.ExportMeshStats(setup_name, variation_string, mesh_path)
+        return mesh_path
+
     @aedt_exception_handler
     def get_all_return_loss_list(self, excitation_names=[], excitation_name_prefix=""):
         """Retrieve a list of all return losses for a list of excitations.
@@ -166,6 +228,10 @@ class FieldAnalysis3DLayout(Analysis):
             List of strings representing the return losses of the excitations.
             For example, ``["S(1, 1)", "S(2, 2)"]``.
 
+        References
+        ----------
+
+        >>> oModule.GetAllPorts
         """
         if not excitation_names:
             excitation_names = self.get_excitations_name
@@ -198,6 +264,10 @@ class FieldAnalysis3DLayout(Analysis):
             List of strings representing insertion losses of the excitations.
             For example, ``["S(1, 2)"]``.
 
+        References
+        ----------
+
+        >>> oModule.GetAllPorts
         """
         spar = []
         if not trlist:
@@ -205,7 +275,7 @@ class FieldAnalysis3DLayout(Analysis):
         if not reclist:
             reclist = [i for i in self.get_excitations_name if rx_prefix in i]
         if len(trlist) != len(reclist):
-            self._messenger.add_error_message("TX and RX should be same length lists")
+            self.logger.error("The TX and RX lists should be same length.")
             return False
         for i, j in zip(trlist, reclist):
             spar.append("S({},{})".format(i, j))
@@ -228,6 +298,10 @@ class FieldAnalysis3DLayout(Analysis):
             List of strings representing near end XTalks of the excitations.
             For example, ``["S(1, 2)", "S(1, 3)", "S(2, 3)"]``.
 
+        References
+        ----------
+
+        >>> oModule.GetAllPorts
         """
         next = []
         if not trlist:
@@ -265,6 +339,10 @@ class FieldAnalysis3DLayout(Analysis):
             List of strings representing the far end XTalks of the excitations.
             For example, ``["S(1, 4)", "S(2, 3)"]``.
 
+        References
+        ----------
+
+        >>> oModule.GetAllPorts
         """
         fext = []
         if not trlist:
@@ -282,33 +360,15 @@ class FieldAnalysis3DLayout(Analysis):
         """Modeler object."""
         return self._modeler
 
-    # @property
-    # def mesh(self):
-    #     return self._mesh
-    #
-    # @property
-    # def post(self):
-    #     return self._post
-
-    @property
-    def osolution(self):
-        """Solution object."""
-        return self.odesign.GetModule("SolveSetups")
-
-    @property
-    def oexcitation(self):
-        """Excitation object."""
-        return self.odesign.GetModule("Excitations")
-
     @property
     def port_list(self):
-        """Port list."""
-        return self.oexcitation.GetAllPortsList()
+        """Port list.
 
-    @property
-    def oanalysis(self):
-        """Analysis."""
-        return self.odesign.GetModule("SolveSetups")
+        References
+        ----------
+
+        >>> oModule.GetAllPorts"""
+        return self.oexcitation.GetAllPortsList()
 
     @property
     def existing_analysis_setups(self):
@@ -319,9 +379,12 @@ class FieldAnalysis3DLayout(Analysis):
         list
             List of names of all analysis setups in the design.
 
+        References
+        ----------
+
+        >>> oModule.GetSetups
         """
-        oModule = self.odesign.GetModule("SolveSetups")
-        setups = list(oModule.GetSetups())
+        setups = list(self.oanalysis.GetSetups())
         return setups
 
     @aedt_exception_handler
@@ -342,9 +405,13 @@ class FieldAnalysis3DLayout(Analysis):
         -------
         :class:`pyaedt.modules.SolveSetup.Setup3DLayout`
 
+        References
+        ----------
+
+        >>> oModule.Add
         """
         if setuptype is None:
-            setuptype = SetupKeys.defaultSetups[self.solution_type]
+            setuptype = self.design_solutions.default_setup
         name = self.generate_unique_setup_name(setupname)
         setup = Setup3DLayout(self, setuptype, name)
         setup.create()
@@ -364,7 +431,7 @@ class FieldAnalysis3DLayout(Analysis):
         ----------
         setupname : str
             Name of the setup.
-        setuptype : SetupTypes, optional
+        setuptype : SETUPS, optional
             Type of the setup. The default is ``None``, in which case
             the default type is applied.
 
@@ -375,7 +442,7 @@ class FieldAnalysis3DLayout(Analysis):
 
         """
         if setuptype is None:
-            setuptype = SetupKeys.defaultSetups[self.solution_type]
+            setuptype = self.design_solutions.default_setup
         for setup in self.setups:
             if setupname == setup.name:
                 return setup
@@ -397,6 +464,11 @@ class FieldAnalysis3DLayout(Analysis):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.Delete
+
         Examples
         --------
         Create a setup and then delete it.
@@ -406,7 +478,7 @@ class FieldAnalysis3DLayout(Analysis):
         >>> setup1 = hfss3dlayout.create_setup(setupname='Setup1')
         >>> hfss3dlayout.delete_setup(setupname='Setup1')
         ...
-        pyaedt Info: Sweep was deleted correctly.
+        pyaedt info: Sweep was deleted correctly.
         """
         if setupname in self.existing_analysis_setups:
             self.osolution.Delete(setupname)
