@@ -1,11 +1,16 @@
 import csv
 import re
-import warnings
+import os
 
-from ..generic.general_methods import aedt_exception_handler, generate_unique_name
-from ..application.Analysis import Analysis
-from ..modeler.Model3D import Modeler3D
-from ..modules.MeshIcepak import IcepakMesh
+from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name, is_ironpython
+from pyaedt.application.Analysis import Analysis
+from pyaedt.modeler.Model3D import Modeler3D
+from pyaedt.modules.MeshIcepak import IcepakMesh
+
+if is_ironpython:
+    from pyaedt.modules.PostProcessor import PostProcessor
+else:
+    from pyaedt.modules.AdvancedPostProcessing import PostProcessor
 
 
 class FieldAnalysisIcepak(Analysis, object):
@@ -79,8 +84,33 @@ class FieldAnalysisIcepak(Analysis, object):
             close_on_exit,
             student_version,
         )
+        self._osolution = self._odesign.GetModule("Solutions")
+        self._oboundary = self._odesign.GetModule("BoundarySetup")
         self._modeler = Modeler3D(self)
         self._mesh = IcepakMesh(self)
+        self._post = PostProcessor(self)
+
+    @property
+    def osolution(self):
+        """Solution Module.
+
+        References
+        ----------
+
+        >>> oModule = oDesign.GetModule("Solutions")
+        """
+        return self._osolution
+
+    @property
+    def oboundary(self):
+        """Boundary Module.
+
+        References
+        ----------
+
+        >>> oModule = oDesign.GetModule("BoundarySetup")
+        """
+        return self._oboundary
 
     @property
     def modeler(self):
@@ -98,13 +128,61 @@ class FieldAnalysisIcepak(Analysis, object):
 
         Returns
         -------
-        :class:`pyaedt.modules.MeshIcepak.IcepakMesh'
+        :class:`pyaedt.modules.MeshIcepak.IcepakMesh`
         """
         return self._mesh
 
-    # @property
-    # def post(self):
-    #     return self._post
+    @aedt_exception_handler
+    def plot(
+        self,
+        objects=None,
+        show=True,
+        export_path=None,
+        plot_as_separate_objects=True,
+        plot_air_objects=True,
+        force_opacity_value=None,
+        clean_files=False,
+    ):
+        """Plot the model or a substet of objects.
+
+        Parameters
+        ----------
+        objects : list, optional
+            Optional list of objects to plot. If `None` all objects will be exported.
+        show : bool, optional
+            Show the plot after generation or simply return the
+            generated Class for more customization before plot.
+        export_path : str, optional
+            If available, an image is saved to file. If `None` no image will be saved.
+        plot_as_separate_objects : bool, optional
+            Plot each object separately. It may require more time to export from AEDT.
+        plot_air_objects : bool, optional
+            Plot also air and vacuum objects.
+        force_opacity_value : float, optional
+            Opacity value between 0 and 1 to be applied to all model.
+            If `None` aedt opacity will be applied to each object.
+        clean_files : bool, optional
+            Clean created files after plot. Cache is mainteined into the model object returned.
+
+        Returns
+        -------
+        :class:`pyaedt.modules.AdvancedPostProcessing.ModelPlotter`
+            Model Object.
+        """
+        if is_ironpython:
+            self.logger.warning("Plot is available only on CPython")
+        elif self._aedt_version < "2021.2":
+            self.logger.warning("Plot is supported from AEDT 2021 R2.")
+        else:
+            return self.post.plot_model_obj(
+                objects=objects,
+                show=show,
+                export_path=export_path,
+                plot_as_separate_objects=plot_as_separate_objects,
+                plot_air_objects=plot_air_objects,
+                force_opacity_value=force_opacity_value,
+                clean_files=clean_files,
+            )
 
     @aedt_exception_handler
     def apply_icepak_settings(
@@ -140,6 +218,10 @@ class FieldAnalysisIcepak(Analysis, object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oDesign.SetDesignSettings
         """
 
         try:
@@ -180,10 +262,76 @@ class FieldAnalysisIcepak(Analysis, object):
         )
         return True
 
+    @aedt_exception_handler
+    def export_3d_model(self, fileName, filePath, fileFormat=".step", object_list=[], removed_objects=[]):
+        """Export the 3D model.
+
+        Parameters
+        ----------
+        fileName : str
+            Name of the file.
+        filePath : str
+            Path for the file.
+        fileFormat : str, optional
+             Format of the file. The default is ``".step"``.
+        object_list : list, optional
+             List of objects to export. The default is ``[]``.
+        removed_objects : list, optional
+             The default is ``[]``.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oEditor.Export
+        """
+        if not object_list:
+            allObjects = self.modeler.primitives.object_names
+            if removed_objects:
+                for rem in removed_objects:
+                    allObjects.remove(rem)
+            else:
+                if "Region" in allObjects:
+                    allObjects.remove("Region")
+        else:
+            allObjects = object_list[:]
+
+        self.logger.info("Exporting {} objects".format(len(allObjects)))
+        major = -1
+        minor = -1
+        # actual version supported by AEDT is 29.0
+        if fileFormat in [".step", ".stp", ".sm3", ".sat", ".sab"]:
+            major = 29
+            minor = 0
+        stringa = ",".join(allObjects)
+        arg = [
+            "NAME:ExportParameters",
+            "AllowRegionDependentPartSelectionForPMLCreation:=",
+            True,
+            "AllowRegionSelectionForPMLCreation:=",
+            True,
+            "Selections:=",
+            stringa,
+            "File Name:=",
+            os.path.join(filePath, fileName + fileFormat),
+            "Major Version:=",
+            major,
+            "Minor Version:=",
+            minor,
+        ]
+
+        self.modeler.oeditor.Export(arg)
+        return True
+
     @aedt_exception_handler
     def get_property_value(self, objectname, property, type=None):
         """Retrieve a design property value for an object.
 
+
         Parameters
         ----------
         objectname : str
@@ -200,6 +348,11 @@ class FieldAnalysisIcepak(Analysis, object):
         type
             Value of the property.
 
+        References
+        ----------
+
+        >>> oDesign.GetPropertyValue
+
         Examples
         --------
 
@@ -265,6 +418,11 @@ class FieldAnalysisIcepak(Analysis, object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.Copy
+        >>> oEditor.Paste
         """
         body_list = design.modeler.solid_bodies
         selection_list = []
@@ -286,18 +444,6 @@ class FieldAnalysisIcepak(Analysis, object):
         self.modeler.oeditor.Paste()
         return True
 
-    @aedt_exception_handler
-    def assignmaterial(self, obj, mat):
-        """Assign a material to one or more objects.
-
-        .. deprecated:: 0.3.1
-           Use :func:`FieldAnalysisIcepak.assign_material` instead.
-
-        """
-        # raise a DeprecationWarning.  User won't have to change anything
-        warnings.warn("assignmaterial is deprecated. Use assign_material instead.", DeprecationWarning)
-        self.assign_material(obj, mat)
-
     @aedt_exception_handler
     def assign_material(self, obj, mat):
         """Assign a material to one or more objects.
@@ -315,41 +461,74 @@ class FieldAnalysisIcepak(Analysis, object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.AssignMaterial
         """
         mat = mat.lower()
-        selections = self.modeler.convert_to_selections(obj)
-        arg1 = ["NAME:Selections"]
-        arg1.append("Selections:="), arg1.append(selections)
-        arg2 = ["NAME:Attributes"]
-        arg2.append("MaterialValue:="), arg2.append(chr(34) + mat + chr(34))
+        selections = self.modeler.convert_to_selections(obj, True)
+
+        mat_exists = False
         if mat in self.materials.material_keys:
+            mat_exists = True
+        if mat_exists or self.materials.checkifmaterialexists(mat):
             Mat = self.materials.material_keys[mat]
-            Mat.update()
-            if Mat.is_dielectric():
-                arg2.append("SolveInside:="), arg2.append(True)
-            else:
-                arg2.append("SolveInside:="), arg2.append(False)
-            self.modeler.oeditor.AssignMaterial(arg1, arg2)
-            self._messenger.add_info_message("Assign Material " + mat + " to object " + selections)
-            self.materials._aedmattolibrary(mat)
-            for el in obj:
-                self.modeler.primitives[el].material_name = mat
-            return True
-        elif self.materials.checkifmaterialexists(mat):
-            Mat = self.materials.material_keys[mat]
-            if Mat.is_dielectric():
-                arg2.append("SolveInside:="), arg2.append(True)
-            else:
-                arg2.append("SolveInside:="), arg2.append(False)
-            self.modeler.oeditor.AssignMaterial(arg1, arg2)
-            self._messenger.add_info_message("Assign Material " + mat + " to object " + selections)
-            for el in obj:
+            if mat_exists:
+                Mat.update()
+            self.logger.info("Assign Material " + mat + " to object " + str(selections))
+            for el in selections:
                 self.modeler.primitives[el].material_name = mat
+                self.modeler.primitives[el].color = self.materials.material_keys[mat].material_appearance
+                if Mat.is_dielectric():
+                    self.modeler.primitives[el].solve_inside = True
+                else:
+                    self.modeler.primitives[el].solve_inside = False
             return True
         else:
-            self._messenger.add_error_message("Material Does Not Exists")
+            self.logger.error("Material does not exist.")
             return False
 
+    @aedt_exception_handler
+    def assign_surface_material(self, obj, mat):
+        """Assign a surface material to one or more objects.
+
+        Parameters
+        ----------
+        obj : str, list
+            One or more objects to assign surface materials to.
+        mat : str
+            Material to assign. The material must be present in the database.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oEditor.ChangeProperty
+        """
+        mat = mat.lower()
+        if mat not in self.materials.surface_material_keys:
+            self.logger.warning("Warning. The material is not the database. Use add_surface_material.")
+            return False
+        else:
+            for el in obj:
+                self.modeler.oeditor.ChangeProperty(
+                    [
+                        "NAME:AllTabs",
+                        [
+                            "NAME:Geometry3DAttributeTab",
+                            ["NAME:PropServers", el],
+                            ["NAME:ChangedProps", ["NAME:Surface Material", "Value:=", '"' + mat + '"']],
+                        ],
+                    ]
+                )
+
+            return True
+
     @aedt_exception_handler
     def _assign_property_to_mat(self, newmat, val, property):
         """Assign a property to a new material.
@@ -425,6 +604,10 @@ class FieldAnalysisIcepak(Analysis, object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.AssignMaterial
         """
         with open(csv_material) as csvfile:
             csv_input = csv.reader(csvfile)
@@ -525,9 +708,8 @@ class FieldAnalysisIcepak(Analysis, object):
 
         Returns
         -------
-        list
+        list of str
             List of conductors.
-
         """
         cond = [i.lower() for i in list(self.materials.conductors)]
         obj_names = []
@@ -542,7 +724,7 @@ class FieldAnalysisIcepak(Analysis, object):
 
         Returns
         -------
-        list
+        list of str
             List of dielectrics.
 
         """
