@@ -1,9 +1,8 @@
-from ..generic.general_methods import aedt_exception_handler
-from ..modeler.Circuit import ModelerNexxim
-from ..modules.PostProcessor import CircuitPostProcessor
-from ..modules.SolveSetup import SetupCircuit
-from .Analysis import Analysis
-from .Design import solutions_settings
+from pyaedt.generic.general_methods import aedt_exception_handler
+from pyaedt.modeler.Circuit import ModelerNexxim
+from pyaedt.modules.PostProcessor import CircuitPostProcessor
+from pyaedt.modules.SolveSetup import SetupCircuit
+from pyaedt.application.Analysis import Analysis
 
 
 class FieldAnalysisCircuit(Analysis):
@@ -33,7 +32,6 @@ class FieldAnalysisCircuit(Analysis):
         close_on_exit=False,
         student_version=False,
     ):
-        self.solution_type = solution_type
         Analysis.__init__(
             self,
             application,
@@ -47,8 +45,9 @@ class FieldAnalysisCircuit(Analysis):
             close_on_exit,
             student_version,
         )
+
         self._modeler = ModelerNexxim(self)
-        self._modeler.primitives.init_padstacks()
+        self._modeler.layout.init_padstacks()
         self._post = CircuitPostProcessor(self)
 
     @property
@@ -62,23 +61,15 @@ class FieldAnalysisCircuit(Analysis):
         """
         return self._post
 
-    @property
-    def solution_type(self):
-        """Solution type."""
-        return self._solution_type
-
-    @solution_type.setter
-    def solution_type(self, soltype):
-        if soltype:
-            self._solution_type = solutions_settings[soltype]
-        else:
-            self._solution_type = "NexximLNA"
-
     @property
     def existing_analysis_setups(self):
-        """Analysis setups."""
-        oModule = self.odesign.GetModule("SimSetup")
-        setups = oModule.GetAllSolutionSetups()
+        """Analysis setups.
+
+        References
+        ----------
+
+        >>> oModule.GetAllSolutionSetups"""
+        setups = self.oanalysis.GetAllSolutionSetups()
         return setups
 
     @property
@@ -94,14 +85,14 @@ class FieldAnalysisCircuit(Analysis):
         """Modeler object."""
         return self._modeler
 
-    @property
-    def oanalysis(self):
-        """Analysis object."""
-        return self.odesign.GetModule("SimSetup")
-
     @property
     def setup_names(self):
-        """Setup names."""
+        """Setup names.
+
+        References
+        ----------
+
+        >>> oModule.GetAllSolutionSetups"""
         return self.oanalysis.GetAllSolutionSetups()
 
     @property
@@ -113,6 +104,10 @@ class FieldAnalysisCircuit(Analysis):
         type
             BoundarySetup Module object
 
+        References
+        ----------
+
+        >>> oEditor.GetAllPorts
         """
         ports = [p.replace("IPort@", "").split(";")[0] for p in self.modeler.oeditor.GetAllPorts()]
         return ports
@@ -123,18 +118,17 @@ class FieldAnalysisCircuit(Analysis):
 
         Parameters
         ----------
-        eexcitation_names : list, optional
+        excitation_names : list, optional
             List of excitations. The default is ``[]``, in which case
             the S parameters for all excitations are to be provided.
             For example, ``["1", "2"]``.
 
         Returns
         -------
-        list
+        list of str
             List of strings representing the S parameters of the excitations.
             For example, ``"S(1,1)", "S(1,2)", "S(2,2)"``.
 
-
         """
         if not excitation_names:
             excitation_names = self.get_excitations_name
@@ -162,10 +156,14 @@ class FieldAnalysisCircuit(Analysis):
 
         Returns
         -------
-        list
+        list of str
             List of strings representing the return losses of the excitations.
             For example ``["S(1, 1)", S(2, 2)]``
 
+        References
+        ----------
+
+        >>> oEditor.GetAllPorts
         """
         if not excitation_names:
             excitation_names = self.get_excitations_name
@@ -194,10 +192,14 @@ class FieldAnalysisCircuit(Analysis):
 
         Returns
         -------
-        list
+        list of str
             List of strings representing insertion losses of the excitations.
             For example, ``["S(1,2)"]``.
 
+        References
+        ----------
+
+        >>> oEditor.GetAllPorts
         """
         spar = []
         if not trlist:
@@ -205,7 +207,7 @@ class FieldAnalysisCircuit(Analysis):
         if not reclist:
             reclist = [i for i in self.get_excitations_name if rx_prefix in i]
         if len(trlist) != len(reclist):
-            self._messenger.add_error_message("TX and RX should be same length lists")
+            self.logger.error("The TX and RX lists should be the same length.")
             return False
         for i, j in zip(trlist, reclist):
             spar.append("S({},{})".format(i, j))
@@ -225,10 +227,14 @@ class FieldAnalysisCircuit(Analysis):
 
         Returns
         -------
-        list
+        list of str
             List of strings representing near end XTalks of the excitations.
             For example, ``["S(1, 2)", "S(1, 3)", "S(2, 3)"]``.
 
+        References
+        ----------
+
+        >>> oEditor.GetAllPorts
         """
         next = []
         if not trlist:
@@ -264,10 +270,14 @@ class FieldAnalysisCircuit(Analysis):
 
         Returns
         -------
-        list
+        list of str
             List of strings representing the far end XTalks of the excitations.
             For example, ``["S(1, 4)", "S(2, 3)"]``.
 
+        References
+        ----------
+
+        >>> oEditor.GetAllPorts
         """
         fext = []
         if not trlist:
@@ -319,6 +329,15 @@ class FieldAnalysisCircuit(Analysis):
         SetupCircuit
             Setup object.
 
+        References
+        ----------
+
+        >>> oModule.AddLinearNetworkAnalysis
+        >>> oModule.AddDCAnalysis
+        >>> oModule.AddTransient
+        >>> oModule.AddQuickEyeAnalysis
+        >>> oModule.AddVerifEyeAnalysis
+        >>> oModule.AddAMIAnalysis
         """
         if setuptype is None:
             setuptype = self.solution_type
