@@ -1,7 +1,7 @@
-from ..generic.general_methods import aedt_exception_handler
-from ..modeler.Model2D import ModelerRMxprt
-from .Analysis import Analysis
-from .Design import design_solutions
+from pyaedt.generic.general_methods import aedt_exception_handler
+from pyaedt.modeler.Model2D import ModelerRMxprt
+from pyaedt.application.Analysis import Analysis
+from pyaedt.modules.PostProcessor import CircuitPostProcessor
 
 
 class FieldAnalysisRMxprt(Analysis):
@@ -18,24 +18,6 @@ class FieldAnalysisRMxprt(Analysis):
 
     """
 
-    @property
-    def solution_type(self):
-        """Solution type."""
-        return self._solution_type
-
-    @solution_type.setter
-    def solution_type(self, soltype):
-        sol = design_solutions[self._design_type]
-        if not soltype:
-            soltype = sol[0]
-        elif soltype not in sol:
-            soltype = sol[0]
-        try:
-            self.odesign.SetDesignFlow(self._design_type, soltype)
-            self._solution_type = soltype
-        except:
-            pass
-
     def __init__(
         self,
         application,
@@ -62,8 +44,9 @@ class FieldAnalysisRMxprt(Analysis):
             close_on_exit,
             student_version,
         )
+
         self._modeler = ModelerRMxprt(self)
-        # self._post = PostProcessor(self)
+        self._post = CircuitPostProcessor(self)
 
     @property
     def modeler(self):
@@ -114,19 +97,11 @@ class FieldAnalysisRMxprt(Analysis):
         self.solution_type = solution_type
         return True
 
-    # @property
-    # def mesh(self):
-    #     return self._mesh
-    #
-    # @property
-    # def post(self):
-    #     return self._post
-
     @aedt_exception_handler
     def _check_solution_consistency(self):
         """Check solution consistency."""
-        if self._solution_type:
-            return self._odesign.GetSolutionType() == self._solution_type
+        if self.design_solutions:
+            return self._odesign.GetSolutionType() == self.design_solutions._solution_type
         else:
             return True
 
