@@ -1,14 +1,17 @@
 """This module contains the `Components` class.
 
 """
+import math
 import re
 import warnings
+import os
 
-from pyaedt import generate_unique_name, is_ironpython, retry_ntimes
+from pyaedt import generate_unique_name, _retry_ntimes
 from pyaedt.edb_core.general import convert_py_list_to_net_list
-from pyaedt.generic.general_methods import aedt_exception_handler, get_filename_without_extension
-
-from .EDB_Data import EDBComponent
+from pyaedt.generic.general_methods import aedt_exception_handler, get_filename_without_extension, is_ironpython
+from pyaedt.generic.constants import SourceType
+from pyaedt.edb_core.EDB_Data import EDBComponent
+from pyaedt.edb_core.padstack import EdbPadstacks
 
 try:
     import clr
@@ -16,7 +19,8 @@ try:
     clr.AddReference("System")
     from System import String
 except ImportError:
-    warnings.warn("This module requires PythonNet.")
+    if os.name != "posix":
+        warnings.warn("This module requires PythonNet.")
 
 
 def resistor_value_parser(RValue):
@@ -33,7 +37,7 @@ def resistor_value_parser(RValue):
         Resistor value.
 
     """
-    if type(RValue) is str:
+    if isinstance(RValue, str):
         RValue = RValue.replace(" ", "")
         RValue = RValue.replace("meg", "m")
         RValue = RValue.replace("Ohm", "")
@@ -50,18 +54,17 @@ class Components(object):
 
     Parameters
     ----------
-    parent : str
+    edb_class : :class:`pyaedt.edb.Edb`
 
     Examples
     --------
     >>> from pyaedt import Edb
     >>> edbapp = Edb("myaedbfolder")
     >>> edbapp.core_components
-
     """
 
-    def __init__(self, parent):
-        self.parent = parent
+    def __init__(self, p_edb):
+        self._pedb = p_edb
         self._cmp = {}
         self._res = {}
         self._cap = {}
@@ -72,15 +75,16 @@ class Components(object):
         self._pins = {}
         self._comps_by_part = {}
         self._init_parts()
+        self._padstack = EdbPadstacks(self._pedb)
 
     @property
-    def _messenger(self):
-        """Messenger."""
-        return self.parent._messenger
+    def _logger(self):
+        """Logger."""
+        return self._pedb.logger
 
     @property
     def _edb(self):
-        return self.parent.edb
+        return self._pedb.edb
 
     @aedt_exception_handler
     def _init_parts(self):
@@ -95,31 +99,31 @@ class Components(object):
 
     @property
     def _builder(self):
-        return self.parent.builder
+        return self._pedb.builder
 
     @property
     def _edb_value(self):
-        return self.parent.edb_value
+        return self._pedb.edb_value
 
     @property
     def _edbutils(self):
-        return self.parent.edbutils
+        return self._pedb.edbutils
 
     @property
     def _active_layout(self):
-        return self.parent.active_layout
+        return self._pedb.active_layout
 
     @property
     def _cell(self):
-        return self.parent.cell
+        return self._pedb.cell
 
     @property
     def _db(self):
-        return self.parent.db
+        return self._pedb.db
 
     @property
     def _components_methods(self):
-        return self.parent.edblib.Layout.ComponentsMethods
+        return self._pedb.edblib.Layout.ComponentsMethods
 
     @property
     def components(self):
@@ -127,8 +131,8 @@ class Components(object):
 
         Returns
         -------
-        dict
-            Default dictionary for the EDB comopnent.
+        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
+            Default dictionary for the EDB component.
 
         Examples
         --------
@@ -144,22 +148,13 @@ class Components(object):
 
     @aedt_exception_handler
     def refresh_components(self):
-        """Refresh the component dictionary.
-
-        Returns
-        -------
-        dict
-            Default dictionary for the EDB component.
-
-        """
-        self._messenger.add_info_message("Refreshing the Components dictionary.")
-        try:
-            cmplist = self.get_component_list()
-            self._cmp = {}
-            for cmp in cmplist:
-                self._cmp[cmp.RefDes] = EDBComponent(self, cmp, cmp.RefDes)
-        except:
-            pass
+        """Refresh the component dictionary."""
+        self._cmp = {}
+        self._logger.info("Refreshing the Components dictionary.")
+        if self._active_layout:
+            for cmp in self._active_layout.Groups:
+                if cmp.GetType().ToString() == "Ansys.Ansoft.Edb.Cell.Hierarchy.Component":
+                    self._cmp[cmp.GetName()] = EDBComponent(self, cmp)
 
     @property
     def resistors(self):
@@ -167,7 +162,7 @@ class Components(object):
 
         Returns
         -------
-        dict
+        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
             Dictionary of resistors.
 
         Examples
@@ -189,7 +184,7 @@ class Components(object):
 
         Returns
         -------
-        dict
+        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
             Dictionary of capacitors.
 
         Examples
@@ -211,7 +206,7 @@ class Components(object):
 
         Returns
         -------
-        dict
+        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
             Dictionary of inductors.
 
         Examples
@@ -234,7 +229,7 @@ class Components(object):
 
         Returns
         -------
-        dict
+        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
             Dictionary of integrated circuits.
 
         Examples
@@ -257,7 +252,7 @@ class Components(object):
 
         Returns
         -------
-        dict
+        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
             Dictionary of circuit inputs and outputs.
 
         Examples
@@ -283,7 +278,7 @@ class Components(object):
 
         Returns
         -------
-        dict
+        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
             Dictionary of other core components.
 
         Examples
@@ -335,7 +330,7 @@ class Components(object):
             List of component setup information.
 
         """
-        cmp_setup_info_list = self._edbutils.ComponentSetupInfo.GetFromLayout(self._builder.EdbHandler.layout)
+        cmp_setup_info_list = self._edbutils.ComponentSetupInfo.GetFromLayout(self._active_layout)
         cmp_list = []
         for comp in cmp_setup_info_list:
             cmp_list.append(comp)
@@ -378,7 +373,7 @@ class Components(object):
 
         """
         cmp_list = []
-        if type(netlist) is str:
+        if isinstance(netlist, str):
             netlist = [netlist]
         components = list(self.components.keys())
         for refdes in components:
@@ -388,7 +383,335 @@ class Components(object):
         return cmp_list
 
     @aedt_exception_handler
-    def create_component_from_pins(self, pins, component_name):
+    def _get_edb_pin_from_pin_name(self, cmp, pin):
+        if not isinstance(cmp, self._edb.Cell.Hierarchy.Component):
+            return False
+        if not isinstance(pin, str):
+            pin = pin.GetName()
+        pins = self.get_pin_from_component(component=cmp, pinName=pin)
+        if pins:
+            return pins[0]
+        return False
+
+    @aedt_exception_handler
+    def get_component_placement_vector(
+        self,
+        mounted_component,
+        hosting_component,
+        mounted_component_pin1=None,
+        mounted_component_pin2=None,
+        hosting_component_pin1=None,
+        hosting_component_pin2=None,
+    ):
+        """Get the placement vector between 2 components.
+
+        Parameters
+        ----------
+        mounted_component : str
+            Mounted component name.
+        hosting_component : str
+            Hosting component name.
+        mounted_component_pin1 : str
+            Mounted component Pin 1 name.
+        mounted_component_pin2 : str
+            Mounted component Pin 2 name.
+        hosting_component_pin1 : str
+            Hosted component Pin 1 name.
+        hosting_component_pin2 : str
+            Hosted component Pin 2 name.
+
+        Returns
+        -------
+        tuple
+            Tuple of Vector offset, rotation and solder height.
+
+        Examples
+        --------
+        >>> edb1 = Edb(edbpath=targetfile1,  edbversion="2021.2")
+        >>> hosting_cmp = edb1.core_components.get_component_by_name("U100")
+        >>> mounted_cmp = edb2.core_components.get_component_by_name("BGA")
+        >>> vector, rotation, solder_ball_height = edb1.core_components.get_component_placement_vector(
+        ...                                             mounted_component=mounted_cmp,
+        ...                                             hosting_component=hosting_cmp,
+        ...                                             mounted_component_pin1="A12",
+        ...                                             mounted_component_pin2="A14",
+        ...                                             hosting_component_pin1="A12",
+        ...                                             hosting_component_pin2="A14")
+        """
+        m_pin1_pos = [0.0, 0.0]
+        m_pin2_pos = [0.0, 0.0]
+        h_pin1_pos = [0.0, 0.0]
+        h_pin2_pos = [0.0, 0.0]
+        if not isinstance(mounted_component, self._edb.Cell.Hierarchy.Component):
+            return False
+        if not isinstance(hosting_component, self._edb.Cell.Hierarchy.Component):
+            return False
+        if mounted_component_pin1:
+            m_pin1 = self._get_edb_pin_from_pin_name(mounted_component, mounted_component_pin1)
+            m_pin1_pos = self.get_pin_position(m_pin1)
+        if mounted_component_pin2:
+            m_pin2 = self._get_edb_pin_from_pin_name(mounted_component, mounted_component_pin2)
+            m_pin2_pos = self.get_pin_position(m_pin2)
+        if hosting_component_pin1:
+            h_pin1 = self._get_edb_pin_from_pin_name(hosting_component, hosting_component_pin1)
+            h_pin1_pos = self.get_pin_position(h_pin1)
+        if hosting_component_pin2:
+            h_pin2 = self._get_edb_pin_from_pin_name(hosting_component, hosting_component_pin2)
+            h_pin2_pos = self.get_pin_position(h_pin2)
+        vector = [h_pin1_pos[0] - m_pin1_pos[0], h_pin1_pos[1] - m_pin1_pos[1]]
+        d_m_pin1_h_pin2 = math.sqrt(
+            math.pow(h_pin2_pos[0] - m_pin1_pos[0], 2) + math.pow(h_pin2_pos[1] - m_pin1_pos[1], 2)
+        )
+        d_m_pin2_h_pin2 = math.sqrt(
+            math.pow(h_pin2_pos[0] - m_pin2_pos[0], 2) + math.pow(h_pin2_pos[1] - m_pin2_pos[1], 2)
+        )
+        rotation = math.atan(d_m_pin2_h_pin2 / d_m_pin1_h_pin2)
+        if vector:
+            solder_ball_height = self.get_solder_ball_height(mounted_component)
+            if solder_ball_height == 0.0:
+                solder_ball_height = 150e-6
+            # mounted_component_name = mounted_component.GetName()
+            self.set_solder_ball(component=mounted_component, sball_height=solder_ball_height)
+            return True, vector, rotation, solder_ball_height
+        return False
+
+    @aedt_exception_handler
+    def get_solder_ball_height(self, cmp):
+        """Get component solder ball height.
+
+        Parameters
+        ----------
+        cmp : str or self._edb.Cell.Hierarchy.Component
+            EDB component or str component name.
+
+        Returns
+        -------
+        double, bool
+            Salder ball height vale, ``False`` when failed.
+
+        """
+        if cmp is not None:
+            if not (isinstance(cmp, self._edb.Cell.Hierarchy.Component)):
+                cmp = self.get_component_by_name(cmp)
+            cmp_prop = cmp.GetComponentProperty().Clone()
+            return cmp_prop.GetSolderBallProperty().GetHeight()
+        return False
+
+    @aedt_exception_handler
+    def create_port_on_component(
+        self, component, net_list, port_type=SourceType.CoaxPort, do_pingroup=True, reference_net="gnd"
+    ):
+        """Create ports on given component.
+
+        Parameters
+        ----------
+        component : str or self._edb.Cell.Hierarchy.Component
+            EDB component or str component name.
+
+        net_list : str or list of string.
+            The list of nets where ports have to be created on the component.
+            If net is not part of the component this one will be skipped.
+
+        port_type : SourceType enumerator, CoaxPort or CircuitPort
+            Define the type of port to be created. CoaxPort will auto generate solder balls.
+            CircuitPort will generate circuit ports on pins belonging to the net list.
+
+        do_pingroup : bool
+            True activate pingroup during port creation (only used with combination of CoaxPort),
+            False will take the closest reference pin and generate one port per signal pin.
+
+        refnet : string or list of string.
+            list of the reference net.
+
+        Returns
+        -------
+        double, bool
+            Salder ball height vale, ``False`` when failed.
+
+        Examples
+        --------
+
+        >>> from pyaedt import Edb
+        >>> edbapp = Edb("myaedbfolder")
+        >>> net_list = ["M_DQ<1>", "M_DQ<2>", "M_DQ<3>", "M_DQ<4>", "M_DQ<5>"]
+        >>> edbapp.core_components.create_port_on_component(cmp="U2A5", net_list=net_list,
+        >>> port_type=SourceType.CoaxPort, do_pingroup=False, refnet="GND")
+
+        """
+        if isinstance(component, self._edb.Cell.Hierarchy.Component):
+            cmp = component.GetName()
+        if not isinstance(net_list, list):
+            net_list = [net_list]
+        for net in net_list:
+            if not isinstance(net, str):
+                try:
+                    net_name = net.GetName()
+                    if net_name != "":
+                        net_list.append(net_name)
+                except:
+                    pass
+        if reference_net in net_list:
+            net_list.remove(reference_net)
+        cmp_pins = self.get_pin_from_component(component, net_list)
+        if len(cmp_pins) == 0:
+            return False
+        pin_layers = cmp_pins[0].GetPadstackDef().GetData().GetLayerNames()
+
+        if port_type == SourceType.CoaxPort:
+            pad_params = self._padstack.get_pad_parameters(pin=cmp_pins[0], layername=pin_layers[0], pad_type=0)
+            sball_diam = min([self._edb_value(val).ToDouble() for val in pad_params[1]])
+            sb_height = sball_diam
+            self.set_solder_ball(component, sb_height, sball_diam)
+            for pin in cmp_pins:
+                self._padstack.create_coax_port(pin)
+
+        elif port_type == SourceType.CircPort:
+            ref_pins = self.get_pin_from_component(component, reference_net)
+            if do_pingroup:
+                pingroups = []
+                if len(ref_pins) == 1:
+                    ref_pin_group_term = self._create_terminal(ref_pins[0])
+                else:
+                    ref_pin_group = self.create_pingroup_from_pins(ref_pins)
+                    ref_pin_group_term = self._create_pin_group_terminal(ref_pin_group[1])
+                    if not ref_pin_group[0]:
+                        return False
+                ref_pin_group_term.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
+                ref_pin_group_term.SetIsCircuitPort(True)
+                for net in net_list:
+                    pins = [pin for pin in cmp_pins if pin.GetNet().GetName() == net]
+                    pin_group = self.create_pingroup_from_pins(pins)
+                    if pin_group[0]:
+                        pingroups.append(pin_group[1])
+                pg_terminal = []
+                for pg in pingroups:
+                    pg_term = self._create_pin_group_terminal(pg)
+                    pg_terminal.append(pg_term)
+                for term in pg_terminal:
+                    term.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
+                    term.SetIsCircuitPort(True)
+                    term.SetReferenceTerminal(ref_pin_group_term)
+            else:
+                for net in net_list:
+                    pins = [pin for pin in cmp_pins if pin.GetNet().GetName().lower() == net]
+                    for pin in pins:
+                        ref_pin = self._get_closest_pin_from(pin, ref_pins)
+                        ref_pin_term = self._create_terminal(ref_pin)
+                        term = self._create_terminal(pin)
+                        ref_pin_term.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
+                        ref_pin_term.SetIsCircuitPort(True)
+                        term.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
+                        term.SetIsCircuitPort(True)
+                        term.SetReferenceTerminal(ref_pin_term)
+        return True
+
+    @aedt_exception_handler
+    def _create_terminal(self, pin):
+        """Create terminal on component pin.
+
+        Parameters
+        ----------
+        pin : Edb padstack instance.
+
+        Returns
+        -------
+        Edb terminal.
+        """
+
+        res, pin_position, pin_rot = pin.GetPositionAndRotation(
+            self._edb.Geometry.PointData(self._edb_value(0.0), self._edb_value(0.0)), 0.0
+        )
+        if not is_ironpython:
+            res, from_layer, to_layer = pin.GetLayerRange(None, None)
+        else:
+            res, from_layer, to_layer = pin.GetLayerRange()
+        cmp_name = pin.GetComponent().GetName()
+        net_name = pin.GetNet().GetName()
+        pin_name = pin.GetName()
+        term_name = "{}_{}_{}".format(cmp_name, net_name, pin_name)
+        term = self._edb.Cell.Terminal.PointTerminal.Create(
+            pin.GetLayout(), pin.GetNet(), term_name, pin_position, from_layer
+        )
+        return term
+
+    @aedt_exception_handler
+    def _get_closest_pin_from(self, pin, ref_pinlist):
+        """Returns the closest pin from given pin among the list of reference pins.
+
+        Parameters
+        ----------
+        pin : Edb padstack instance.
+
+        ref_pinlist : list of reference edb pins.
+
+        Returns
+        -------
+        Edb pin.
+
+        """
+        res, pin_position, pin_rot = pin.GetPositionAndRotation(
+            self._edb.Geometry.PointData(self._edb_value(0.0), self._edb_value(0.0)), 0.0
+        )
+        distance = 1e3
+        closest_pin = ref_pinlist[0]
+        for ref_pin in ref_pinlist:
+            res, ref_pin_position, ref_pin_rot = ref_pin.GetPositionAndRotation(
+                self._edb.Geometry.PointData(self._edb_value(0.0), self._edb_value(0.0)), 0.0
+            )
+            temp_distance = pin_position.Distance(ref_pin_position)
+            if temp_distance < distance:
+                distance = temp_distance
+                closest_pin = ref_pin
+        return closest_pin
+
+    @aedt_exception_handler
+    def _create_pin_group_terminal(self, pingroup, isref=False):
+        """Creates edb pin group terminal from given edb pin group.
+
+        Parameters
+        ----------
+        pingroup : Edb pin group.
+
+        isref : bool
+
+        Returns
+        -------
+        Edb pin group terminal.
+        """
+
+        layout = pingroup.GetLayout()
+        cmp_name = pingroup.GetComponent().GetName()
+        net_name = pingroup.GetNet().GetName()
+        term_name = pingroup.GetUniqueName(layout, "Pingroup_{0}_{1}".format(cmp_name, net_name))
+        pingroup_term = self._edb.Cell.Terminal.PinGroupTerminal.Create(
+            self._active_layout, pingroup.GetNet(), term_name, pingroup, isref
+        )
+        return pingroup_term
+
+    @aedt_exception_handler
+    def _is_top_component(self, cmp):
+        """Test the component placment layer.
+
+        Parameters
+        ----------
+        cmp : self._edb.Cell.Hierarchy.Component
+             Edb component.
+
+        Returns
+        -------
+        bool
+            ``True`` when component placed on top layer, ``False`` on bottom layer.
+
+
+        """
+        signal_layers = cmp.GetLayout().GetLayerCollection().Layers(self._edb.Cell.LayerTypeSet.SignalLayerSet)
+        if cmp.GetPlacementLayer() == signal_layers[0]:
+            return True
+        else:
+            return False
+
+    @aedt_exception_handler
+    def create_component_from_pins(self, pins, component_name, placement_layer=None):
         """Create a component from pins.
 
         Parameters
@@ -397,6 +720,8 @@ class Components(object):
             List of EDB core pins.
         component_name : str
             Name of the reference designator for the component.
+        placement_layer : str
+            Name of the layer used for placing the component.
 
         Returns
         -------
@@ -413,16 +738,24 @@ class Components(object):
 
         """
         try:
-            new_cmp = self._edb.Cell.Hierarchy.Component.Create(self._builder.EdbHandler, component_name)
-            new_group = self._edb.Cell.Hierarchy.Group.Create(self._builder.EdbHandler.layout, component_name)
-            for pin in pins:
-                new_group.AddMember(pin)
+            new_cmp = self._edb.Cell.Hierarchy.Component.Create(self._active_layout, component_name, component_name)
+            new_group = self._edb.Cell.Hierarchy.Group.Create(self._active_layout, component_name)
             new_cmp.SetGroup(new_group)
-            new_cmp_layer_name = pins[0].GetPadstackDef().GetData().GetLayerNames().First()
+            for pin in pins:
+                pin.SetIsLayoutPin(True)
+                conv_pin = self._components_methods.PinToConnectable(pin)
+                add_result = new_group.AddMember(conv_pin)
+            # new_cmp.SetGroup(new_group)
+            if not placement_layer:
+                new_cmp_layer_name = pins[0].GetPadstackDef().GetData().GetLayerNames()[0]
+            else:
+                new_cmp_layer_name = placement_layer
             new_cmp_placement_layer = self._edb.Cell.Layer.FindByName(
-                self._builder.EdbHandler.layout.GetLayerCollection(), new_cmp_layer_name
+                self._active_layout.GetLayerCollection(), new_cmp_layer_name
             )
             new_cmp.SetPlacementLayer(new_cmp_placement_layer)
+            # cmp_transform = System.Activator.CreateInstance(self._edb.Utility.)
+            # new_cmp.SetTransform(cmp_transform)
             return (True, new_cmp)
         except:
             return (False, None)
@@ -487,10 +820,10 @@ class Components(object):
 
                 edbRlcComponentProperty.SetModel(spiceMod)
                 if not edbComponent.SetComponentProperty(edbRlcComponentProperty):
-                    self._messenger.add_error_message("Error Assigning the Touchstone model")
+                    self._logger.error("Error Assigning the Touchstone model")
                     return False
             else:
-                self._messenger.add_error_message("Wrong number of Pins")
+                self._logger.error("Wrong number of Pins")
                 return False
 
         elif model_type == "Touchstone":
@@ -514,7 +847,7 @@ class Components(object):
             sParameterMod.SetReferenceNet(net)
             edbRlcComponentProperty.SetModel(sParameterMod)
             if not edbComponent.SetComponentProperty(edbRlcComponentProperty):
-                self._messenger.add_error_message("Error Assigning the Touchstone model")
+                self._logger.error("Error Assigning the Touchstone model")
                 return False
         return True
 
@@ -543,13 +876,13 @@ class Components(object):
 
         """
         if len(pins) < 1:
-            self._messenger.add_error_message("No pins specified for pin group {}".format(group_name))
+            self._logger.error("No pins specified for pin group %s", group_name)
             return (False, None)
         if group_name is None:
             cmp_name = pins[0].GetComponent().GetName()
             net_name = pins[0].GetNet().GetName()
             group_name = generate_unique_name("{}_{}_".format(cmp_name, net_name), n=3)
-        pingroup = retry_ntimes(
+        pingroup = _retry_ntimes(
             10,
             self._edb.Cell.Hierarchy.PinGroup.Create,
             self._active_layout,
@@ -559,6 +892,7 @@ class Components(object):
         if pingroup.IsNull():
             return (False, None)
         else:
+            pingroup.SetNet(pins[0].GetNet())
             return (True, pingroup)
 
     @aedt_exception_handler
@@ -587,7 +921,7 @@ class Components(object):
                 if edb_cmp is not None:
                     edb_cmp.Delete()
                     deleted_comps.append(comp)
-                    self.parent._messenger.add_info_message("Component {} deleted".format(comp))
+                    self._pedb._logger.info("Component {} deleted".format(comp))
         for el in deleted_comps:
             del self.components[el]
         return deleted_comps
@@ -658,6 +992,87 @@ class Components(object):
             return True
         return False
 
+    @aedt_exception_handler
+    def set_solder_ball(self, component="", sball_diam="100um", sball_height="150um"):
+        """Set cylindrical solder balls on a given component.
+
+        Parameters
+        ----------
+        componentname : str or EDB component
+            Name of the discret component.
+
+        sball_diam  : str, float
+            Diameter of the solder ball.
+
+        sball_height : str, float
+            Height of the solder ball.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        Examples
+        --------
+
+        >>> from pyaedt import Edb
+        >>> edbapp = Edb("myaedbfolder")
+        >>> edbapp.core_components.set_solder_ball("A1")
+
+        """
+        if not isinstance(component, self._edb.Cell.Hierarchy.Component):
+            edb_cmp = self.get_component_by_name(component)
+        else:
+            edb_cmp = component
+        if edb_cmp:
+            cmp_type = edb_cmp.GetComponentType()
+            if cmp_type == self._edb.Definition.ComponentType.IC:
+                ic_cmp_property = edb_cmp.GetComponentProperty().Clone()
+                ic_die_prop = ic_cmp_property.GetDieProperty().Clone()
+                ic_die_prop.SetType(self._edb.Definition.DieType.FlipChip)
+                ic_die_prop.SetOrientation(self._edb.Definition.DieOrientation.ChipDown)
+                ic_cmp_property.SetDieProperty(ic_die_prop)
+
+                ic_solder_ball_prop = ic_cmp_property.GetSolderBallProperty().Clone()
+                ic_solder_ball_prop.SetDiameter(self._edb_value(sball_diam), self._edb_value(sball_diam))
+                ic_solder_ball_prop.SetHeight(self._edb_value(sball_height))
+                ic_solder_ball_prop.SetShape(self._edb.Definition.SolderballShape.Cylinder)
+                ic_cmp_property.SetSolderBallProperty(ic_solder_ball_prop)
+
+                ic_port_prop = ic_cmp_property.GetPortProperty().Clone()
+                ic_port_prop.SetReferenceSizeAuto(True)
+                ic_cmp_property.SetPortProperty(ic_port_prop)
+                edb_cmp.SetComponentProperty(ic_cmp_property)
+                return True
+
+            elif cmp_type == self._edb.Definition.ComponentType.IO:
+                io_cmp_prop = edb_cmp.GetComponentProperty().Clone()
+                io_solder_ball_prop = io_cmp_prop.GetSolderBallProperty().Clone()
+                io_solder_ball_prop.SetDiameter(self._edb_value(sball_diam), self._edb_value(sball_diam))
+                io_solder_ball_prop.SetHeight(self._edb_value(sball_height))
+                io_solder_ball_prop.SetShape(self._edb.Definition.SolderballShape.Cylinder)
+                io_cmp_prop.SetSolderBallProperty(io_solder_ball_prop)
+                io_port_prop = io_cmp_prop.GetPortProperty().Clone()
+                io_port_prop.SetReferenceSizeAuto(True)
+                io_cmp_prop.SetPortProperty(io_port_prop)
+                edb_cmp.SetComponentProperty(io_cmp_prop)
+                return True
+            elif cmp_type == self._edb.Definition.ComponentType.Other:
+                other_cmp_prop = edb_cmp.GetComponentProperty().Clone()
+                other_solder_ball_prop = other_cmp_prop.GetSolderBallProperty().Clone()
+                other_solder_ball_prop.SetDiameter(self._edb_value(sball_diam), self._edb_value(sball_diam))
+                other_solder_ball_prop.SetHeight(self._edb_value(sball_height))
+                other_solder_ball_prop.SetShape(self._edb.Definition.SolderballShape.Cylinder)
+                other_cmp_prop.SetSolderBallProperty(other_solder_ball_prop)
+                other_port_prop = other_cmp_prop.GetPortProperty().Clone()
+                other_port_prop.SetReferenceSizeAuto(True)
+                other_cmp_prop.SetPortProperty(other_port_prop)
+                edb_cmp.SetComponentProperty(other_port_prop)
+            else:
+                return False
+        else:
+            return False
+
     @aedt_exception_handler
     def set_component_rlc(self, componentname, res_value=None, ind_value=None, cap_value=None, isparallel=False):
         """Update values for an RLC component.
@@ -717,15 +1132,16 @@ class Components(object):
             if not edbRlcComponentProperty.SetModel(rlcModel) or not edbComponent.SetComponentProperty(
                 edbRlcComponentProperty
             ):
-                self._messenger.add_error_message("Failed to set RLC model on component")
+                self._logger.error("Failed to set RLC model on component")
                 return False
         else:
-            self._messenger.add_warning_message(
-                "Component {} has not been assigned because either it is not present in the layout "
-                "or it contains a number of pins not equal to 2".format(componentname)
+            self._logger.warning(
+                "Component %s has not been assigned because either it is not present in the layout "
+                "or it contains a number of pins not equal to 2",
+                componentname,
             )
             return False
-        self._messenger.add_warning_message("RLC properties for Component {} has been assigned.".format(componentname))
+        self._logger.warning("RLC properties for Component %s has been assigned.", componentname)
         return True
 
     @aedt_exception_handler
@@ -788,13 +1204,13 @@ class Components(object):
         return found
 
     @aedt_exception_handler
-    def get_pin_from_component(self, cmpName, netName=None, pinName=None):
+    def get_pin_from_component(self, component, netName=None, pinName=None):
         """Retrieve the pins of a component.
 
         Parameters
         ----------
-        cmpName : str
-            Name of the component.
+        component : str or EDB component
+            Name of the component or the EDB component object.
         netName : str, optional
             Filter on the net name as an alternative to
             ``pinName``. The default is ``None``.
@@ -815,30 +1231,36 @@ class Components(object):
         >>> edbapp.core_components.get_pin_from_component("R1", refdes)
 
         """
-
-        cmp = self._edb.Cell.Hierarchy.Component.FindByName(self._active_layout, cmpName)
+        if not isinstance(component, self._edb.Cell.Hierarchy.Component):
+            component = self._edb.Cell.Hierarchy.Component.FindByName(self._active_layout, component)
         if netName:
+            if not isinstance(netName, list):
+                netName = [netName]
+            # pins = []
+            # cmp_obj = list(cmp.LayoutObjs)
+            # for p in cmp_obj:
+            #    if p.GetObjType() == 1:
+            #        if p.IsLayoutPin():
+            #            pin_net_name = p.GetNet().GetName()
+            #            if pin_net_name in netName:
+            #                pins.append(p)
             pins = [
                 p
-                for p in cmp.LayoutObjs
-                if p.GetObjType() == self._edb.Cell.LayoutObjType.PadstackInstance
-                and p.IsLayoutPin()
-                and p.GetNet().GetName() == netName
+                for p in list(component.LayoutObjs)
+                if int(p.GetObjType()) == 1 and p.IsLayoutPin() and p.GetNet().GetName() in netName
             ]
         elif pinName:
+            if not isinstance(pinName, list):
+                pinName = [pinName]
             pins = [
                 p
-                for p in cmp.LayoutObjs
-                if p.GetObjType() == self._edb.Cell.LayoutObjType.PadstackInstance
+                for p in list(component.LayoutObjs)
+                if int(p.GetObjType()) == 1
                 and p.IsLayoutPin()
-                and (self.get_aedt_pin_name(p) == str(pinName) or p.GetName() == str(pinName))
+                and (self.get_aedt_pin_name(p) == str(pinName) or p.GetName() in str(pinName))
             ]
         else:
-            pins = [
-                p
-                for p in cmp.LayoutObjs
-                if p.GetObjType() == self._edb.Cell.LayoutObjType.PadstackInstance and p.IsLayoutPin()
-            ]
+            pins = [p for p in list(component.LayoutObjs) if int(p.GetObjType()) == 1 and p.IsLayoutPin()]
         return pins
 
     @aedt_exception_handler
