@@ -1,56 +1,66 @@
 """
-This module contains the `Edb3DLayout` class.
+This module contains the `EdbHfss` class.
 """
-from pyaedt import is_ironpython
 from pyaedt.edb_core.general import convert_netdict_to_pydict
-from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name
+from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name, is_ironpython
 
 
-class Edb3DLayout(object):
-    """Manages EDB functionalities for 3D layouts."""
+class EdbHfss(object):
+    """Manages EDB functionalities for 3D layouts.
 
-    def __init__(self, parent):
-        self.parent = parent
+    Examples
+    --------
+    >>> from pyaedt import Edb
+    >>> edbapp = Edb("myaedbfolder")
+    >>> edb_hfss = edb_3dedbapp.core_hfss
+    """
+
+    def __init__(self, p_edb):
+        self._pedb = p_edb
 
     @property
     def _hfss_terminals(self):
-        return self.parent.edblib.HFSS3DLayout.HFSSTerminalMethods
+        return self._pedb.edblib.HFSS3DLayout.HFSSTerminalMethods
 
     @property
     def _hfss_ic_methods(self):
-        return self.parent.edblib.HFSS3DLayout.ICMethods
+        return self._pedb.edblib.HFSS3DLayout.ICMethods
 
     @property
     def _hfss_setup(self):
-        return self.parent.edblib.HFSS3DLayout.HFSSSetup
+        return self._pedb.edblib.HFSS3DLayout.HFSSSetup
 
     @property
     def _hfss_mesh_setup(self):
-        return self.parent.edblib.HFSS3DLayout.Meshing
+        return self._pedb.edblib.HFSS3DLayout.Meshing
 
     @property
     def _sweep_methods(self):
-        return self.parent.edblib.SimulationSetup.SweepMethods
+        return self._pedb.edblib.SimulationSetup.SweepMethods
+
+    @property
+    def _logger(self):
+        return self._pedb.logger
 
     @property
     def _edb(self):
-        return self.parent.edb
+        return self._pedb.edb
 
     @property
     def _active_layout(self):
-        return self.parent.active_layout
+        return self._pedb.active_layout
 
     @property
     def _cell(self):
-        return self.parent.cell
+        return self._pedb.cell
 
     @property
     def _db(self):
-        return self.parent.db
+        return self._pedb.db
 
     @property
     def _builder(self):
-        return self.parent.builder
+        return self._pedb.builder
 
     @aedt_exception_handler
     def get_trace_width_for_traces_with_ports(self):
@@ -61,7 +71,7 @@ class Edb3DLayout(object):
         dict
             Dictionary of trace width data.
         """
-        mesh = self._hfss_mesh_setup.GetMeshOperation(self._builder)
+        mesh = self._hfss_mesh_setup.GetMeshOperation(self._active_layout)
         if mesh.Item1:
             return convert_netdict_to_pydict(mesh.Item2)
         else:
@@ -93,7 +103,7 @@ class Edb3DLayout(object):
             Port Name.
 
         """
-        return self.parent.core_siwave.create_circuit_port_on_pin(pos_pin, neg_pin, impedance, port_name)
+        return self._pedb.core_siwave.create_circuit_port_on_pin(pos_pin, neg_pin, impedance, port_name)
 
     @aedt_exception_handler
     def create_voltage_source_on_pin(self, pos_pin, neg_pin, voltage_value=3.3, phase_value=0, source_name=""):
@@ -125,7 +135,7 @@ class Edb3DLayout(object):
         >>> pins =edbapp.core_components.get_pin_from_component("U2A5")
         >>> edbapp.core_hfss.create_voltage_source_on_pin(pins[0], pins[1],50,"source_name")
         """
-        return self.parent.core_siwave.create_voltage_source_on_pin(
+        return self._pedb.core_siwave.create_voltage_source_on_pin(
             pos_pin, neg_pin, voltage_value, phase_value, source_name
         )
 
@@ -160,7 +170,7 @@ class Edb3DLayout(object):
         >>> edbapp.core_hfss.create_current_source_on_pin(pins[0], pins[1],50,"source_name")
         """
 
-        return self.parent.core_siwave.create_current_source_on_pin(
+        return self._pedb.core_siwave.create_current_source_on_pin(
             pos_pin, neg_pin, current_value, phase_value, source_name
         )
 
@@ -192,7 +202,7 @@ class Edb3DLayout(object):
         >>> pins =edbapp.core_components.get_pin_from_component("U2A5")
         >>> edbapp.core_hfss.create_resistor_on_pin(pins[0], pins[1],50,"res_name")
         """
-        return self.parent.core_siwave.create_resistor_on_pin(pos_pin, neg_pin, rvalue, resistor_name)
+        return self._pedb.core_siwave.create_resistor_on_pin(pos_pin, neg_pin, rvalue, resistor_name)
 
     @aedt_exception_handler
     def create_circuit_port_on_net(
@@ -234,7 +244,7 @@ class Edb3DLayout(object):
         >>> edbapp = Edb("myaedbfolder", "project name", "release version")
         >>> edbapp.core_hfss.create_circuit_port_on_net("U2A5", "V1P5_S3", "U2A5", "GND", 50, "port_name")
         """
-        return self.parent.core_siwave.create_circuit_port_on_net(
+        return self._pedb.core_siwave.create_circuit_port_on_net(
             positive_component_name,
             positive_net_name,
             negative_component_name,
@@ -286,7 +296,7 @@ class Edb3DLayout(object):
         >>> edbapp = Edb("myaedbfolder", "project name", "release version")
         >>> edb.core_hfss.create_voltage_source_on_net("U2A5", "V1P5_S3", "U2A5", "GND", 3.3, 0, "source_name")
         """
-        return self.parent.core_siwave.create_voltage_source_on_net(
+        return self._pedb.core_siwave.create_voltage_source_on_net(
             positive_component_name,
             positive_net_name,
             negative_component_name,
@@ -339,7 +349,7 @@ class Edb3DLayout(object):
         >>> edbapp = Edb("myaedbfolder", "project name", "release version")
         >>> edb.core_hfss.create_current_source_on_net("U2A5", "V1P5_S3", "U2A5", "GND", 0.1, 0, "source_name")
         """
-        return self.parent.core_siwave.create_current_source_on_net(
+        return self._pedb.core_siwave.create_current_source_on_net(
             positive_component_name,
             positive_net_name,
             negative_component_name,
@@ -389,7 +399,7 @@ class Edb3DLayout(object):
         >>> edbapp = Edb("myaedbfolder", "project name", "release version")
         >>> edb.core_hfss.create_resistor_on_net("U2A5", "V1P5_S3", "U2A5", "GND", 1, "resistor_name")
         """
-        return self.parent.core_siwave.create_resistor_on_net(
+        return self._pedb.core_siwave.create_resistor_on_net(
             positive_component_name,
             positive_net_name,
             negative_component_name,
@@ -425,7 +435,7 @@ class Edb3DLayout(object):
         if not isinstance(net_list, list):
             net_list = [net_list]
         for ref in ref_des_list:
-            for pinname, pin in self.parent.core_components.components[ref].pins.items():
+            for pinname, pin in self._pedb.core_components.components[ref].pins.items():
                 if pin.net in net_list and pin.pin.IsLayoutPin():
                     port_name = "{}_{}_{}".format(ref, pin.net, pin.pin.GetName())
                     if is_ironpython:
