@@ -7,14 +7,14 @@ import os
 import time
 import warnings
 
-from pyaedt import is_ironpython
-from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name, retry_ntimes
+from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name, _retry_ntimes, is_ironpython
 
 try:
     from System import String
     from System.Collections.Generic import Dictionary
 except ImportError:
-    warnings.warn("This module requires pythonnet.")
+    if os.name != "posix":
+        warnings.warn("This module requires pythonnet.")
 
 
 class SiwaveDCSetupTemplate(object):
@@ -355,59 +355,63 @@ class EdbSiwave(object):
 
     Parameters
     ----------
-    parent :
+    edb_class : :class:`pyaedt.edb.Edb`
         Inherited parent object.
 
     Examples
     --------
     >>> from pyaedt import Edb
-    >>> edbapp = Edb("myaedbfolder", edbversion="2021.1")
-    >>> edbapp.core_siwave
-
+    >>> edbapp = Edb("myaedbfolder", edbversion="2021.2")
+    >>> edb_siwave = edbapp.core_siwave
     """
 
-    def __init__(self, parent):
-        self.parent = parent
+    def __init__(self, p_edb):
+        self._pedb = p_edb
 
     @property
     def _siwave_source(self):
         """SIwave source."""
-        return self.parent.edblib.SIwave.SiwaveSourceMethods
+        return self._pedb.edblib.SIwave.SiwaveSourceMethods
 
     @property
     def _siwave_setup(self):
         """SIwave setup."""
-        return self.parent.edblib.SIwave.SiwaveSimulationSetupMethods
+        return self._pedb.edblib.SIwave.SiwaveSimulationSetupMethods
 
     @property
     def _builder(self):
         """Builder."""
-        return self.parent.builder
+        return self._pedb.builder
 
     @property
     def _edb(self):
         """EDB."""
-        return self.parent.edb
+        return self._pedb.edb
 
     @property
-    def _messenger(self):
+    def _edb_value(self):
         """EDB."""
-        return self.parent._messenger
+        return self._pedb.edb_value
+
+    @property
+    def _logger(self):
+        """EDB."""
+        return self._pedb.logger
 
     @property
     def _active_layout(self):
         """Active layout."""
-        return self.parent.active_layout
+        return self._pedb.active_layout
 
     @property
     def _cell(self):
         """Cell."""
-        return self.parent.active_cell
+        return self._pedb.active_cell
 
     @property
     def _db(self):
         """ """
-        return self.parent.db
+        return self._pedb.db
 
     @aedt_exception_handler
     def _create_terminal_on_pins(self, source):
@@ -428,7 +432,7 @@ class EdbSiwave(object):
         else:
             res, fromLayer_pos, toLayer_pos = source.positive_node.node_pins.GetLayerRange(None, None)
             res, fromLayer_neg, toLayer_neg = source.negative_node.node_pins.GetLayerRange(None, None)
-        pos_pingroup_terminal = retry_ntimes(
+        pos_pingroup_terminal = _retry_ntimes(
             10,
             self._edb.Cell.Terminal.PadstackInstanceTerminal.Create,
             self._active_layout,
@@ -438,8 +442,8 @@ class EdbSiwave(object):
             toLayer_pos,
         )
         time.sleep(0.5)
-        neg_pingroup_terminal = retry_ntimes(
-            10,
+        neg_pingroup_terminal = _retry_ntimes(
+            20,
             self._edb.Cell.Terminal.PadstackInstanceTerminal.Create,
             self._active_layout,
             neg_pin.GetNet(),
@@ -450,7 +454,7 @@ class EdbSiwave(object):
         if source.type == SourceType.Port:
             pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
             neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
-            pos_pingroup_terminal.SetSourceAmplitude(self._edb.Utility.Value(source.impedance))
+            pos_pingroup_terminal.SetSourceAmplitude(self._edb_value(source.impedance))
             pos_pingroup_terminal.SetIsCircuitPort(True)
             neg_pingroup_terminal.SetIsCircuitPort(True)
             pos_pingroup_terminal.SetReferenceTerminal(neg_pingroup_terminal)
@@ -459,50 +463,50 @@ class EdbSiwave(object):
             except:
                 name = generate_unique_name(source.name)
                 pos_pingroup_terminal.SetName(name)
-                self._messenger.add_warning_message("{} already exists. Renaming to {}".format(source.name, name))
+                self._logger.warning("%s already exists. Renaming to %s", source.name, name)
         elif source.type == SourceType.CurrentSource:
             pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kCurrentSource)
             neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kCurrentSource)
-            pos_pingroup_terminal.SetSourceAmplitude(self._edb.Utility.Value(source.magnitude))
-            pos_pingroup_terminal.SetSourcePhase(self._edb.Utility.Value(source.phase))
+            pos_pingroup_terminal.SetSourceAmplitude(self._edb_value(source.magnitude))
+            pos_pingroup_terminal.SetSourcePhase(self._edb_value(source.phase))
             pos_pingroup_terminal.SetReferenceTerminal(neg_pingroup_terminal)
             try:
                 pos_pingroup_terminal.SetName(source.name)
             except Exception as e:
                 name = generate_unique_name(source.name)
                 pos_pingroup_terminal.SetName(name)
-                self._messenger.add_warning_message("{} already exists. Renaming to {}".format(source.name, name))
+                self._logger.warning("%s already exists. Renaming to %s", source.name, name)
 
         elif source.type == SourceType.VoltageSource:
             pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kVoltageSource)
             neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kVoltageSource)
-            pos_pingroup_terminal.SetSourceAmplitude(self._edb.Utility.Value(source.magnitude))
-            pos_pingroup_terminal.SetSourcePhase(self._edb.Utility.Value(source.phase))
+            pos_pingroup_terminal.SetSourceAmplitude(self._edb_value(source.magnitude))
+            pos_pingroup_terminal.SetSourcePhase(self._edb_value(source.phase))
             pos_pingroup_terminal.SetReferenceTerminal(neg_pingroup_terminal)
             try:
                 pos_pingroup_terminal.SetName(source.name)
             except:
                 name = generate_unique_name(source.name)
                 pos_pingroup_terminal.SetName(name)
-                self._messenger.add_warning_message("{} already exists. Renaming to {}".format(source.name, name))
+                self._logger.warning("%s already exists. Renaming to %s", source.name, name)
 
         elif source.type == SourceType.Resistor:
             pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.RlcBoundary)
             neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.RlcBoundary)
             pos_pingroup_terminal.SetReferenceTerminal(neg_pingroup_terminal)
-            pos_pingroup_terminal.SetSourceAmplitude(self._edb.Utility.Value(source.rvalue))
+            pos_pingroup_terminal.SetSourceAmplitude(self._edb_value(source.rvalue))
             Rlc = self._edb.Utility.Rlc()
             Rlc.CEnabled = False
             Rlc.LEnabled = False
             Rlc.REnabled = True
-            Rlc.R = self._edb.Utility.Value(source.rvalue)
+            Rlc.R = self._edb_value(source.rvalue)
             pos_pingroup_terminal.SetRlcBoundaryParameters(Rlc)
             try:
                 pos_pingroup_terminal.SetName(source.name)
             except:
                 name = generate_unique_name(source.name)
                 pos_pingroup_terminal.SetName(name)
-                self._messenger.add_warning_message("{} already exists. Renaming to {}".format(source.name, name))
+                self._logger.warning("%s already exists. Renaming to %s", source.name, name)
         else:
             pass
         return pos_pingroup_terminal.GetName()
@@ -648,7 +652,7 @@ class EdbSiwave(object):
         current_source.positive_node.component_node = pos_pin.GetComponent()
         current_source.positive_node.node_pins = pos_pin
         current_source.negative_node.component_node = neg_pin.GetComponent()
-        current_source.negative_node.node_pins = pos_pin
+        current_source.negative_node.node_pins = neg_pin
         return self._create_terminal_on_pins(current_source)
 
     @aedt_exception_handler
@@ -700,13 +704,13 @@ class EdbSiwave(object):
     @aedt_exception_handler
     def _check_gnd(self, component_name):
         negative_net_name = None
-        if self.parent.core_nets.is_net_in_component(component_name, "GND"):
+        if self._pedb.core_nets.is_net_in_component(component_name, "GND"):
             negative_net_name = "GND"
-        elif self.parent.core_nets.is_net_in_component(component_name, "PGND"):
+        elif self._pedb.core_nets.is_net_in_component(component_name, "PGND"):
             negative_net_name = "PGND"
-        elif self.parent.core_nets.is_net_in_component(component_name, "AGND"):
+        elif self._pedb.core_nets.is_net_in_component(component_name, "AGND"):
             negative_net_name = "AGND"
-        elif self.parent.core_nets.is_net_in_component(component_name, "DGND"):
+        elif self._pedb.core_nets.is_net_in_component(component_name, "DGND"):
             negative_net_name = "DGND"
         if not negative_net_name:
             raise ValueError("No GND, PGND, AGND, DGND found. Please setup the negative net name manually.")
@@ -762,10 +766,10 @@ class EdbSiwave(object):
         circuit_port.positive_node.net = positive_net_name
         circuit_port.negative_node.net = negative_net_name
         circuit_port.impedance = impedance_value
-        pos_node_cmp = self.parent.core_components.get_component_by_name(positive_component_name)
-        neg_node_cmp = self.parent.core_components.get_component_by_name(negative_component_name)
-        pos_node_pins = self.parent.core_components.get_pin_from_component(positive_component_name, positive_net_name)
-        neg_node_pins = self.parent.core_components.get_pin_from_component(negative_component_name, negative_net_name)
+        pos_node_cmp = self._pedb.core_components.get_component_by_name(positive_component_name)
+        neg_node_cmp = self._pedb.core_components.get_component_by_name(negative_component_name)
+        pos_node_pins = self._pedb.core_components.get_pin_from_component(positive_component_name, positive_net_name)
+        neg_node_pins = self._pedb.core_components.get_pin_from_component(negative_component_name, negative_net_name)
         if port_name == "":
             port_name = "Port_{}_{}_{}_{}".format(
                 positive_component_name, positive_net_name, negative_component_name, negative_net_name
@@ -829,10 +833,10 @@ class EdbSiwave(object):
         voltage_source.negative_node.net = negative_net_name
         voltage_source.magnitude = voltage_value
         voltage_source.phase = phase_value
-        pos_node_cmp = self.parent.core_components.get_component_by_name(positive_component_name)
-        neg_node_cmp = self.parent.core_components.get_component_by_name(negative_component_name)
-        pos_node_pins = self.parent.core_components.get_pin_from_component(positive_component_name, positive_net_name)
-        neg_node_pins = self.parent.core_components.get_pin_from_component(negative_component_name, negative_net_name)
+        pos_node_cmp = self._pedb.core_components.get_component_by_name(positive_component_name)
+        neg_node_cmp = self._pedb.core_components.get_component_by_name(negative_component_name)
+        pos_node_pins = self._pedb.core_components.get_pin_from_component(positive_component_name, positive_net_name)
+        neg_node_pins = self._pedb.core_components.get_pin_from_component(negative_component_name, negative_net_name)
 
         if source_name == "":
             source_name = "Vsource_{}_{}_{}_{}".format(
@@ -897,10 +901,10 @@ class EdbSiwave(object):
         current_source.negative_node.net = negative_net_name
         current_source.magnitude = current_value
         current_source.phase = phase_value
-        pos_node_cmp = self.parent.core_components.get_component_by_name(positive_component_name)
-        neg_node_cmp = self.parent.core_components.get_component_by_name(negative_component_name)
-        pos_node_pins = self.parent.core_components.get_pin_from_component(positive_component_name, positive_net_name)
-        neg_node_pins = self.parent.core_components.get_pin_from_component(negative_component_name, negative_net_name)
+        pos_node_cmp = self._pedb.core_components.get_component_by_name(positive_component_name)
+        neg_node_cmp = self._pedb.core_components.get_component_by_name(negative_component_name)
+        pos_node_pins = self._pedb.core_components.get_pin_from_component(positive_component_name, positive_net_name)
+        neg_node_pins = self._pedb.core_components.get_pin_from_component(negative_component_name, negative_net_name)
 
         if source_name == "":
             source_name = "Port_{}_{}_{}_{}".format(
@@ -960,10 +964,10 @@ class EdbSiwave(object):
         resistor.positive_node.net = positive_net_name
         resistor.negative_node.net = negative_net_name
         resistor.magnitude = rvalue
-        pos_node_cmp = self.parent.core_components.get_component_by_name(positive_component_name)
-        neg_node_cmp = self.parent.core_components.get_component_by_name(negative_component_name)
-        pos_node_pins = self.parent.core_components.get_pin_from_component(positive_component_name, positive_net_name)
-        neg_node_pins = self.parent.core_components.get_pin_from_component(negative_component_name, negative_net_name)
+        pos_node_cmp = self._pedb.core_components.get_component_by_name(positive_component_name)
+        neg_node_cmp = self._pedb.core_components.get_component_by_name(negative_component_name)
+        pos_node_pins = self._pedb.core_components.get_pin_from_component(positive_component_name, positive_net_name)
+        neg_node_pins = self._pedb.core_components.get_pin_from_component(negative_component_name, negative_net_name)
 
         if resistor_name == "":
             resistor_name = "Port_{}_{}_{}_{}".format(
@@ -979,8 +983,8 @@ class EdbSiwave(object):
     @aedt_exception_handler
     def create_exec_file(self):
         """Create an executable file."""
-        workdir = os.path.dirname(self.parent.edbpath)
-        file_name = os.path.join(workdir, os.path.splitext(os.path.basename(self.parent.edbpath))[0] + ".exec")
+        workdir = os.path.dirname(self._pedb.edbpath)
+        file_name = os.path.join(workdir, os.path.splitext(os.path.basename(self._pedb.edbpath))[0] + ".exec")
         if os.path.isfile(file_name):
             os.remove(file_name)
         f = open(file_name, "w")
@@ -1022,7 +1026,7 @@ class EdbSiwave(object):
             ``True`` when successful, ``False`` when failed.
         """
         self._siwave_setup.AddACSimSetup(
-            self._builder,
+            self._cell,
             accuracy_level,
             str(decade_count),
             sweeptype,
@@ -1073,7 +1077,7 @@ class EdbSiwave(object):
         """
 
         self._siwave_setup.AddSYZSimSetup(
-            self._builder,
+            self._cell,
             accuracy_level,
             str(decade_count),
             sweeptype,
@@ -1131,8 +1135,8 @@ class EdbSiwave(object):
         >>> edb.core_siwave.add_siwave_dc_analysis2(settings)
 
         """
-        sim_setup_info = self.parent.simsetupdata.SimSetupInfo[
-            self.parent.simsetupdata.SIwave.SIWDCIRSimulationSettings
+        sim_setup_info = self._pedb.simsetupdata.SimSetupInfo[
+            self._pedb.simsetupdata.SIwave.SIWDCIRSimulationSettings
         ]()
         sim_setup_info.Name = setup_settings.name
         sim_setup_info.SimulationSettings.DCIRSettings.DCReportShowActiveDevices = (
@@ -1187,13 +1191,13 @@ class EdbSiwave(object):
             Name of the source.
 
         """
-        pos_pin_group = self.parent.core_components.create_pingroup_from_pins(source.positive_node.node_pins)
-        neg_pin_group = self.parent.core_components.create_pingroup_from_pins(source.negative_node.node_pins)
-        pos_node_net = self.parent.core_nets.get_net_by_name(source.positive_node.net)
-        neg_node_net = self.parent.core_nets.get_net_by_name(source.negative_node.net)
+        pos_pin_group = self._pedb.core_components.create_pingroup_from_pins(source.positive_node.node_pins)
+        neg_pin_group = self._pedb.core_components.create_pingroup_from_pins(source.negative_node.node_pins)
+        pos_node_net = self._pedb.core_nets.get_net_by_name(source.positive_node.net)
+        neg_node_net = self._pedb.core_nets.get_net_by_name(source.negative_node.net)
         pos_pingroup_term_name = generate_unique_name(source.name + "_P_", n=3)
         neg_pingroup_term_name = generate_unique_name(source.name + "_N_", n=3)
-        pos_pingroup_terminal = retry_ntimes(
+        pos_pingroup_terminal = _retry_ntimes(
             10,
             self._edb.Cell.Terminal.PinGroupTerminal.Create,
             self._active_layout,
@@ -1203,8 +1207,8 @@ class EdbSiwave(object):
             False,
         )
         time.sleep(0.5)
-        neg_pingroup_terminal = retry_ntimes(
-            10,
+        neg_pingroup_terminal = _retry_ntimes(
+            20,
             self._edb.Cell.Terminal.PinGroupTerminal.Create,
             self._active_layout,
             neg_node_net,
@@ -1216,7 +1220,7 @@ class EdbSiwave(object):
         if source.type == SourceType.Port:
             pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
             neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
-            pos_pingroup_terminal.SetSourceAmplitude(self._edb.Utility.Value(source.impedance))
+            pos_pingroup_terminal.SetSourceAmplitude(self._edb_value(source.impedance))
             pos_pingroup_terminal.SetIsCircuitPort(True)
             neg_pingroup_terminal.SetIsCircuitPort(True)
             pos_pingroup_terminal.SetReferenceTerminal(neg_pingroup_terminal)
@@ -1225,12 +1229,12 @@ class EdbSiwave(object):
             except:
                 name = generate_unique_name(source.name)
                 pos_pingroup_terminal.SetName(name)
-                self._messenger.add_warning_message("{} already exists. Renaming to {}".format(source.name, name))
+                self._logger.warning("%s already exists. Renaming to %s", source.name, name)
 
         elif source.type == SourceType.CurrentSource:
             pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kCurrentSource)
             neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kCurrentSource)
-            pos_pingroup_terminal.SetSourceAmplitude(self._edb.Utility.Value(source.magnitude))
+            pos_pingroup_terminal.SetSourceAmplitude(self._edb_value(source.magnitude))
             pos_pingroup_terminal.SetSourcePhase(self._edb.Utility.Value(source.phase))
             pos_pingroup_terminal.SetReferenceTerminal(neg_pingroup_terminal)
             try:
@@ -1238,31 +1242,31 @@ class EdbSiwave(object):
             except Exception as e:
                 name = generate_unique_name(source.name)
                 pos_pingroup_terminal.SetName(name)
-                self._messenger.add_warning_message("{} already exists. Renaming to {}".format(source.name, name))
+                self._logger.warning("%s already exists. Renaming to %s", source.name, name)
 
         elif source.type == SourceType.VoltageSource:
             pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kVoltageSource)
             neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kVoltageSource)
-            pos_pingroup_terminal.SetSourceAmplitude(self._edb.Utility.Value(source.magnitude))
-            pos_pingroup_terminal.SetSourcePhase(self._edb.Utility.Value(source.phase))
+            pos_pingroup_terminal.SetSourceAmplitude(self._edb_value(source.magnitude))
+            pos_pingroup_terminal.SetSourcePhase(self._edb_value(source.phase))
             pos_pingroup_terminal.SetReferenceTerminal(neg_pingroup_terminal)
             try:
                 pos_pingroup_terminal.SetName(source.name)
             except:
                 name = generate_unique_name(source.name)
                 pos_pingroup_terminal.SetName(name)
-                self._messenger.add_warning_message("{} already exists. Renaming to {}".format(source.name, name))
+                self._logger.warning("%s already exists. Renaming to %s", source.name, name)
 
         elif source.type == SourceType.Resistor:
             pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.RlcBoundary)
             neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.RlcBoundary)
             pos_pingroup_terminal.SetReferenceTerminal(neg_pingroup_terminal)
-            pos_pingroup_terminal.SetSourceAmplitude(self._edb.Utility.Value(source.rvalue))
+            pos_pingroup_terminal.SetSourceAmplitude(self._edb_value(source.rvalue))
             Rlc = self._edb.Utility.Rlc()
             Rlc.CEnabled = False
             Rlc.LEnabled = False
             Rlc.REnabled = True
-            Rlc.R = self._edb.Utility.Value(source.rvalue)
+            Rlc.R = self._edb_value(source.rvalue)
             pos_pingroup_terminal.SetRlcBoundaryParameters(Rlc)
 
         else:
