@@ -5,7 +5,7 @@ import shutil
 import zipfile
 import tempfile
 
-from pyaedt import is_ironpython
+from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.misc import list_installed_ansysem
 
 if is_ironpython:
@@ -58,16 +58,28 @@ def _retrieve_file(url, filename, directory):
         versions = list_installed_ansysem()
         if versions:
             cpython = os.listdir(os.path.join(os.getenv(versions[0]), "commonfiles", "CPython"))
-            command = "\"" + os.path.join(os.getenv(versions[0]), "commonfiles", "CPython", cpython[0], "winx64",
-                                          "Release", "python", "python.exe") + "\""
+            command = (
+                '"'
+                + os.path.join(
+                    os.getenv(versions[0]),
+                    "commonfiles",
+                    "CPython",
+                    cpython[0],
+                    "winx64",
+                    "Release",
+                    "python",
+                    "python.exe",
+                )
+                + '"'
+            )
             commandargs = os.path.join(os.path.dirname(local_path), "download.py")
-            command += " \"" + commandargs + "\""
+            command += ' "' + commandargs + '"'
             with open(os.path.join(os.path.dirname(local_path), "download.py"), "w") as f:
                 f.write("import urllib.request\n")
                 f.write("urlretrieve = urllib.request.urlretrieve\n")
                 f.write("import urllib.request\n")
-                f.write("url = r\"{}\"\n".format(url))
-                f.write("local_path = r\"{}\"\n".format(local_path))
+                f.write('url = r"{}"\n'.format(url))
+                f.write('local_path = r"{}"\n'.format(local_path))
                 f.write("urlretrieve(url, local_path)\n")
             print(command)
             os.system(command)
@@ -207,6 +219,30 @@ def download_icepak():
     return _download_file("icepak", "Graphics_card.aedt")
 
 
+def download_via_wizard():
+    """Download an example of Hfss Via Wizard and return the def path.
+
+    Examples files are downloaded to a persistent cache to avoid
+    re-downloading the same file twice.
+
+    Returns
+    -------
+    str
+        Path to the example file.
+
+    Examples
+    --------
+    Download an example result file and return the path of the file
+
+    >>> from pyaedt import examples
+    >>> path = examples.download_via_wizard()
+    >>> path
+    'C:/Users/user/AppData/local/temp/pyaedtexamples/Graphic_Card.aedt'
+    """
+
+    return _download_file("via_wizard", "viawizard_vacuum_FR4.aedt")
+
+
 def download_touchstone():
     """Download an example of touchstone File and return the def path.
 
@@ -279,8 +315,10 @@ def download_multiparts():
     >>> path
     'C:/Users/user/AppData/local/temp/multiparts/library'
     """
-    _download_file("multiparts", "library.zip")
     dest_folder = os.path.join(EXAMPLES_PATH, "multiparts")
+    if os.path.exists(os.path.join(dest_folder, "library")):
+        shutil.rmtree(os.path.join(dest_folder, "library"), ignore_errors=True)
+    _download_file("multiparts", "library.zip")
     if os.path.exists(os.path.join(EXAMPLES_PATH, "multiparts", "library.zip")):
         unzip(os.path.join(EXAMPLES_PATH, "multiparts", "library.zip"), dest_folder)
     return os.path.join(dest_folder, "library")
