@@ -1,6 +1,6 @@
+# -*- coding: utf-8 -*-
 import re
-from collections import OrderedDict
-
+from pyaedt.generic.general_methods import time_fn
 
 # --------------------------------------------------------------------
 # public interface
@@ -58,6 +58,9 @@ _value_parse1 = re.compile(r"\s")
 _value_parse2 = re.compile(r"^'([^']*\s[^']*)(?=')")
 _begin_search = re.compile(r"\$begin '(.+)'")
 
+# set recognized keywords
+_recognized_keywords = ["CurvesInfo"]
+
 # global variables
 _all_lines = []
 _len_all_lines = 0
@@ -161,7 +164,36 @@ def _decode_value_and_save(k, v, d):
             d[k] = _parse_value(v)
 
 
-def _decode_key(l , d):
+def _decode_recognized_key(keyword, l, d):
+    """Special decodings for keys belonging to  _recognized_keywords
+
+    Parameters
+    ----------
+    keyword : str
+        dictionary key recognized
+
+    l : str
+        Line.
+
+    d : dict
+        Active dictionary.
+
+    -------
+
+    """
+    if keyword == _recognized_keywords[0]:  # 'CurvesInfo'
+        m = re.search(r"\'(\d+)\'\((.*)\)$", l)
+        if m:
+            k = m.group(1)
+            v = m.group(2)
+            v2 = v.replace("\\'", '"')
+            v3 = _separate_list_elements(v2)
+            d[k] = v3
+    else:
+        raise AttributeError("Keyword {} is supposed to be in the recognized_keywords list".format(keyword))
+
+
+def _decode_key(l, d):
     """
 
     Parameters
@@ -197,9 +229,8 @@ def _decode_key(l , d):
             value2 = value.replace("\\'", '"')
         else:
             value2 = value
-        # if there are no spaces in value
+        # if there are no spaces in value   or   values with spaces are between quotes
         if not _value_parse1.search(value2) or _value_parse2.search(value2):
-            # or values with spaces are between quote
             key = m.group("KEY2")
             _decode_value_and_save(key, value, d)
         else:  # spaces in value without quotes
@@ -234,17 +265,17 @@ def _walk_through_structure(keyword, save_dict):
     while _count < _len_all_lines:
         line = _all_lines[_count]
         # begin_key is found
-        if begin_key == line.strip():
+        if begin_key == line:
             found = True
             saved_value = save_dict.get(keyword)  # if the keyword is already present
             # makes the value a list, if it's not already
             if saved_value and type(saved_value) is not list:
                 saved_value = [saved_value]
-            save_dict[keyword] = OrderedDict()
+            save_dict[keyword] = {}
             _count += 1
             continue
         # end_key is found
-        if end_key == line.strip():
+        if end_key == line:
             break
         # between begin_key and end_key
         if found:
@@ -252,6 +283,8 @@ def _walk_through_structure(keyword, save_dict):
             if b:  # walk down a level
                 nextlvl_begin_key = b.group(1)
                 _walk_through_structure(nextlvl_begin_key, save_dict[keyword])
+            elif keyword in _recognized_keywords:
+                _decode_recognized_key(keyword, line, save_dict[keyword])
             else:  # decode key
                 _decode_key(line, save_dict[keyword])
         _count += 1
@@ -284,11 +317,10 @@ def _read_aedt_file(filename):
     ascii_lines = []
     for raw_line in raw_lines:
         try:
-            ascii_lines.append(raw_line.decode("utf-8").lstrip("\t"))
+            ascii_lines.append(raw_line.decode("utf-8").lstrip(" \t"))
         except UnicodeDecodeError:
             continue
     ascii_content = "\n".join(ascii_lines)
-
     # combine subsequent lines when the line ends in \
     _all_lines = ascii_content.replace("\\\n", "").splitlines()
     _len_all_lines = len(_all_lines)
@@ -310,8 +342,8 @@ def _load_entire_aedt_file(filename):
 
     """
     global _count
-    _read_aedt_file(filename)
-    main_dict = OrderedDict()
+    time_fn(_read_aedt_file, filename)
+    main_dict = {}
     # load the aedt file
     while _count < _len_all_lines:
         line = _all_lines[_count]
@@ -340,6 +372,6 @@ def _load_keyword_in_aedt_file(filename, keyword):
     """
     _read_aedt_file(filename)
     # load the aedt file
-    main_dict = OrderedDict()
+    main_dict = {}
     _walk_through_structure(keyword, main_dict)
     return main_dict
