@@ -1,4 +1,5 @@
 import os
+import csv
 import string
 import random
 import time
@@ -11,7 +12,23 @@ from collections import OrderedDict
 import inspect
 import itertools
 
-logger = logging.getLogger(__name__)
+try:
+    logger = logging.getLogger("Global")
+except:
+    logger = logging.getLogger(__name__)
+is_ironpython = "IronPython" in sys.version or ".NETFramework" in sys.version
+_pythonver = sys.version_info[0]
+inside_desktop = True
+import sys
+
+try:
+    import ScriptEnv
+
+    ScriptEnv.Initialize("Ansoft.ElectronicsDesktop")
+except:
+    inside_desktop = False
+
+is_remote_server = os.getenv("PYAEDT_IRONPYTHON_SERVER", "False").lower() in ("true", "1", "t")
 
 
 class MethodNotSupportedError(Exception):
@@ -22,18 +39,13 @@ class MethodNotSupportedError(Exception):
 
 def _write_mes(mes_text):
     mes_text = str(mes_text)
-    parts = [mes_text[i:i + 80] for i in range(0, len(mes_text), 80)]
-
-    if os.getenv("PYAEDT_SCREEN_LOGS", "True").lower() in ("true", "1", "t"):
-        for el in parts:
-            print(el)
-    if logger and os.getenv("PYAEDT_FILE_LOGS", "True").lower() in ("true", "1", "t"):
+    parts = [mes_text[i : i + 250] for i in range(0, len(mes_text), 250)]
+    if logger:
         for el in parts:
             logger.error(el)
-    if (os.getenv("PYAEDT_DESKTOP_LOGS", "True").lower() in ("true", "1", "t")
-            and "oDesktop" in dir(sys.modules["__main__"])):
+    elif os.getenv("PYAEDT_SCREEN_LOGS", "True").lower() in ("true", "1", "t"):
         for el in parts:
-            sys.modules["__main__"].oDesktop.AddMessage("", "", 2, el)
+            print(el)
 
 
 def _exception(ex_info, func, args, kwargs, message="Type Error"):
@@ -56,8 +68,18 @@ def _exception(ex_info, func, args, kwargs, message="Type Error"):
     -------
 
     """
-    _write_mes("**************************************************************")
-    _write_mes("pyaedt Error on Method {}:  {}. Please Check again".format(func.__name__, message))
+    message_to_print = ""
+    if "oDesktop" in dir(sys.modules["__main__"]):
+        try:
+            messages = list(sys.modules["__main__"].oDesktop.GetMessages("", "", 2))
+        except:
+            messages = []
+        if messages and "[error] Script macro error" in messages[-1]:
+            message_to_print = messages[-1]
+    _write_mes("Method {} Failed:  {}. Please Check again".format(func.__name__, message))
+    _write_mes(ex_info[1])
+    if message_to_print:
+        _write_mes(message_to_print)
     _write_mes("Arguments Provided: ")
     try:
         if int(sys.version[0]) > 2:
@@ -80,14 +102,101 @@ def _exception(ex_info, func, args, kwargs, message="Type Error"):
         tblist = tb_trace[0].split("\n")
     for el in tblist:
         if func.__name__ in el:
-            _write_mes("Error in : ")
-            _write_mes(el)
-    _write_mes("")
-    _write_mes("")
-    _write_mes("Check Online documentation on: ")
-    _write_mes("")
-    _write_mes("https://aedtdocs.pyansys.com/search.html?q={}".format(func.__name__))
-    _write_mes("************************************************************")
+            _write_mes("Error in : " + el)
+    _write_mes("Check Online documentation on: https://aedtdocs.pyansys.com/search.html?q={}".format(func.__name__))
+
+
+def _check_types(arg):
+    if "netref.builtins.list" in str(type(arg)):
+        return "list"
+    elif "netref.builtins.dict" in str(type(arg)):
+        return "dict"
+    elif "netref.__builtin__.list" in str(type(arg)):
+        return "list"
+    elif "netref.__builtin__.dict" in str(type(arg)):
+        return "dict"
+    return ""
+
+
+def convert_remote_object(arg):
+    """Convert Remote list or dict to native list and dictionary.
+
+    .. note::
+        This is needed only on Cpython to Ironpython Connection.
+
+    Parameters
+    ----------
+    arg : dict or list
+        Object to convert
+    Returns
+    -------
+    dict or list
+    """
+    if _check_types(arg) == "list":
+        if arg.__len__() > 0:
+            if isinstance(arg[0], (int, float, str, dict)):
+                return list(eval(str(arg)))
+            else:
+                return [arg[i] for i in range(arg.__len__())]
+        else:
+            return []
+    elif _check_types(arg) == "dict":
+        return dict(eval(str(arg)))
+    return arg
+
+
+def _remote_list_conversion(args):
+    if not is_remote_server:
+        return args
+    new_args = []
+    if args:
+        for arg in args:
+            new_args.append(convert_remote_object(arg))
+    return new_args
+
+
+def _remote_dict_conversion(args):
+    if not is_remote_server:
+        return args
+
+    if args:
+        new_kwargs = {}
+        for arg in args:
+            new_kwargs[arg] = convert_remote_object(args[arg])
+    else:
+        new_kwargs = args
+    return new_kwargs
+
+
+def _log_method(func, new_args, new_kwargs):
+    if str(func.__name__)[0] != "_":
+        line_begin = "    Implicit Arguments: "
+        line_begin2 = "    Explicit Arguments: "
+        message = []
+        if new_args:
+            object_name = str([new_args[0]])[1:-1]
+            id = object_name.find(" object at ")
+            if id >= 0:
+                object_name = object_name[1:id]
+                message.append(" '{}' has been exectuted.".format(object_name + "." + str(func.__name__)))
+                if new_args[1:]:
+                    message.append(line_begin + str(new_args[1:])[1:-1])
+                if new_kwargs:
+                    message.append(line_begin2 + str(new_kwargs)[1:-1])
+
+            else:
+                message.append(" '{}' has been exectuted.".format(str(func.__name__)))
+                if new_args[1:]:
+                    message.append(line_begin + str(new_args[1:])[1:-1])
+                if new_kwargs:
+                    message.append(line_begin2 + str(new_kwargs)[1:-1])
+
+        else:
+            message.append(" '{}' has been exectuted".format(str(func.__name__)))
+            if new_kwargs:
+                message.append(line_begin2 + str(new_kwargs)[1:-1])
+        for m in message:
+            logger.debug(m)
 
 
 def aedt_exception_handler(func):
@@ -109,9 +218,14 @@ def aedt_exception_handler(func):
     def inner_function(*args, **kwargs):
         if os.getenv("PYAEDT_ERROR_HANDLER", "True").lower() in ("true", "1", "t"):
             try:
-                return func(*args, **kwargs)
+                new_args = _remote_list_conversion(args)
+                new_kwargs = _remote_dict_conversion(kwargs)
+                out = func(*new_args, **new_kwargs)
+                _log_method(func, new_args, new_kwargs)
+                return out
             except TypeError:
-                _exception(sys.exc_info(), func, args, kwargs, "Type Error")
+                if not is_remote_server:
+                    _exception(sys.exc_info(), func, args, kwargs, "Type Error")
                 return False
             except ValueError:
                 _exception(sys.exc_info(), func, args, kwargs, "Value Error")
@@ -123,8 +237,9 @@ def aedt_exception_handler(func):
                 _exception(sys.exc_info(), func, args, kwargs, "Key Error")
                 return False
             except IndexError:
-                _exception(sys.exc_info(), func, args, kwargs, "Index Error")
-                return False
+                if not is_remote_server:
+                    _exception(sys.exc_info(), func, args, kwargs, "Index Error")
+                    return False
             except AssertionError:
                 _exception(sys.exc_info(), func, args, kwargs, "Assertion Error")
                 return False
@@ -138,7 +253,7 @@ def aedt_exception_handler(func):
                 message = "This Method is not supported in current AEDT Design Type."
                 if os.getenv("PYAEDT_SCREEN_LOGS", "True").lower() in ("true", "1", "t"):
                     print("**************************************************************")
-                    print("pyaedt Error on Method {}:  {}. Please Check again".format(func.__name__, message))
+                    print("pyaedt error on Method {}:  {}. Please Check again".format(func.__name__, message))
                     print("**************************************************************")
                     print("")
                 if os.getenv("PYAEDT_FILE_LOGS", "True").lower() in ("true", "1", "t"):
@@ -146,6 +261,7 @@ def aedt_exception_handler(func):
                 return False
             except BaseException:
                 _exception(sys.exc_info(), func, args, kwargs, "General or AEDT Error")
+
                 return False
         else:
             return func(*args, **kwargs)
@@ -154,18 +270,7 @@ def aedt_exception_handler(func):
 
 
 @aedt_exception_handler
-def env_path(input_version):
-    """
-
-    Parameters
-    ----------
-    input_version :
-
-
-    Returns
-    -------
-
-    """
+def get_version_and_release(input_version):
     version = int(input_version[2:4])
     release = int(input_version[5])
     if version < 20:
@@ -173,95 +278,106 @@ def env_path(input_version):
             version -= 1
         else:
             release -= 2
-    v_key = "ANSYSEM_ROOT{0}{1}".format(version, release)
-    return os.getenv(v_key)
+    return (version, release)
+
+
+@aedt_exception_handler
+def env_path(input_version):
+    """Return the version Environment Variable name based on an input version string.
+
+    Parameters
+    ----------
+    input_version : str
+
+    Returns
+    -------
+    str
+
+    Examples
+    --------
+    >>> env_path_student("2021.2")
+    "C:/Program Files/ANSYSEM/ANSYSEM2021.2/Win64"
+    """
+    return os.getenv(
+        "ANSYSEM_ROOT{0}{1}".format(
+            get_version_and_release(input_version)[0], get_version_and_release(input_version)[1]
+        ),
+        "",
+    )
 
 
 @aedt_exception_handler
 def env_value(input_version):
-    """
+    """Return the version Environment Variable value based on an input version string.
 
     Parameters
     ----------
-    input_version :
-
+    input_version : str
 
     Returns
     -------
+    str
 
+    Examples
+    --------
+    >>> env_value("2021.2")
+    "ANSYSEM_ROOT211"
     """
-    version = int(input_version[2:4])
-    release = int(input_version[5])
-    if version < 20:
-        if release < 3:
-            version -= 1
-        else:
-            release -= 2
-    v_key = "ANSYSEM_ROOT{0}{1}".format(version, release)
-    return v_key
+    return "ANSYSEM_ROOT{0}{1}".format(
+        get_version_and_release(input_version)[0], get_version_and_release(input_version)[1]
+    )
 
 
 @aedt_exception_handler
 def env_path_student(input_version):
-    """Return the Student version Environment Variable value based on an input version string
+    """Return the Student version Environment Variable value based on an input version string.
 
     Parameters
     ----------
     input_version : str
 
-
     Returns
     -------
     str
 
     Examples
     --------
-    >>> env_path_student("2021.1")
-    "C:/Program Files/ANSYSEM/ANSYSEM2021.1/Win64"
+    >>> env_path_student("2021.2")
+    "C:/Program Files/ANSYSEM/ANSYSEM2021.2/Win64"
     """
-    version = int(input_version[2:4])
-    release = int(input_version[5])
-    if version < 20:
-        if release < 3:
-            version -= 1
-        else:
-            release -= 2
-    v_key = "ANSYSEMSV_ROOT{0}{1}".format(version, release)
-    return os.getenv(v_key)
+    return os.getenv(
+        "ANSYSEMSV_ROOT{0}{1}".format(
+            get_version_and_release(input_version)[0], get_version_and_release(input_version)[1]
+        ),
+        "",
+    )
 
 
 @aedt_exception_handler
 def env_value_student(input_version):
-    """Return the Student version Environment Variable name based on an input version string
+    """Return the Student version Environment Variable name based on an input version string.
 
     Parameters
     ----------
     input_version : str
 
-
     Returns
     -------
     str
 
     Examples
     --------
-    >>> env_value_student("2021.1")
+    >>> env_value_student("2021.2")
     "ANSYSEMSV_ROOT211"
     """
-    version = int(input_version[2:4])
-    release = int(input_version[5])
-    if version < 20:
-        if release < 3:
-            version -= 1
-        else:
-            release -= 2
-    v_key = "ANSYSEMSV_ROOT{0}{1}".format(version, release)
-    return v_key
+    return "ANSYSEMSV_ROOT{0}{1}".format(
+        get_version_and_release(input_version)[0], get_version_and_release(input_version)[1]
+    )
 
 
 @aedt_exception_handler
 def get_filename_without_extension(path):
-    """
+    """Get the filename without its extension.
 
     Parameters
     ----------
@@ -270,6 +386,7 @@ def get_filename_without_extension(path):
 
     Returns
     -------
+    str
 
     """
     return os.path.splitext(os.path.split(path)[1])[0]
@@ -277,7 +394,7 @@ def get_filename_without_extension(path):
 
 @aedt_exception_handler
 def generate_unique_name(rootname, suffix="", n=6):
-    """Generate a new Random name given a rootname and, optionally a suffix
+    """Generate a new  name given a rootname and optionally a suffix.
 
     Parameters
     ----------
@@ -286,7 +403,7 @@ def generate_unique_name(rootname, suffix="", n=6):
     suffix :
         Suffix to be added (Default value = '')
     n :
-        Number of random characters in the name, defaults to 6
+        Number of random characters in the name. The default value is 6.
 
     Returns
     -------
@@ -300,7 +417,7 @@ def generate_unique_name(rootname, suffix="", n=6):
     return unique_name
 
 
-def retry_ntimes(n, function, *args, **kwargs):
+def _retry_ntimes(n, function, *args, **kwargs):
     """
 
     Parameters
@@ -365,3 +482,52 @@ def is_number(a):
     else:
         return False
     # return str(a).replace(".", "").replace("+", "").replace("-", "").replace("e","").replace("E","").isnumeric()
+
+
+def is_project_locked(project_path):
+    """Checks if an aedt project lock file exists.
+
+    Parameters
+    ----------
+    project_path : str
+        Aedt project path.
+
+    Returns
+    -------
+    bool
+    """
+    return os.path.exists(project_path[:-4] + "lock")
+
+
+@aedt_exception_handler
+def remove_project_lock(project_path):
+    """Checks if an aedt project exists and try to remove the lock file.
+
+    .. note::
+       This operation is risky because the file could be opened in another Desktop instance.
+
+    Parameters
+    ----------
+    project_path : str
+        Aedt project path.
+
+    Returns
+    -------
+    bool
+    """
+    if os.path.exists(project_path + ".lock"):
+        os.remove(project_path + ".lock")
+    return True
+
+
+@aedt_exception_handler
+def write_csv(output, list_data, delimiter=",", quotechar="|", quoting=csv.QUOTE_MINIMAL):
+    if is_ironpython:
+        f = open(output, "wb")
+    else:
+        f = open(output, "w", newline="")
+    writer = csv.writer(f, delimiter=delimiter, quotechar=quotechar, quoting=quoting)
+    for data in list_data:
+        writer.writerow(data)
+    f.close()
+    return True
