@@ -5,8 +5,8 @@ from __future__ import absolute_import
 import os
 import warnings
 
-from .application.Analysis3DLayout import FieldAnalysis3DLayout
-from .generic.general_methods import aedt_exception_handler, generate_unique_name
+from pyaedt.application.Analysis3DLayout import FieldAnalysis3DLayout
+from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name
 
 
 class Hfss3dLayout(FieldAnalysis3DLayout):
@@ -36,7 +36,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
     specified_version : str, optional
         Version of AEDT to use. The default is ``None``, in which case
         the active version or latest installed version is used.
-    NG : bool, optional
+    non_graphical : bool, optional
         Whether to launch AEDT in the non-graphical mode. The default
         is``False``, in which case AEDT is launched in the graphical mode.
     new_desktop_session : bool, optional
@@ -74,7 +74,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
     Create an AEDT 2021 R1 object and then create a
     `Hfss3dLayout` object and open the specified project.
 
-    >>> aedtapp = Hfss3dLayout(specified_version="2021.1", projectname="myfile.aedt")
+    >>> aedtapp = Hfss3dLayout(specified_version="2021.2", projectname="myfile.aedt")
 
     """
 
@@ -125,6 +125,10 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         type
             Name of the port when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.CreateEdgePort
         """
         listp = self.port_list
         self.modeler.oeditor.CreateEdgePort(
@@ -145,6 +149,54 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         else:
             return False
 
+    @aedt_exception_handler
+    def create_wave_port_from_two_conductors(self, primivitivenames=[""], edgenumbers=[""]):
+        """Create a wave port.
+
+        Parameters
+        ----------
+        primivitivenames : list(str)
+            List of the of the primitive name to create the wave port on.
+            The list length must be 2 e.g. for the two conductors or the command will not be executed.
+
+        edgenumbers :
+            List of the edge number to create the wave port on.
+            The list length must be 2 e.g. for the two edges or the command will not be executed.
+
+        Returns
+        -------
+        type
+            Name of the port when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oEditor.CreateEdgePort
+        """
+        if len(primivitivenames) == 2 and len(edgenumbers) == 2:
+            listp = self.port_list
+            self.modeler.oeditor.CreateEdgePort(
+                [
+                    "NAME:Contents",
+                    "edge:=",
+                    ["et:=", "pe", "prim:=", primivitivenames[0], "edge:=", edgenumbers[0]],
+                    "edge:=",
+                    ["et:=", "pe", "prim:=", primivitivenames[1], "edge:=", edgenumbers[1]],
+                    "external:=",
+                    True,
+                    "btype:=",
+                    0,
+                ]
+            )
+            listnew = self.port_list
+            a = [i for i in listnew if i not in listp]
+            if len(a) > 0:
+                return a[0]
+            else:
+                return False
+        else:
+            return False
+
     @aedt_exception_handler
     def create_coax_port(self, vianame, layer, xstart, xend, ystart, yend, archeight=0, arcrad=0, isexternal=True):
         """Create a new coax port.
@@ -175,9 +227,13 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         str
             Name of the port when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.CreateEdgePort
         """
         listp = self.port_list
-        if type(layer) is str:
+        if isinstance(layer, str):
             layerid = self.modeler.layers.layer_id(layer)
         else:
             layerid = layer
@@ -242,6 +298,10 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.CreatePin
         """
         self.modeler.layers.refresh_all_layers()
         layers = self.modeler.layers.all_signal_layers
@@ -287,6 +347,10 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.Delete
         """
         self.oexcitation.Delete(portname)
         return True
@@ -305,9 +369,12 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.ImportEDB
         """
-        oTool = self.odesktop.GetTool("ImportExport")
-        oTool.ImportEDB(edb_full_path)
+        self.oimport_export.ImportEDB(edb_full_path)
         self.oproject = self.odesktop.GetActiveProject().GetName()
         self.odesign = self.odesktop.GetActiveProject().GetActiveDesign().GetName().split(";")[1]
         return True
@@ -321,22 +388,28 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         name : str, optional
             Name of the design to validate. The default is ``None``.
         outputdir : str, optional
-            Output directory to save the log file to. The default is ``None``.
+            Output directory to save the log file to.
+            The default is ``None`` which export file in working_directory.
+
         ports : str, optional
             Number of excitations that are expected. The default is ``None``.
 
         Returns
         -------
-        list
+        list of str
             List of validation messages.
 
+        References
+        ----------
+
+        >>> oDesign.ValidateDesign
         """
         if name is None:
             name = self.design_name
         if outputdir is None:
-            outputdir = self.project_path
+            outputdir = self.working_directory
 
-        self._messenger.add_info_message("#### Design Validation Checks###")
+        self.logger.info("#### Design Validation Checks###")
         #
         # Routine outputs to the validation info to a log file in the project directory and also
         # returns the validation info to be used to update properties.xml file
@@ -355,10 +428,10 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             msg = "Desktop Messages:"
             validation.writelines(msg + "\n")
             val_list.append(msg)
-            msgs = self._desktop.GetMessages(name, "HFSSDesign1", 0)
+            msgs = self._desktop.GetMessages(self.project_name, name, 0)
             # need to check if design name is always this default name HFSSDesign1
             for msg in msgs:
-                self._messenger.add_info_message(msg)
+                self.logger.info(msg)
                 # msg = msg.replace('"','')
                 msg = msg.rstrip("\r\n")
                 val_list.append(msg)
@@ -372,10 +445,10 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             val_list.append(msg)
             if ret == 0:
                 msg = "**** ERRORS Present - please check and confirm"
-                self._messenger.add_error_message(msg)
+                self.logger.error(msg)
             else:
                 msg = "**** Validation Completed Correctly"
-                self._messenger.add_info_message(msg)
+                self.logger.info(msg)
 
             # Find the Excitations and check or list them out
             msg = "Excitation Messages:"
@@ -384,7 +457,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             numportsdefined = int(len(self.get_excitations_name))
             if ports is not None and ports != numportsdefined:
                 msg = "**** Port Number Error! - Please check model"
-                self._messenger.add_error_message(msg)
+                self.logger.error(msg)
                 validation.writelines(msg + "\n")
                 val_list.append(msg)
                 validation_ok = False
@@ -392,17 +465,17 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             else:
                 msg1 = "Ports Requested: " + str(ports)
                 msg2 = "Ports Defined: " + str(numportsdefined)
-                self._messenger.add_info_message(msg1)
+                self.logger.info(msg1)
                 validation.writelines(msg1 + "\n")
                 val_list.append(msg1)
-                self._messenger.add_info_message(msg2)
+                self.logger.info(msg2)
                 validation.writelines(msg2 + "\n")
                 val_list.append(msg2)
 
             excitation_names = self.get_excitations_name
             for excitation in excitation_names:
                 msg = "Excitation name: " + str(excitation)
-                self._messenger.add_info_message(msg)
+                self.logger.info(msg)
                 validation.writelines(msg + "\n")
                 val_list.append(msg)
         validation.close()
@@ -432,6 +505,10 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.CreateReport
         """
         Families = ["Freq:=", ["All"]]
         if variations:
@@ -451,9 +528,9 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             ["dB(S(" + p + "," + q + "))" for p, q in zip(list(port_names), list(port_excited))],
         ]
         solution_data = ""
-        if self.solution_type == "DrivenModal":
+        if "Modal" in self.solution_type:
             solution_data = "Modal Solution Data"
-        elif self.solution_type == "DrivenTerminal":
+        elif "Terminal" in self.solution_type:
             solution_data = "Terminal Solution Data"
         elif self.solution_type == "HFSS3DLayout":
             solution_data = "Standard"
@@ -478,6 +555,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             Name of the sweep that has been solved.
         filename : str
             Full path for the Touchstone file.
+            The default is ``None`` which export file in working_directory.
         variation : list
             List of all parameter variations, such  as ``["$AmbientTemp", "$PowerIn"]``.
         variations_value : list
@@ -488,6 +566,10 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oDesign.ExportNetworkData
         """
         # normalize the save path
         if not filename:
@@ -495,7 +577,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             for v, vv in zip(variation, variations_value):
                 appendix += "_" + v + vv.replace("'", "")
             ext = ".S" + str(len(self.port_list)) + "p"
-            filename = os.path.join(self.project_path, solutionname + "_" + sweepname + appendix + ext)
+            filename = os.path.join(self.working_directory, solutionname + "_" + sweepname + appendix + ext)
         else:
             filename = filename.replace("//", "/").replace("\\", "/")
         print("Exporting Touchstone " + filename)
@@ -553,6 +635,10 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oDesign.DesignOptions
         """
         settings = []
         if activate:
@@ -577,7 +663,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         freqstop,
         num_of_freq_points,
         sweepname=None,
-        sweeptype="interpolating",
+        sweeptype="Interpolating",
         interpolation_tol_percent=0.5,
         interpolation_max_solutions=250,
         save_fields=True,
@@ -597,24 +683,24 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         )
         if sweeptype == "interpolating":
             sweeptype = "Interpolating"
-        elif sweeptype == 'discrete':
+        elif sweeptype == "discrete":
             sweeptype = "Discrete"
-        elif sweeptype == 'fast':
+        elif sweeptype == "fast":
             sweeptype = "Fast"
 
         return self.create_linear_count_sweep(
-                setupname=setupname,
-                unit=unit,
-                freqstart=freqstart,
-                freqstop=freqstop,
-                num_of_freq_points=num_of_freq_points,
-                sweepname=sweepname,
-                save_fields=save_fields,
-                save_rad_fields_only=save_rad_fields_only,
-                sweep_type=sweeptype,
-                interpolation_tol_percent=interpolation_tol_percent,
-                interpolation_max_solutions=interpolation_max_solutions,
-                use_q3d_for_dc=use_q3d_for_dc,
+            setupname=setupname,
+            unit=unit,
+            freqstart=freqstart,
+            freqstop=freqstop,
+            num_of_freq_points=num_of_freq_points,
+            sweepname=sweepname,
+            save_fields=save_fields,
+            save_rad_fields_only=save_rad_fields_only,
+            sweep_type=sweeptype,
+            interpolation_tol_percent=interpolation_tol_percent,
+            interpolation_max_solutions=interpolation_max_solutions,
+            use_q3d_for_dc=use_q3d_for_dc,
         )
 
     @aedt_exception_handler
@@ -673,6 +759,10 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         :class:`pyaedt.modules.SetupTemplates.SweepHFSS3DLayout` or bool
             Sweep object if successful, ``False`` otherwise.
 
+        References
+        ----------
+
+        >>> oModule.AddSweep
         """
         if sweep_type not in ["Discrete", "Interpolating", "Fast"]:
             raise AttributeError("Invalid in `sweep_type`. It has to be either 'Discrete', 'Interpolating', or 'Fast'")
@@ -695,10 +785,12 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
                 if sweepname in [sweep.name for sweep in setupdata.sweeps]:
                     oldname = sweepname
                     sweepname = generate_unique_name(oldname)
-                    self._messenger.add_warning_message(
-                        "Sweep {} is already present. Sweep has been renamed in {}.".format(oldname, sweepname)
+                    self.logger.warning(
+                        "Sweep %s is already present. Sweep has been renamed in %s.", oldname, sweepname
                     )
                 sweep = setupdata.add_sweep(sweepname=sweepname)
+                if not sweep:
+                    return False
                 sweep.change_range("LinearCount", freqstart, freqstop, num_of_freq_points, unit)
                 sweep.props["GenerateSurfaceCurrent"] = save_fields
                 sweep.props["SaveRadFieldsOnly"] = save_rad_fields_only
@@ -708,7 +800,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
                 sweep.props["UseQ3DForDC"] = use_q3d_for_dc
                 sweep.props["MaxSolutions"] = interpolation_max_solutions
                 sweep.update()
-                self.add_info_message("Linear count sweep {} has been correctly created".format(sweepname))
+                self.logger.info("Linear count sweep %s has been correctly created", sweepname)
                 return sweep
         return False
 
@@ -768,6 +860,10 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         :class:`pyaedt.modules.SetupTemplates.SweepHFSS3DLayout` or bool
             Sweep object if successful, ``False`` otherwise.
 
+        References
+        ----------
+
+        >>> oModule.AddSweep
         """
         if sweep_type not in ["Discrete", "Interpolating", "Fast"]:
             raise AttributeError("Invalid in `sweep_type`. It has to be either 'Discrete', 'Interpolating', or 'Fast'")
@@ -790,10 +886,12 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
                 if sweepname in [sweep.name for sweep in setupdata.sweeps]:
                     oldname = sweepname
                     sweepname = generate_unique_name(oldname)
-                    self._messenger.add_warning_message(
-                        "Sweep {} is already present. Sweep has been renamed in {}.".format(oldname, sweepname)
+                    self.logger.warning(
+                        "Sweep %s is already present. Sweep has been renamed in %s.", oldname, sweepname
                     )
                 sweep = setupdata.add_sweep(sweepname=sweepname)
+                if not sweep:
+                    return False
                 sweep.change_range("LinearStep", freqstart, freqstop, step_size, unit)
                 sweep.props["GenerateSurfaceCurrent"] = save_fields
                 sweep.props["SaveRadFieldsOnly"] = save_rad_fields_only
@@ -803,7 +901,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
                 sweep.props["UseQ3DForDC"] = use_q3d_for_dc
                 sweep.props["MaxSolutions"] = interpolation_max_solutions
                 sweep.update()
-                self.add_info_message("Linear step sweep {} has been correctly created".format(sweepname))
+                self.logger.info("Linear step sweep %s has been correctly created", sweepname)
                 return sweep
         return False
 
@@ -838,6 +936,11 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         -------
         :class:`pyaedt.modules.SetupTemplates.SweepHFSS` or bool
             Sweep object if successful, ``False`` otherwise.
+
+        References
+        ----------
+
+        >>> oModule.AddSweep
         """
         if sweepname is None:
             sweepname = generate_unique_name("SinglePoint")
@@ -860,8 +963,8 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
                 if sweepname in [sweep.name for sweep in setupdata.sweeps]:
                     oldname = sweepname
                     sweepname = generate_unique_name(oldname)
-                    self._messenger.add_warning_message(
-                        "Sweep {} is already present. Sweep has been renamed in {}.".format(oldname, sweepname)
+                    self.logger.warning(
+                        "Sweep %s is already present. Sweep has been renamed in %s.", oldname, sweepname
                     )
                 sweepdata = setupdata.add_sweep(sweepname, "Discrete")
                 sweepdata.change_range("SinglePoint", freq0, unit=unit)
@@ -871,7 +974,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
                 if add_subranges:
                     for f in freq:
                         sweepdata.add_subrange(rangetype="SinglePoint", start=f, unit=unit)
-                self.add_info_message("Single point sweep {} has been correctly created".format(sweepname))
+                self.logger.info("Single point sweep %s has been correctly created", sweepname)
                 return sweepdata
         return False
 
@@ -898,6 +1001,11 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.ImportGDSII
+        >>> oEditor.ImportStackupXML
         """
         active_project = self.project_name
         project_name = os.path.basename(gds_path)[:-4]
@@ -907,15 +1015,15 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
             old_name = project_name
             project_name = generate_unique_name(project_name)
             aedb_path = gds_path.replace(old_name + ".gds", project_name + ".aedb")
-            self._messenger.add_warning_message("aedb_exists. Renaming it to {}".format(project_name))
+            self.logger.warning("aedb_exists. Renaming it to %s", project_name)
 
-        oTool = self.odesktop.GetTool("ImportExport")
-        oTool.ImportGDSII(gds_path, aedb_path, "", "")
+        self.oimport_export.ImportGDSII(gds_path, aedb_path, "", "")
         project = self.odesktop.SetActiveProject(project_name)
         oeditor = project.GetActiveDesign().SetActiveEditor("Layout")
         if xml_path:
             oeditor.ImportStackupXML(xml_path)
         if set_as_active:
+            self._close_edb()
             self.__init__(project_name)
         if close_active_project:
             self.odesktop.CloseProject(active_project)
@@ -965,6 +1073,11 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
         bool
             ``True`` if successful and ``False`` if failed.
 
+        References
+        ----------
+
+        >>> oDesign.EditCoSimulationOptions
+
         Examples
         --------
         >>> from pyaedt import Hfss3dLayout
@@ -983,7 +1096,7 @@ class Hfss3dLayout(FieldAnalysis3DLayout):
 
         """
         if interpolation_algorithm not in ["auto", "lin", "shadH", "shadNH"]:
-            self.add_error_message("Wrong Interpolation Algorithm")
+            self.logger.error("Wrong Interpolation Algorithm")
             return False
         arg = ["NAME:CoSimOptions", "Override:="]
 
