@@ -4,88 +4,69 @@ from __future__ import absolute_import
 import os
 import json
 import io
-from .application.Analysis2D import FieldAnalysis2D
-from .application.Analysis3D import FieldAnalysis3D
-from .generic.DataHandlers import float_units
-from .generic.general_methods import generate_unique_name, aedt_exception_handler
-from .modules.Boundary import BoundaryObject
+from pyaedt.application.Analysis2D import FieldAnalysis2D
+from pyaedt.application.Analysis3D import FieldAnalysis3D
+from pyaedt.generic.DataHandlers import float_units
+from pyaedt.generic.general_methods import generate_unique_name, aedt_exception_handler
+from pyaedt.modules.Boundary import BoundaryObject
 from collections import OrderedDict
+from pyaedt.modeler.GeometryOperators import GeometryOperators
+from pyaedt.generic.constants import SOLUTIONS
 
 
 class Maxwell(object):
-    """Contains all methods that are common to both Maxwell 2D and Maxwell 3D.
-
-    Parameters
-    ----------
-    projectname : str, optional
-        Name of the project to select or the full path to the project
-        or AEDTZ archive to open. The default is ``None``, in which
-        case an attempt is made to get an active project. If no
-        projects are present, an empty project is created.
-    designname : str, optional
-        Name of the design to select. The default is ``None``, in
-        which case an attempt is made to get an active design. If no
-        designs are present, an empty design is created.
-    solution_type : str, optional
-        Solution type to apply to the design. The default is
-        ``None``, in which case the default type is applied.
-    setup_name : str, optional
-        Name of the setup to use as the nominal. The default is
-        ``None``, in which case the active setup is used or
-        nothing is used.
-    specified_version : str, optional
-        Version of AEDT to use. The default is ``None``, in which case
-        the active version or latest installed version is used. This
-        parameter is ignored when Script is launched within AEDT.
-    NG : bool, optional
-        Whether to launch AEDT in the non-graphical mode. The default
-        is ``False``, in which case AEDT is launched in the graphical
-        mode. This parameter is ignored when Script is launched within
-        AEDT.
-    new_desktop_session : bool, optional
-        Whether to launch an instance of AEDT in a new thread, even if
-        another instance of the ``specified_version`` is active on the
-        machine. The default is ``True``. This parameter is ignored
-        when Script is launched within AEDT.
-    close_on_exit : bool, optional
-        Whether to release AEDT on exit. The default is ``False``.
-    student_version : bool, optional
-        Whether to open the AEDT student version. The default is
-        ``False``. This parameter is ignored when Script is launched
-        within AEDT.
-
-    """
-
     def __init__(self):
+        self._odefinition_manager = self.materials.odefinition_manager
+        self._omaterial_manager = self.materials.omaterial_manager
+        self._o_maxwell_parameters = self.odesign.GetModule("MaxwellParameterSetup")
         pass
 
     @property
-    def odefinition_manager(self):
-        """Definition manager."""
-        return self.oproject.GetDefinitionManager()
+    def o_maxwell_parameters(self):
+        """AEDT MaxwellParameterSetup Object.
+
+        References
+        ----------
+
+        >>> oDesign.GetModule("MaxwellParameterSetup")
+        """
+        return self._o_maxwell_parameters
 
     @property
-    def omaterial_manager(self):
-        """Material manager."""
-        return self.odefinition_manager.GetManager("Material")
+    def omodelsetup(self):
+        """AEDT Model Setup Object.
+
+        References
+        ----------
+
+        >>> oDesign.GetModule("ModelSetup")
+        """
+        if self.solution_type != "Transient":
+            return None
+        else:
+            return self._odesign.GetModule("ModelSetup")
 
     @property
     def symmetry_multiplier(self):
-        """Symmetry multiplier."""
-        omodule = self._odesign.GetModule("ModelSetup")
-        return int(omodule.GetSymmetryMultiplier())
+        """Symmetry multiplier.
+
+        References
+        ----------
+
+        >>> oModule.GetSymmetryMultiplier()
+        """
+        return int(self.omodelsetup.GetSymmetryMultiplier())
 
     @property
     def windings(self):
-        """Windings."""
-        oModule = self.odesign.GetModule("BoundarySetup")
-        windings = oModule.GetExcitationsOfType("Winding Group")
-        return list(windings)
+        """Windings.
 
-    @property
-    def o_maxwell_parameters(self):
-        """Maxwell parameters."""
-        return self.odesign.GetModule("MaxwellParameterSetup")
+        References
+        ----------
+
+        >>> oModule.GetExcitationsOfType("Winding Group")"""
+        windings = self.oboundary.GetExcitationsOfType("Winding Group")
+        return list(windings)
 
     @property
     def design_file(self):
@@ -93,6 +74,116 @@ class Maxwell(object):
         design_file = os.path.join(self.working_directory, "design_data.json")
         return design_file
 
+    @aedt_exception_handler
+    def change_inductance_computation(self, compute_transient_inductance=True, incremental_matrix=False):
+        """Enable the inductance computation (for Transient Analysis) and sets the incremental_matrix.
+
+        Parameters
+        ----------
+        compute_transient_inductance : bool
+            Enable or disable the Inductance Calculation for Transient Analysis.
+        incremental_matrix : bool
+            Set the Inductance Calculation to Incremental if ``True``.
+
+        Returns
+        -------
+        bool
+
+        References
+        ----------
+
+        >>> oDesign.SetDesignSettings
+        """
+        self.odesign.SetDesignSettings(
+            [
+                "NAME:Design Settings Data",
+                "ComputeTransientInductance:=",
+                compute_transient_inductance,
+                "ComputeIncrementalMatrix:=",
+                incremental_matrix,
+            ]
+        )
+        return True
+
+    @aedt_exception_handler
+    def set_core_losses(self, objects, value=True):
+        """Enable/Disable core losses for a set of objects.
+        It works only on `EddyCurrent` and `Transient` solutions.
+
+        Parameters
+        ----------
+        objects : list, str
+            List of object to apply core losses to.
+        value : bool
+            Either to enable or disable core losses for given list.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oModule.SetCoreLoss
+
+        Examples
+        --------
+        Set Core Losses in Maxwell 3d.
+
+        >>> from pyaedt import Maxwell3d
+        >>> maxwell_3d = Maxwell3d()
+        >>> maxwell_3d.set_core_losses(["PQ_Core_Bottom", "PQ_Core_Top"], True)
+
+        """
+        if self.solution_type in ["EddyCurrent", "Transient"]:
+            objects = self.modeler.convert_to_selections(objects, True)
+            self.oboundary.SetCoreLoss(objects, value)
+            return True
+        else:
+            raise Exception("Core losses is only available with `EddyCurrent` and `Transient` solutions.")
+        return False
+
+    @aedt_exception_handler
+    def assign_matrix(self, objects, matrix_name=None):
+        """Assign a Matrix to the selection.
+
+        Parameters
+        ----------
+        objects : list, str
+            List of objects to apply core losses.
+        matrix_name : str, optional
+            Boundary condition name.
+
+        Returns
+        -------
+        str
+            The matrix name when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oModule.AssignMatrix
+
+        Examples
+        --------
+        Set Matrix in Maxwell 3d analysis.
+
+        >>> from pyaedt import Maxwell3d
+        >>> maxwell_3d = Maxwell3d()
+        >>> maxwell_3d.assign_matrix(["pri", "sec"])
+        """
+        if self.solution_type in ["EddyCurrent", "Magnetostatic"]:
+            objects = self.modeler._convert_list_to_ids(objects, True)
+            if not matrix_name:
+                matrix_name = generate_unique_name("Matrix")
+            args = ["NAME:" + matrix_name, ["NAME:MatrixEntry"]]
+            for object in objects:
+                args[1].append(["NAME:MatrixEntry", "Source:=", object])
+            self.o_maxwell_parameters.AssignMatrix(args)
+            return matrix_name
+        return False
+
     @aedt_exception_handler
     def setup_ctrlprog(
         self, setupname, file_str=None, keep_modifications=False, python_interpreter=None, aedt_lib_dir=None
@@ -107,10 +198,10 @@ class Maxwell(object):
             Name of the file. The default value is ``None``.
         keep_modifications : bool, optional
             Whether to save the changes. The default value is ``False``.
-        python_interpreter : bool, optional
+        python_interpreter : str, optional
              The default value is ``None``.
         aedt_lib_dir : str, optional
-             Full path to the ``AEDTLib`` directory. The default value is ``None``.
+             Full path to the ``PyAEDT`` directory. The default value is ``None``.
 
         Returns
         -------
@@ -150,7 +241,7 @@ class Maxwell(object):
                     fo.write(file_str)
                 assert os.path.exists(ctl_file), "Control Program file could not be created."
 
-        self.oanalysis_setup.EditSetup(
+        self.oanalysis.EditSetup(
             setupname,
             [
                 "NAME:" + setupname,
@@ -186,6 +277,10 @@ class Maxwell(object):
         bool
             ``True`` when successful and ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.SetEddyEffect
         """
         EddyVector = ["NAME:EddyEffectVector"]
         for obj in object_list:
@@ -204,7 +299,7 @@ class Maxwell(object):
         object_list : list
             List of objects to assign the current source to.
         amplitude : float, optional
-            Voltage amplitude in mV. The default is ``1``.
+            Current amplitude in mA. The default is ``1``.
         phase : str, optional
             The default is ``"0deg"``.
         solid : bool, optional
@@ -219,8 +314,14 @@ class Maxwell(object):
         :class:`pyaedt.modules.Boundary.BoundaryObject`
             Boundary object.
 
+        References
+        ----------
+
+        >>> oModule.AssignCurrent
         """
-        amplitude = str(amplitude) + "A"
+
+        if isinstance(amplitude, (int, float)):
+            amplitude = str(amplitude) + "A"
 
         if not name:
             name = generate_unique_name("Current")
@@ -232,8 +333,6 @@ class Maxwell(object):
                     {
                         "Faces": object_list,
                         "Current": amplitude,
-                        "IsSolid": solid,
-                        "Point out of terminal": swap_direction,
                     }
                 )
             else:
@@ -241,20 +340,206 @@ class Maxwell(object):
                     {
                         "Objects": object_list,
                         "Current": amplitude,
-                        "Phase": phase,
-                        "IsSolid": solid,
-                        "Point out of terminal": swap_direction,
                     }
                 )
+            if self.solution_type not in ["Magnetostatic", "DCConduction", "ElectricTransient"]:
+                props["Phase"] = phase
+                if self.solution_type not in ["DCConduction", "ElectricTransient"]:
+                    props["IsSolid"] = solid
+            props["Point out of terminal"] = swap_direction
         else:
             if type(object_list[0]) is str:
                 props = OrderedDict({"Objects": object_list, "Current": amplitude, "IsPositive": swap_direction})
             else:
-                self._messenger.add_warning_message("Input has to be a 2D Object")
+                self.logger.warning("Input has to be a 2D Object.")
                 return False
         bound = BoundaryObject(self, name, props, "Current")
         if bound.create():
+            self.boundaries.append(bound)
+            return bound
+        return False
 
+    @aedt_exception_handler
+    def assign_translate_motion(
+        self,
+        band_object,
+        coordinate_system="Global",
+        axis="Z",
+        positive_movement=True,
+        start_position=0,
+        periodic_translate=True,
+        negative_limit=0,
+        positive_limit=0,
+        velocity=0,
+        mechanical_transient=False,
+        mass=1,
+        damping=0,
+        load_force=0,
+        motion_name=None,
+    ):
+        """Assign a Translation Motion to an object container.
+
+        Parameters
+        ----------
+        band_object : str,
+            Object container.
+        coordinate_system : str, optional
+            Coordinate System Name. Default is ``"Global``.
+        axis :str or int, optional
+            Coordinate System Axis. Default is ``"Z"``.
+            It can be a ``pyaedt.generic.constants.AXIS`` Enumerator value.
+        positive_movement : bool, Optional
+            Either if movement is Positive or not. Default is ``True``.
+        start_position : float or str, optional
+            Movement Start Position. If float, default modeler units will be applied.
+        periodic_translate : bool, Optional
+            Either if Periodic Movement or not. Default is ``False``.
+        negative_limit : float or str, optional
+            Movement negative limit. If float, default modeler units will be applied.
+        positive_limit : float or str, optional
+            Movement positive limit. If float, default modeler units will be applied.
+        velocity : float or str, optional
+            Movement velocity. If float, "m_per_sec" units will be applied.
+        mechanical_transient : bool, Optional
+            Either to consider or not mechanical movement. Default is ``False``.
+        mass : float or str, optional
+            mechanical mass. If float, "Kg" units will be applied.
+        damping : float, optional
+            Damping Factor. Default ``0``.
+        load_force : float or str, optional
+            Load Force. If float, "newton" units will be applied.
+        motion_name : str, optional
+            Motion Name.
+
+        Returns
+        -------
+        :class:`pyaedt.modules.Boundary.BoundaryObject`
+            Boundary object.
+
+        References
+        ----------
+
+        >>> oModule.AssignBand
+        """
+        assert self.solution_type == SOLUTIONS.Maxwell3d.Transient, "Motion applies only to Transient Setup"
+        if not motion_name:
+            motion_name = generate_unique_name("Motion")
+        object_list = self.modeler._convert_list_to_ids(band_object)
+        props = OrderedDict(
+            {
+                "Move Type": "Translate",
+                "Coordinate System": coordinate_system,
+                "PostProcessing Coordinate System": coordinate_system,
+                "Axis": GeometryOperators.cs_axis_str(axis),
+                "Is Positive": positive_movement,
+                "InitPos": self._arg_with_units(start_position),
+                "TranslatePeriodic": periodic_translate,
+                "NegativePos": self._arg_with_units(negative_limit),
+                "PositivePos": self._arg_with_units(positive_limit),
+                "Consider Mechanical Transient": mechanical_transient,
+                "Velocity": self._arg_with_units(velocity, "m_per_sec"),
+                "Mass": self._arg_with_units(mass, "Kg"),
+                "Damping": str(damping),
+                "Load Force": self._arg_with_units(load_force, "newton"),
+                "Objects": object_list,
+            }
+        )
+        bound = BoundaryObject(self, motion_name, props, "Band")
+        if bound.create():
+            self.boundaries.append(bound)
+            return bound
+        return False
+
+    @aedt_exception_handler
+    def assign_rotate_motion(
+        self,
+        band_object,
+        coordinate_system="Global",
+        axis="Z",
+        positive_movement=True,
+        start_position=0,
+        has_rotation_limits=True,
+        negative_limit=0,
+        positive_limit=360,
+        non_cylindrical=False,
+        mechanical_transient=False,
+        angular_velocity="0rpm",
+        inertia="1",
+        damping=0,
+        load_torque="0newton",
+        motion_name=None,
+    ):
+        """Assign a Rotation Motion to an object container.
+
+        Parameters
+        ----------
+        band_object : str,
+            Object container.
+        coordinate_system : str, optional
+            Coordinate System Name. Default is ``"Global``.
+        axis : str or int, optional
+            Coordinate System Axis. Default is ``"Z"``.
+            It can be a ``pyaedt.generic.constants.AXIS`` Enumerator value.
+        positive_movement : bool, Optional
+            Either if movement is Positive or not. Default is ``True``.
+        start_position : float or str, optional
+            Movement Start Position. If float, "deg" units will be applied.
+        has_rotation_limits : bool, Optional
+            Either if there will be a limit in rotation or not. Default is ``False``.
+        negative_limit : float or str, optional
+            Movement negative limit. If float, "deg" units will be applied.
+        positive_limit : float or str, optional
+            Movement positive limit. If float, "deg" units will be applied.
+        non_cylindrical : bool, optional
+            Either if Non Cylindrical rotation has to be considered. Default is ``False``.
+        angular_velocity : float or str, optional
+            Movement velocity. If float, "rpm" units will be applied.
+        mechanical_transient : bool, Optional
+            Either to consider or not mechanical movement. Default is ``False``.
+        inertia : float, optional
+            mechanical inertia.
+        damping : float, optional
+            Damping Factor. Default ``0``.
+        load_torque : float or str, optional
+            Load Force. If float, "NewtonMeter" units will be applied.
+        motion_name : str, optional
+            Motion Name.
+
+        Returns
+        -------
+        :class:`pyaedt.modules.Boundary.BoundaryObject`
+            Boundary object.
+
+        References
+        ----------
+
+        >>> oModule.AssignBand
+        """
+        assert self.solution_type == SOLUTIONS.Maxwell3d.Transient, "Motion applies only to Transient Setup"
+        if not motion_name:
+            motion_name = generate_unique_name("Motion")
+        object_list = self.modeler._convert_list_to_ids(band_object)
+        props = OrderedDict(
+            {
+                "Move Type": "Rotate",
+                "Coordinate System": coordinate_system,
+                "Axis": GeometryOperators.cs_axis_str(axis),
+                "Is Positive": positive_movement,
+                "InitPos": self._arg_with_units(start_position, "deg"),
+                "HasRotateLimit": has_rotation_limits,
+                "NegativePos": self._arg_with_units(negative_limit, "deg"),
+                "PositivePos": self._arg_with_units(positive_limit, "deg"),
+                "NonCylindrical": non_cylindrical,
+                "Consider Mechanical Transient": mechanical_transient,
+                "Angular Velocity": self._arg_with_units(angular_velocity, "rpm"),
+                "Moment of Inertia": str(inertia),
+                "Damping": str(damping),
+                "Load Torque": self._arg_with_units(load_torque, "NewtonMeter"),
+                "Objects": object_list,
+            }
+        )
+        bound = BoundaryObject(self, motion_name, props, "Band")
+        if bound.create():
             self.boundaries.append(bound)
             return bound
         return False
@@ -277,9 +562,13 @@ class Maxwell(object):
         :class:`pyaedt.modules.Boundary.BoundaryObject`
             Boundary object.
 
-        """
+        References
+        ----------
 
-        amplitude = str(amplitude) + "mV"
+        >>> oModule.AssignVoltage
+        """
+        if isinstance(amplitude, (int, float)):
+            amplitude = str(amplitude) + "mV"
 
         if not name:
             name = generate_unique_name("Voltage")
@@ -313,9 +602,14 @@ class Maxwell(object):
         -------
         :class:`pyaedt.modules.Boundary.BoundaryObject`
             Boundary object.
-        """
 
-        amplitude = str(amplitude) + "mV"
+        References
+        ----------
+
+        >>> oModule.AssignVoltageDrop
+        """
+        if isinstance(amplitude, (int, float)):
+            amplitude = str(amplitude) + "mV"
 
         if not name:
             name = generate_unique_name("VoltageDrop")
@@ -371,6 +665,10 @@ class Maxwell(object):
         :class:`pyaedt.modules.Boundary.BoundaryObject`
             Bounding object for the winding, otherwise only the bounding object.
 
+        References
+        ----------
+
+        >>> oModule.AssignWindingGroup
         """
 
         if not name:
@@ -418,6 +716,11 @@ class Maxwell(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.AddWindingTerminals
+        >>> oModule.AddWindingCoils
         """
         if self.modeler._is3d:
             self.oboundary.AddWindingTerminals(windingname, coil_names)
@@ -445,6 +748,10 @@ class Maxwell(object):
         CoilObject
             Coil object.
 
+        References
+        ----------
+
+        >>> oModule.AssignCoil
         """
         if polarity == "Positive":
             point = False
@@ -475,7 +782,7 @@ class Maxwell(object):
                 bound = BoundaryObject(self, name, props2, "CoilTerminal")
 
             else:
-                self._messenger.add_warning_message("Face Selection is not allowed in Maxwell 2D. Provide a 2D object.")
+                self.logger.warning("Face Selection is not allowed in Maxwell 2D. Provide a 2D object.")
                 return False
         if bound.create():
             self.boundaries.append(bound)
@@ -502,6 +809,10 @@ class Maxwell(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.AssignForce
         """
         input_object = self.modeler._convert_list_to_ids(input_object, True)
         if not force_name:
@@ -550,6 +861,10 @@ class Maxwell(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.AssignTorque
         """
         input_object = self.modeler._convert_list_to_ids(input_object, True)
         if not torque_name:
@@ -604,6 +919,10 @@ class Maxwell(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.AssignForce
         """
         input_object = self.modeler._convert_list_to_ids(input_object, True)
         if not force_name:
@@ -637,6 +956,10 @@ class Maxwell(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.ChangeProperty
         """
         self.modeler.primitives[name].solve_inside = activate
         return True
@@ -650,6 +973,10 @@ class Maxwell(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.ResetSetupToTimeZero
         """
         self.oanalysis.ResetSetupToTimeZero(self._setup)
         self.analyze_nominal()
@@ -671,6 +998,10 @@ class Maxwell(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oDesign.ChangeProperty
         """
         self.odesign.ChangeProperty(
             [
@@ -740,13 +1071,13 @@ class Maxwell3d(Maxwell, FieldAnalysis3D, object):
 
     >>> from pyaedt import Maxwell3d
     >>> aedtapp = Maxwell3d("mymaxwell.aedt")
-    pyaedt Info: Added design ...
+    pyaedt info: Added design ...
 
     Create an instance of Maxwell 3D using the 2021 R1 release and open
     the specified project, which is named ``mymaxwell2.aedt``.
 
-    >>> aedtapp = Maxwell3d(specified_version="2021.1", projectname="mymaxwell2.aedt")
-    pyaedt Info: Added design ...
+    >>> aedtapp = Maxwell3d(specified_version="2021.2", projectname="mymaxwell2.aedt")
+    pyaedt info: Added design ...
 
     """
 
@@ -858,7 +1189,12 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
 
     @property
     def geometry_mode(self):
-        """Geometry mode."""
+        """Geometry mode.
+
+        References
+        ----------
+
+        >>> oDesign.GetGeometryMode"""
         return self.odesign.GetGeometryMode()
 
     def __init__(
@@ -889,19 +1225,46 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
         )
         Maxwell.__init__(self)
 
+    @property
+    def xy_plane(self):
+        """Get/Set Maxwell 2d plane between `"XY"` and `"about Z"`."""
+        if self.design_solutions.xy_plane == "XY":
+            return True
+        else:
+            return False
+
+    @xy_plane.setter
     @aedt_exception_handler
-    def get_model_depth(self):
+    def xy_plane(self, value=True):
+        self.design_solutions.xy_plane = value
+
+    @property
+    def model_depth(self):
         """Get model depth."""
+
         if "ModelDepth" in self.design_properties:
             value_str = self.design_properties["ModelDepth"]
             try:
                 a = float_units(value_str)
             except:
                 a = self.variable_manager[value_str].value
-            return a
+            finally:
+                return a
         else:
             return None
 
+    @model_depth.setter
+    def model_depth(self, value):
+        """Set model depth."""
+
+        self.odesign.SetDesignSettings(
+            [
+                "NAME:Design Settings Data",
+                "ModelDepth:=",
+                value,
+            ]
+        )
+
     @aedt_exception_handler
     def generate_design_data(self, linefilter=None, objectfilter=None):
         """Generate a generic set of design data and store it in the extension directory as ``design_data.json``.
@@ -934,7 +1297,6 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
             solid_ids = [i for i, j in self.modeler.primitives.object_id_dict.items() if j.name in objectfilter]
         else:
             solid_ids = [i for i in list(self.modeler.primitives.object_id_dict.keys())]
-        model_depth = self.get_model_depth()
         self.design_data = {
             "Project Directory": self.project_path,
             "Working Directory": self.working_directory,
@@ -943,7 +1305,7 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
             "GeoMode": self.geometry_mode,
             "ModelUnits": self.modeler.model_units,
             "Symmetry": self.symmetry_multiplier,
-            "ModelDepth": model_depth,
+            "ModelDepth": self.model_depth,
             "ObjectList": solid_ids,
             "LineList": self.modeler.vertex_data_of_lines(linefilter),
             "VarList": self.variable_manager.variable_names,
@@ -987,6 +1349,10 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
         :class:`pyaedt.modules.Boundary.BoundaryObject`
             Boundary object.
 
+        References
+        ----------
+
+        >>> oModule.AssignBalloon
         """
         edge_list = self.modeler._convert_list_to_ids(edge_list)
 
@@ -1019,6 +1385,10 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
         :class:`pyaedt.modules.Boundary.BoundaryObject`
             Vector Potential Object
 
+        References
+        ----------
+
+        >>> oModule.AssignVectorPotential
         """
         input_edge = self.modeler._convert_list_to_ids(input_edge)
 
@@ -1036,8 +1406,9 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
         return False
 
     @aedt_exception_handler
-    def assign_master_slave(self, master_edge, slave_edge, reverse_master=False, reverse_slave=False,
-                            same_as_master=True, bound_name=None):
+    def assign_master_slave(
+        self, master_edge, slave_edge, reverse_master=False, reverse_slave=False, same_as_master=True, bound_name=None
+    ):
         """Assign master and slave boundary conditions to two edges of the same object.
 
         Parameters
@@ -1060,6 +1431,11 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
         :class:`pyaedt.modules.Boundary.BoundaryObject`, :class:`pyaedt.modules.Boundary.BoundaryObject`
             Master and slave objects.
 
+        References
+        ----------
+
+        >>> oModule.AssignIndependent
+        >>> oModule.AssignDependent
         """
         master_edge = self.modeler._convert_list_to_ids(master_edge)
         slave_edge = self.modeler._convert_list_to_ids(slave_edge)
@@ -1074,9 +1450,15 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
         if bound.create():
             self.boundaries.append(bound)
 
-            props2 = OrderedDict({"Edges": slave_edge, "ReverseU": reverse_slave, "Independent": bound_name_m,
-                                  "SameAsMaster": same_as_master})
-            bound2 = BoundaryObject(self, bound_name_s, props2, "Independent")
+            props2 = OrderedDict(
+                {
+                    "Edges": slave_edge,
+                    "ReverseU": reverse_slave,
+                    "Independent": bound_name_m,
+                    "SameAsMaster": same_as_master,
+                }
+            )
+            bound2 = BoundaryObject(self, bound_name_s, props2, "Dependent")
             if bound2.create():
                 self.boundaries.append(bound2)
                 return bound, bound2
