@@ -2,9 +2,9 @@
 
 from __future__ import absolute_import
 
-from .application.Analysis3D import FieldAnalysis3D
-from .generic.general_methods import generate_unique_name, aedt_exception_handler
-from .modules.Boundary import BoundaryObject
+from pyaedt.application.Analysis3D import FieldAnalysis3D
+from pyaedt.generic.general_methods import generate_unique_name, aedt_exception_handler
+from pyaedt.modules.Boundary import BoundaryObject
 from collections import OrderedDict
 
 
@@ -71,11 +71,11 @@ class Mechanical(FieldAnalysis3D, object):
 
     >>> aedtapp = Mechanical("myfile.aedt")
 
-    Create a ``Desktop on 2021R1`` object and then create an
+    Create a ``Desktop on 2021R2`` object and then create an
     ``Mechanical`` object and open the specified project, which is
     named ``"myfile.aedt"``.
 
-    >>> aedtapp = Mechanical(specified_version="2021.1", projectname="myfile.aedt")
+    >>> aedtapp = Mechanical(specified_version="2021.2", projectname="myfile.aedt")
 
     """
 
@@ -146,11 +146,16 @@ class Mechanical(FieldAnalysis3D, object):
 
         Returns
         -------
+        :class:`pyaedt.modules.Boundary.BoundaryObject`
 
+        References
+        ----------
+
+        >>> oModule.AssignEMLoss
         """
         assert self.solution_type == "Thermal", "This Method works only in Mechanical Structural Solution"
 
-        self._messenger.add_info_message("Mapping HFSS EM Lossess")
+        self.logger.info("Mapping HFSS EM Lossess")
         oName = self.project_name
         if oName == source_project_name or source_project_name is None:
             projname = "This Project*"
@@ -198,7 +203,7 @@ class Mechanical(FieldAnalysis3D, object):
         bound = BoundaryObject(self, name, props, "EMLoss")
         if bound.create():
             self.boundaries.append(bound)
-            self._messenger.add_info_message("EM losses mapped from design {}.".format(designname))
+            self.logger.info("EM losses mapped from design %s.", designname)
             return bound
         return False
 
@@ -237,11 +242,16 @@ class Mechanical(FieldAnalysis3D, object):
         -------
         :class:`aedt.modules.Boundary.Boundary object`
             Boundary object.
+
+        References
+        ----------
+
+        >>> oModule.AssignThermalCondition
         """
 
         assert self.solution_type == "Structural", "This method works only in a Mechanical structural solution."
 
-        self._messenger.add_info_message("Mapping HFSS EM Lossess")
+        self.logger.info("Mapping HFSS EM Lossess")
         oName = self.project_name
         if oName == source_project_name or source_project_name is None:
             projname = "This Project*"
@@ -281,7 +291,7 @@ class Mechanical(FieldAnalysis3D, object):
         bound = BoundaryObject(self, name, props, "ThermalCondition")
         if bound.create():
             self.boundaries.append(bound)
-            self._messenger.add_info_message("Thermal conditions are mapped from design {}.".format(designname))
+            self.logger.info("Thermal conditions are mapped from design %s.", designname)
             return bound
 
         return True
@@ -310,6 +320,10 @@ class Mechanical(FieldAnalysis3D, object):
         :class:`aedt.modules.Boundary.Boundary object`
             Boundary object.
 
+        References
+        ----------
+
+        >>> oModule.AssignConvection
         """
         assert self.solution_type == "Thermal", "This method works only in a Mechanical structural solution."
 
@@ -355,6 +369,10 @@ class Mechanical(FieldAnalysis3D, object):
         :class:`aedt.modules.Boundary.Boundary object`
             Boundary object.
 
+        References
+        ----------
+
+        >>> oModule.AssignTemperature
         """
         assert self.solution_type == "Thermal", "This method works only in a Mechanical structural analysis."
 
@@ -396,10 +414,14 @@ class Mechanical(FieldAnalysis3D, object):
         :class:`aedt.modules.Boundary.Boundary object`
             Boundary object.
 
+        References
+        ----------
+
+        >>> oModule.AssignFrictionlessSupport
         """
 
-        if not (self.solution_type == "Structural" or self.solution_type == "Modal"):
-            self._messenger.add_error_message("This method works only in Mechanical Structural Solution")
+        if not (self.solution_type == "Structural" or "Modal" in self.solution_type):
+            self.logger.error("This method works only in Mechanical Structural Solution")
             return False
         props = {}
         objects_list = self.modeler._convert_list_to_ids(objects_list)
@@ -437,9 +459,13 @@ class Mechanical(FieldAnalysis3D, object):
         aedt.modules.Boundary.Boundary
             Boundary object.
 
+        References
+        ----------
+
+        >>> oModule.AssignFixedSupport
         """
-        if not (self.solution_type == "Structural" or self.solution_type == "Modal"):
-            self._messenger.add_error_message("This method works only in a Mechanical structural solution.")
+        if not (self.solution_type == "Structural" or "Modal" in self.solution_type):
+            self.logger.error("This method works only in a Mechanical structural solution.")
             return False
         props = {}
         objects_list = self.modeler._convert_list_to_ids(objects_list)
@@ -464,6 +490,10 @@ class Mechanical(FieldAnalysis3D, object):
         list
             List of existing analysis sweeps.
 
+        References
+        ----------
+
+        >>> oModule.GetSetups
         """
         setup_list = self.existing_analysis_setups
         sweep_list = []
