@@ -1,8 +1,9 @@
 import math
+from warnings import warn
 
-from ..generic.general_methods import aedt_exception_handler
-from .Modeler import Modeler, GeometryModeler
-from .Primitives2D import Primitives2D
+from pyaedt.generic.general_methods import aedt_exception_handler
+from pyaedt.modeler.Modeler import Modeler, GeometryModeler
+from pyaedt.modeler.Primitives2D import Primitives2D
 
 
 class ModelerRMxprt(Modeler):
@@ -13,16 +14,22 @@ class ModelerRMxprt(Modeler):
 
     """
 
-    def __init__(self, parent):
-        Modeler.__init__(self, parent)
+    def __init__(self, app):
+        Modeler.__init__(self, app)
+        self._oeditor = self._odesign.SetActiveEditor("Machine")
 
     @property
     def oeditor(self):
-        """Editor."""
-        return self.odesign.SetActiveEditor("Machine")
+        """oEditor Module.
+
+        References
+        ----------
+
+        >>> oEditor = oDesign.SetActiveEditor("Machine")"""
+        return self._oeditor
 
 
-class Modeler2D(GeometryModeler):
+class Modeler2D(GeometryModeler, Primitives2D):
     """Provides the Modeler 2D application interface.
 
     This class is inherited in the caller application and is accessible through the modeler variable
@@ -30,34 +37,40 @@ class Modeler2D(GeometryModeler):
 
     Parameters
     ----------
-    application :
-
-    is3d : bool, optional
-        Whether the model is 3D. The default is ``False``.
+    application : :class:`pyaedt.application.Analysis2D.FieldAnalysis2D`
 
+    Examples
+    --------
+    >>> from pyaedt import Maxwell2d
+    >>> app = Maxwell2d()
+    >>> my_modeler = app.modeler
     """
 
     def __init__(self, application):
         GeometryModeler.__init__(self, application, is3d=False)
-        self._primitives = Primitives2D(self._parent, self)
-        self._primitivesDes = self._parent.project_name + self._parent.design_name
+        Primitives2D.__init__(self)
+        self._primitives = self
+        self._primitivesDes = self._app.project_name + self._app.design_name
 
     def __get__(self, instance, owner):
-        self._parent = instance
+        self._app = instance
         return self
 
     @property
     def primitives(self):
         """Primitives.
 
+        .. deprecated:: 0.4.15
+            No need to use primitives anymore. You can instantiate primitives methods directly from modeler instead.
+
         Returns
         -------
         :class:`pyaedt.modeler.Primitives2D.Primitives2D`
 
         """
-        if self._primitivesDes != self._parent.project_name + self._parent.design_name:
-            self._primitives.refresh()
-            self._primitivesDes = self._parent.project_name + self._parent.design_name
+        mess = "`primitives` is deprecated.\n"
+        mess += " Use `app.modeler` directly to instantiate primitives methods."
+        warn(mess, DeprecationWarning)
         return self._primitives
 
     @aedt_exception_handler
@@ -115,7 +128,6 @@ class Modeler2D(GeometryModeler):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
-
         """
         self.oeditor.CreateCircle(
             [
