@@ -1,10 +1,12 @@
 from __future__ import absolute_import
-from ..generic.general_methods import aedt_exception_handler
-from .Modeler import GeometryModeler
-from .Primitives3D import Primitives3D
+import warnings
+
+from pyaedt.generic.general_methods import aedt_exception_handler
+from pyaedt.modeler.Modeler import GeometryModeler
+from pyaedt.modeler.Primitives3D import Primitives3D
 
 
-class Modeler3D(GeometryModeler):
+class Modeler3D(GeometryModeler, Primitives3D, object):
     """Provides the Modeler 3D application interface.
 
     This class is inherited in the caller application and is accessible through the modeler variable
@@ -12,34 +14,39 @@ class Modeler3D(GeometryModeler):
 
     Parameters
     ----------
-    application :
-
-    is3D : bool, optional
-        Whether the model is 3D. The default is ``True``.
-
+    application : :class:`pyaedt.application.Analysis3D.FieldAnalysis3D`
+    Examples
+    --------
+    >>> from pyaedt import Hfss
+    >>> hfss = Hfss()
+    >>> my_modeler = hfss.modeler
     """
 
     def __init__(self, application):
         GeometryModeler.__init__(self, application, is3d=True)
-        self._primitives = Primitives3D(self._parent, self)
-        self._primitivesDes = self._parent.project_name + self._parent.design_name
+        Primitives3D.__init__(self)
+        self._primitives = self
+        self._primitivesDes = self._app.project_name + self._app.design_name
 
     def __get__(self, instance, owner):
-        self._parent = instance
+        self._app = instance
         return self
 
     @property
     def primitives(self):
         """Primitives.
 
+        .. deprecated:: 0.4.15
+            No need to use primitives anymore. You can instantiate primitives methods directly from modeler instead.
+
         Returns
         -------
         :class:`pyaedt.modeler.Primitives3D.Primitives3D`
 
         """
-        if self._primitivesDes != self._parent.project_name + self._parent.design_name:
-            self._primitives.refresh()
-            self._primitivesDes = self._parent.project_name + self._parent.design_name
+        mess = "The property `primitives` is deprecated.\n"
+        mess += " Use `app.modeler` directly to instantiate primitives methods."
+        warnings.warn(mess, DeprecationWarning)
         return self._primitives
 
     @aedt_exception_handler
@@ -62,11 +69,15 @@ class Modeler3D(GeometryModeler):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.Create3DComponent
         """
-        if self._parent.design_type == "Icepak":
+        if self._app.design_type == "Icepak":
             exclude_region = True
         if not component_name:
-            component_name = self._parent.design_name
+            component_name = self._app.design_name
         arg = [
             "NAME:CreateData",
             "ComponentName:=",
@@ -124,7 +135,7 @@ class Modeler3D(GeometryModeler):
         arg.append("ReferenceCS:="), arg.append(activecs)
         variables = variables_to_include
         arg.append("IncludedParameters:="), arg.append(variables)
-        variables = self._parent._variable_manager.dependent_variable_names
+        variables = self._app._variable_manager.dependent_variable_names
         par_description = []
         for el in variables:
             par_description.append(el)
@@ -141,8 +152,8 @@ class Modeler3D(GeometryModeler):
         arg2 = ["NAME:DesignData"]
         boundaries = self.get_boundaries_name()
         arg2.append("Boundaries:="), arg2.append(boundaries)
-        if self._parent.design_type == "Icepak":
-            meshregions = [name for name in self._parent.mesh.meshregions.name]
+        if self._app.design_type == "Icepak":
+            meshregions = [name for name in self._app.mesh.meshregions.name]
             try:
                 meshregions.remove("Global")
             except:
@@ -151,7 +162,7 @@ class Modeler3D(GeometryModeler):
         else:
             excitations = self.get_excitations_name()
             arg2.append("Excitations:="), arg2.append(excitations)
-        meshops = [el.name for el in self._parent.mesh.meshoperations]
+        meshops = [el.name for el in self._app.mesh.meshoperations]
         arg2.append("MeshOperations:="), arg2.append(meshops)
         arg3 = ["NAME:ImageFile", "ImageFile:=", ""]
         self.oeditor.Create3DComponent(arg, arg2, component_file, arg3)
