@@ -1,16 +1,22 @@
 import os
+import time
+from warnings import warn
 
-from pyaedt import _pythonver, is_ironpython, inside_desktop
-
-from ..application.Variables import AEDT_units
-from ..edb import Edb
-from ..generic.general_methods import aedt_exception_handler, retry_ntimes
-from ..modules.LayerStackup import Layers
-from .Modeler import Modeler
-from .Primitives3DLayout import Geometries3DLayout, Primitives3DLayout
+from pyaedt.generic.constants import AEDT_UNITS
+from pyaedt.edb import Edb
+from pyaedt.generic.general_methods import (
+    aedt_exception_handler,
+    _retry_ntimes,
+    is_ironpython,
+    _pythonver,
+    inside_desktop,
+)
+from pyaedt.modules.LayerStackup import Layers
+from pyaedt.modeler.Modeler import Modeler
+from pyaedt.modeler.Primitives3DLayout import Geometries3DLayout, Primitives3DLayout
 
 
-class Modeler3DLayout(Modeler):
+class Modeler3DLayout(Modeler, Primitives3DLayout):
     """Manages Modeler 3D layouts.
 
     This class is inherited in the caller application and is accessible through the modeler variable
@@ -18,18 +24,24 @@ class Modeler3DLayout(Modeler):
 
     Parameters
     ----------
-    parent :
-        Inherited parent object.
+    app : :class:`pyaedt.application.Analysis3DLayout.FieldAnalysis3DLayout`
+            Inherited parent object.
 
+    Examples
+    --------
+    >>> from pyaedt import Hfss3dLayout
+    >>> hfss = Hfss3dLayout()
+    >>> my_modeler = hfss.modeler
     """
 
-    def __init__(self, parent):
-        self._parent = parent
-        self._messenger.add_info_message("Loading Modeler.")
-        Modeler.__init__(self, parent)
-        self._messenger.add_info_message("Modeler loaded.")
-        self._primitivesDes = self._parent.project_name + self._parent.design_name
-        edb_folder = os.path.join(self._parent.project_path, self._parent.project_name + ".aedb")
+    def __init__(self, app):
+        self._app = app
+        self._oeditor = self._app._odesign.SetActiveEditor("Layout")
+        self.logger.info("Loading Modeler.")
+        Modeler.__init__(self, app)
+        self.logger.info("Modeler loaded.")
+        self._primitivesDes = self._app.project_name + self._app.design_name
+        edb_folder = os.path.join(self._app.project_path, self._app.project_name + ".aedb")
         edb_file = os.path.join(edb_folder, "edb.def")
         self._edb = None
         if os.path.exists(edb_file) or (inside_desktop and is_ironpython):
@@ -37,38 +49,50 @@ class Modeler3DLayout(Modeler):
                 self._mttime = os.path.getmtime(edb_file)
             else:
                 self._mttime = 0
+            time.sleep(1)
             self._edb = Edb(
                 edb_folder,
-                self._parent.design_name,
+                self._app.design_name,
                 True,
-                self._parent._aedt_version,
+                self._app._aedt_version,
                 isaedtowned=True,
-                oproject=self._parent.oproject,
+                oproject=self._app.oproject,
             )
         else:
             self._mttime = 0
-        self._messenger.add_info_message("EDB loaded.")
+        self.logger.info("EDB loaded.")
+        self.layers = Layers(self, roughnessunits="um")
+        self.logger.info("Layers loaded.")
+        Primitives3DLayout.__init__(self, app)
+        self._primitives = self
 
-        self.layers = Layers(self._parent, self, roughnessunits="um")
-        self._messenger.add_info_message("Layers loaded.")
-        self._primitives = Primitives3DLayout(self._parent, self)
-        self._messenger.add_info_message("Primitives loaded.")
+        self.logger.info("Primitives loaded.")
         self.layers.refresh_all_layers()
 
         pass
 
+    @property
+    def oeditor(self):
+        """Oeditor Module.
+
+        References
+        ----------
+
+        >>> oEditor = oDesign.SetActiveEditor("Layout")"""
+        return self._oeditor
+
     @property
     def edb(self):
         """EBD.
 
         Returns
         -------
-        :class:`pyaedt.Edb`
+        :class:`pyaedt.edb.Edb`
              EDB.
 
         """
         if not (inside_desktop and is_ironpython):
-            edb_folder = os.path.join(self._parent.project_path, self._parent.project_name + ".aedb")
+            edb_folder = os.path.join(self._app.project_path, self._app.project_name + ".aedb")
             edb_file = os.path.join(edb_folder, "edb.def")
             if os.path.exists(edb_file):
                 _mttime = os.path.getmtime(edb_file)
@@ -79,28 +103,29 @@ class Modeler3DLayout(Modeler):
                     self._edb.close_edb()
                 self._edb = Edb(
                     edb_folder,
-                    self._parent.design_name,
+                    self._app.design_name,
                     True,
-                    self._parent._aedt_version,
+                    self._app._aedt_version,
                     isaedtowned=True,
-                    oproject=self._parent.oproject,
+                    oproject=self._app.oproject,
                 )
                 self._mttime = _mttime
         return self._edb
 
     @property
-    def _messenger(self):
-        """Messenger."""
-        return self._parent._messenger
-
-    @property
-    def oeditor(self):
-        """Editor."""
-        return self._parent.odesign.SetActiveEditor("Layout")
+    def logger(self):
+        """Logger."""
+        return self._app.logger
 
     @aedt_exception_handler
     def fit_all(self):
-        """Fit all."""
+        """Fit all.
+
+        References
+        ----------
+
+        >>> oEditor.ZoomToFit()
+        """
         try:
             self._desktop.RestoreWindow()
             self.oeditor.ZoomToFit()
@@ -109,31 +134,53 @@ class Modeler3DLayout(Modeler):
 
     @property
     def model_units(self):
-        """Model units."""
-        return retry_ntimes(10, self.oeditor.GetActiveUnits)
+        """Model units.
+
+        References
+        ----------
+
+        >>> oEditor.GetActiveUnits
+        >>> oEditor.SetActivelUnits
+        """
+        return _retry_ntimes(10, self.oeditor.GetActiveUnits)
 
     @model_units.setter
     def model_units(self, units):
-        assert units in AEDT_units["Length"], "Invalid units string {0}.".format(units)
+        assert units in AEDT_UNITS["Length"], "Invalid units string {0}.".format(units)
         """ Set the model units as a string e.g. "mm" """
         self.oeditor.SetActivelUnits(["NAME:Units Parameter", "Units:=", units, "Rescale:=", False])
 
     @property
     def primitives(self):
-        """Primitives."""
-        if self._primitivesDes != self._parent.project_name + self._parent.design_name:
-            self._primitives = Primitives3DLayout(self._parent, self)
-            self._primitivesDes = self._parent.project_name + self._parent.design_name
+        """Primitives.
+
+        .. deprecated:: 0.4.15
+            No need to use primitives anymore. You can instantiate primitives methods directly from modeler instead.
+
+        Returns
+        -------
+        :class:`pyaedt.modeler.Primitives3DLayout.Primitives3DLayout`
+
+        """
+        mess = "`primitives` is deprecated.\n"
+        mess += " Use `app.modeler` directly to instantiate primitives methods."
+        warn(mess, DeprecationWarning)
         return self._primitives
 
     @property
     def obounding_box(self):
-        """Bounding box."""
+        """Bounding box.
+
+        References
+        ----------
+
+        >>> oEditor.GetModelBoundingBox
+        """
         return self.oeditor.GetModelBoundingBox()
 
     @aedt_exception_handler
     def _arg_with_dim(self, value, units=None):
-        if type(value) is str:
+        if isinstance(value, str):
             val = value
         else:
             if units is None:
@@ -176,21 +223,40 @@ class Modeler3DLayout(Modeler):
         -------
         bool
             ``True`` if successful.
+
+        References
+        ----------
+
+        >>> oEditor.ChangeProperty
         """
         if isinstance(property_value, list) and len(property_value) == 3:
             xpos, ypos, zpos = self._pos_with_arg(property_value)
             self.oeditor.ChangeProperty(
-                ["NAME:AllTabs", ["NAME:" + property_tab, ["NAME:PropServers", property_object], ["NAME:ChangedProps", [
-                    "NAME:" + property_name, "X:=", xpos, "Y:=", ypos, "Z:=", zpos]]]])
+                [
+                    "NAME:AllTabs",
+                    [
+                        "NAME:" + property_tab,
+                        ["NAME:PropServers", property_object],
+                        ["NAME:ChangedProps", ["NAME:" + property_name, "X:=", xpos, "Y:=", ypos, "Z:=", zpos]],
+                    ],
+                ]
+            )
         elif isinstance(property_value, (str, float, int)):
             posx = self._arg_with_dim(property_value, self.model_units)
             self.oeditor.ChangeProperty(
-                ["NAME:AllTabs", ["NAME:"+property_tab, ["NAME:PropServers", property_object],
-                                  ["NAME:ChangedProps", ["NAME:"+property_name, "Value:=", posx]]]])
+                [
+                    "NAME:AllTabs",
+                    [
+                        "NAME:" + property_tab,
+                        ["NAME:PropServers", property_object],
+                        ["NAME:ChangedProps", ["NAME:" + property_name, "Value:=", posx]],
+                    ],
+                ]
+            )
         else:
-            self._messenger.add_error_message("Wrong Property Value")
+            self.logger.error("Wrong Property Value")
             return False
-        self._messenger.add_info_message("Property {} Changed correctly.".format(property_name))
+        self.logger.info("Property {} Changed correctly.".format(property_name))
         return True
 
     @aedt_exception_handler
@@ -208,6 +274,11 @@ class Modeler3DLayout(Modeler):
         -------
         bool
             ``True`` if successful.
+
+        References
+        ----------
+
+        >>> oEditor.ChangeProperty
         """
         return self.change_property(clip_name, "Location", position)
 
@@ -227,17 +298,23 @@ class Modeler3DLayout(Modeler):
         bool
              ``True`` when successful, ``False`` when failed.
 
+
+        References
+        ----------
+
+        >>> oEditor.Heal
+
+
         Examples
         --------
         >>> from pyaedt import Hfss3dLayout
-        >>> h3d=Hfss3dLayout(specified_version="2021.1")
+        >>> h3d=Hfss3dLayout(specified_version="2021.2")
         >>> h3d.modeler.layers.add_layer("TOP")
         >>> l1=h3d.modeler.primitives.create_line("TOP", [[0,0],[100,0]],  0.5, name="poly_1")
         >>> l2=h3d.modeler.primitives.create_line("TOP", [[100,0],[120,-35]],  0.5, name="poly_2")
         >>> h3d.modeler.unite([l1,l2])
         >>> h3d.modeler.colinear_heal("poly_2", 0.25)
         True
-
         """
         if isinstance(selection, str):
             selection = [selection]
@@ -276,10 +353,16 @@ class Modeler3DLayout(Modeler):
         str
             Name of the object.
 
+        References
+        ----------
+
+        >>> oEditor.Expand
+
+
         Examples
         --------
         >>> from pyaedt import Hfss3dLayout
-        >>> h3d=Hfss3dLayout(specified_version="2021.1")
+        >>> h3d=Hfss3dLayout(specified_version="2021.2")
         >>> h3d.modeler.layers.add_layer("TOP")
         >>> h3d.modeler.primitives.create_rectangle("TOP", [20,20],[50,50], name="rect_1")
         >>> h3d.modeler.primitives.create_line("TOP",[[25,25],[40,40]], name="line_3")
@@ -288,7 +371,7 @@ class Modeler3DLayout(Modeler):
         line_4
 
         """
-        layer = retry_ntimes(10, self.oeditor.GetPropertyValue, "BaseElementTab", object_to_expand, "PlacementLayer")
+        layer = _retry_ntimes(10, self.oeditor.GetPropertyValue, "BaseElementTab", object_to_expand, "PlacementLayer")
         poly = self.oeditor.GetPolygonDef(object_to_expand).GetPoints()
         pos = [poly[0].GetX(), poly[0].GetY()]
         geom_names = self.oeditor.FindObjectsByPoint(self.oeditor.Point().Set(pos[0], pos[1]), layer)
@@ -301,8 +384,8 @@ class Modeler3DLayout(Modeler):
                 for i in self.oeditor.FindObjectsByPoint(self.oeditor.Point().Set(pos[0], pos[1]), layer)
                 if i not in geom_names
             ]
-            if self.primitives.isoutsideDesktop:
-                self.primitives._geometries[new_geom_names[0]] = Geometries3DLayout(self, new_geom_names[0])
+            if self.primitives.is_outside_desktop:
+                self.primitives._geometries[new_geom_names[0]] = Geometries3DLayout(self.primitives, new_geom_names[0])
             return new_geom_names[0]
         return object_to_expand
 
@@ -326,6 +409,10 @@ class Modeler3DLayout(Modeler):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oImportExport.ImportExtracta
         """
         if not edb_path:
             edb_path = self.projdir
@@ -333,18 +420,10 @@ class Modeler3DLayout(Modeler):
             name = os.path.basename(brd_filename)
             edb_name = os.path.splitext(name)[0]
 
-        self.oimportexport.ImportExtracta(
+        self._oimportexport.ImportExtracta(
             brd_filename, os.path.join(edb_path, edb_name + ".aedb"), os.path.join(edb_path, edb_name + ".xml")
         )
-        self._parent.oproject = self._parent._desktop.GetActiveProject().GetName()
-        self._parent.odesign = None
-
-        # name = self._parent.project_name
-        # prjpath = self._parent.project_path
-        # self._parent.close_project(self._parent.project_name, True)
-        #
-        # self._parent.load_project(os.path.join(prjpath, name+".aedt"))
-
+        self._app.__init__(self._app._desktop.GetActiveProject().GetName())
         return True
 
     @aedt_exception_handler
@@ -384,6 +463,10 @@ class Modeler3DLayout(Modeler):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oImportExport.ImportIPC
         """
         if not edb_path:
             edb_path = self.projdir
@@ -391,11 +474,10 @@ class Modeler3DLayout(Modeler):
             name = os.path.basename(ipc_filename)
             edb_name = os.path.splitext(name)[0]
 
-        self.oimportexport.ImportIPC(
+        self._oimportexport.ImportIPC(
             ipc_filename, os.path.join(edb_path, edb_name + ".aedb"), os.path.join(edb_path, edb_name + ".xml")
         )
-        self._parent.oproject = self._parent._desktop.GetActiveProject().GetName()
-        self._parent.odesign = None
+        self._app.__init__(self._app._desktop.GetActiveProject().GetName())
         return True
 
     @aedt_exception_handler
@@ -414,21 +496,25 @@ class Modeler3DLayout(Modeler):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.Subtract
         """
         vArg1 = ["NAME:primitives", blank]
-        if type(tool) is list:
+        if isinstance(tool, list):
             for el in tool:
                 vArg1.append(el)
         else:
             vArg1.append(tool)
         if self.oeditor is not None:
             self.oeditor.Subtract(vArg1)
-        if type(tool) is list:
+        if isinstance(tool, list):
             for el in tool:
-                if self.primitives.isoutsideDesktop:
+                if self.primitives.is_outside_desktop:
                     self.primitives._geometries.pop(el)
         else:
-            if self.primitives.isoutsideDesktop:
+            if self.primitives.is_outside_desktop:
                 self.primitives._geometries.pop(tool)
         return True
 
@@ -446,6 +532,10 @@ class Modeler3DLayout(Modeler):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.Unite
         """
         vArg1 = ["NAME:primitives"]
         if len(objectlists) >= 2:
@@ -454,11 +544,11 @@ class Modeler3DLayout(Modeler):
             self.oeditor.Unite(vArg1)
             for el in objectlists:
                 if not self.oeditor.FindObjects("Name", el):
-                    if self.primitives.isoutsideDesktop:
+                    if self.primitives.is_outside_desktop:
                         self.primitives._geometries.pop(el)
             return True
         else:
-            self._messenger.add_error_message("Input list must contain at least two elements.")
+            self.logger.error("Input list must contain at least two elements.")
             return False
 
     @aedt_exception_handler
@@ -475,6 +565,10 @@ class Modeler3DLayout(Modeler):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.Intersect
         """
         vArg1 = ["NAME:primitives"]
         if len(objectlists) >= 2:
@@ -483,11 +577,11 @@ class Modeler3DLayout(Modeler):
             self.oeditor.Intersect(vArg1)
             for el in objectlists:
                 if not self.oeditor.FindObjects("Name", el):
-                    if self.primitives.isoutsideDesktop:
+                    if self.primitives.is_outside_desktop:
                         self.primitives._geometries.pop(el)
             return True
         else:
-            self._messenger.add_error_message("Input list must contain at least two elements.")
+            self.logger.error("Input list must contain at least two elements.")
             return False
 
     @aedt_exception_handler
@@ -508,6 +602,10 @@ class Modeler3DLayout(Modeler):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.Duplicate
         """
         if isinstance(objectlists, str):
             objectlists = [objectlists]
@@ -518,11 +616,11 @@ class Modeler3DLayout(Modeler):
 
     @aedt_exception_handler
     def set_temperature_dependence(
-            self,
-            include_temperature_dependence=True,
-            enable_feedback=True,
-            ambient_temp=22,
-            create_project_var=False,
+        self,
+        include_temperature_dependence=True,
+        enable_feedback=True,
+        ambient_temp=22,
+        create_project_var=False,
     ):
         """Set the temperature dependence for the design.
 
@@ -543,24 +641,31 @@ class Modeler3DLayout(Modeler):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oDesign.SetTemperatureSettings
         """
-        self._messenger.add_info_message("Set the temperature dependence for the design.")
+        self.logger.info("Set the temperature dependence for the design.")
         if create_project_var:
-            self._parent.variable_manager["$AmbientTemp"] = str(ambient_temp) + "cel"
+            self._app.variable_manager["$AmbientTemp"] = str(ambient_temp) + "cel"
             var = "$AmbientTemp"
         else:
             var = str(ambient_temp) + "cel"
         vargs1 = [
             "NAME:TemperatureSettings",
-            "IncludeTempDependence:=", include_temperature_dependence,
-            "EnableFeedback:=", enable_feedback,
-            "Temperature:=", var,
+            "IncludeTempDependence:=",
+            include_temperature_dependence,
+            "EnableFeedback:=",
+            enable_feedback,
+            "Temperature:=",
+            var,
         ]
         try:
-            self.odesign.SetTemperatureSettings(vargs1)
+            self._odesign.SetTemperatureSettings(vargs1)
         except:
-            self._messenger.add_error_message("Failed to enable the temperature dependence.")
+            self.logger.error("Failed to enable the temperature dependence.")
             return False
         else:
-            self._messenger.add_info_message("Assigned Objects Temperature")
+            self.logger.info("Assigned Objects Temperature")
             return True
