@@ -1,18 +1,22 @@
 import sys
-from collections import defaultdict
+import warnings
+import os
 
-from ..generic.general_methods import aedt_exception_handler, retry_ntimes
-from .Object3d import Padstack, Components3DLayout, Geometries3DLayout, Pins3DLayout, Nets3DLayout, _uname
-from .Primitives import default_materials
-from pyaedt import is_ironpython
-from .GeometryOperators import GeometryOperators
-import pkgutil
+from pyaedt.generic.general_methods import aedt_exception_handler, is_ironpython
+from pyaedt.modeler.Object3d import Padstack, Components3DLayout, Geometries3DLayout, Pins3DLayout, Nets3DLayout, _uname
+from pyaedt.modeler.Primitives import default_materials
+from pyaedt.modeler.GeometryOperators import GeometryOperators
 
-modules = [tup[1] for tup in pkgutil.iter_modules()]
-if "clr" in modules or is_ironpython:
+# import pkgutil
+# modules = [tup[1] for tup in pkgutil.iter_modules()]
+# if "clr" in modules or is_ironpython:
+try:
     import clr
     from System import String
     import System
+except ImportError:
+    if os.name != "posix":
+        warnings.warn("Pythonnet has to be installed to run Pyaedt")
 
 
 class Primitives3DLayout(object):
@@ -23,11 +27,16 @@ class Primitives3DLayout(object):
 
     Parameters
     ----------
-    parent : str
-        Name of the parent AEDT application.
-    modeler : str
+    modeler : :class:`pyaedt.modeler.Model3DLayout.Modeler3DLayout`
         Name of the modeler.
 
+    Examples
+    --------
+    Basic usage demonstrated with an HFSS 3D Layout design:
+
+    >>> from pyaedt import Hfss3dLayout
+    >>> aedtapp = Hfss3dLayout()
+    >>> prim = aedtapp.modeler.primitives
     """
 
     @aedt_exception_handler
@@ -50,19 +59,32 @@ class Primitives3DLayout(object):
                 return self.geometries[el]
         return None
 
-    def __init__(self, parent, modeler):
-        self._modeler = modeler
-        self._parent = parent
-        self._currentId = 0
-        self.padstacks = defaultdict(Padstack)
-        self._components = defaultdict(Components3DLayout)
-        self._geometries = defaultdict(Geometries3DLayout)
-        self._pins = defaultdict(Pins3DLayout)
-        self._nets = defaultdict(Nets3DLayout)
-        self._main = sys.modules["__main__"]
-        self.isoutsideDesktop = self._main.isoutsideDesktop
+    def __init__(self, app):
+        self.is_outside_desktop = sys.modules["__main__"].isoutsideDesktop
+        self._app = app
+        self._opadstackmanager = self._app._oproject.GetDefinitionManager().GetManager("Padstack")
+        self.padstacks = {}
+        self._components = {}
+        self._geometries = {}
+        self._pins = {}
+        self._nets = {}
         pass
 
+    @property
+    def _modeler(self):
+        return self._app.modeler
+
+    @property
+    def opadstackmanager(self):
+        """Aedt oPadstackManager.
+
+        References
+        ----------
+
+        >>> oPadstackManger = oDefinitionManager.GetManager("Padstack")
+        """
+        return self._opadstackmanager
+
     @property
     def components(self):
         """Components.
@@ -73,6 +95,9 @@ class Primitives3DLayout(object):
             List of components from EDB. If EDB is not present, ``None`` is returned.
 
         """
+        if self._primitivesDes == self._app.project_name + self._app.design_name and self._components:
+            return self._components
+        self._primitivesDes = self._app.project_name + self._app.design_name
         try:
             comps = list(self.modeler.edb.core_components.components.keys())
         except:
@@ -91,6 +116,9 @@ class Primitives3DLayout(object):
             List of geometries from EDB. If EDB is not present, ``None`` is returned.
 
         """
+        if self._primitivesDes == self._app.project_name + self._app.design_name and self._geometries:
+            return self._geometries
+        self._primitivesDes = self._app.project_name + self._app.design_name
         try:
             prims = self.modeler.edb.core_primitives.primitives
         except:
@@ -141,6 +169,9 @@ class Primitives3DLayout(object):
             List of pins from EDB. If EDB is not present, ``None`` is returned.
 
         """
+        if self._primitivesDes == self._app.project_name + self._app.design_name and self._pins:
+            return self._pins
+        self._primitivesDes = self._app.project_name + self._app.design_name
         try:
             pins_objs = list(self.modeler.edb.pins)
         except:
@@ -173,6 +204,9 @@ class Primitives3DLayout(object):
             List of nets from EDB. If EDB is not present, ``None`` is returned.
 
         """
+        if self._primitivesDes == self._app.project_name + self._app.design_name and self._nets:
+            return self._nets
+        self._primitivesDes = self._app.project_name + self._app.design_name
         try:
             nets_objs = list(self.modeler.edb.core_nets.nets)
         except:
@@ -191,12 +225,12 @@ class Primitives3DLayout(object):
             List of default materials.
 
         """
-        return default_materials[self._parent._design_type]
+        return default_materials[self._app._design_type]
 
     @property
-    def _messenger(self):
-        """Messenger."""
-        return self._parent._messenger
+    def logger(self):
+        """Logger."""
+        return self._app.logger
 
     @property
     def version(self):
@@ -208,23 +242,13 @@ class Primitives3DLayout(object):
             Version of AEDT.
 
         """
-        return self._parent._aedt_version
+        return self._app._aedt_version
 
     @property
     def modeler(self):
         """Modeler."""
         return self._modeler
 
-    @property
-    def oeditor(self):
-        """Editor."""
-        return self.modeler.oeditor
-
-    @property
-    def opadstackmanager(self):
-        """Padstack manager."""
-        return retry_ntimes(10, self._parent._oproject.GetDefinitionManager().GetManager, "Padstack")
-
     @property
     def model_units(self):
         """Model units."""
@@ -351,6 +375,10 @@ class Primitives3DLayout(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.SetNetVisible
         """
         if not netlist:
             netlist = self.nets
@@ -363,7 +391,7 @@ class Primitives3DLayout(object):
             args.append(net)
             args.append("Vis:=")
             args.append(visible)
-        self.oeditor.SetNetVisible(args)
+        self._oeditor.SetNetVisible(args)
         return True
 
     @aedt_exception_handler
@@ -410,6 +438,10 @@ class Primitives3DLayout(object):
         str
             Name of the via created when successful.
 
+        References
+        ----------
+
+        >>> oEditor.CreateVia
         """
         layers = self.modeler.layers.all_signal_layers
         if not top_layer:
@@ -419,7 +451,7 @@ class Primitives3DLayout(object):
         if not name:
             name = _uname()
         else:
-            listnames = self.oeditor.FindObjects("Name", name)
+            listnames = self._oeditor.FindObjects("Name", name)
             if listnames:
                 name = _uname(name)
         arg = ["NAME:Contents"]
@@ -430,7 +462,7 @@ class Primitives3DLayout(object):
         arg.append("vrotation:="), arg.append([str(rotation) + "deg"])
         if hole_diam:
             arg.append("overrides hole:="), arg.append(True)
-            arg.append("hole diameter:="), arg.append([self.arg_with_dim("hole_diam")])
+            arg.append("hole diameter:="), arg.append([self.arg_with_dim(hole_diam)])
 
         else:
             arg.append("overrides hole:="), arg.append(False)
@@ -439,7 +471,7 @@ class Primitives3DLayout(object):
         arg.append("Pin:="), arg.append(False)
         arg.append("highest_layer:="), arg.append(top_layer)
         arg.append("lowest_layer:="), arg.append(bot_layer)
-        self.oeditor.CreateVia(arg)
+        self._oeditor.CreateVia(arg)
         # self.objects[name] = Object3dlayout(self)
         # self.objects[name].name = name
         # if netname:
@@ -472,11 +504,15 @@ class Primitives3DLayout(object):
         str
             Name of the circle created when successful.
 
+        References
+        ----------
+
+        >>> oEditor.CreateCircle
         """
         if not name:
             name = _uname()
         else:
-            listnames = self.oeditor.FindObjects("Name", name)
+            listnames = self._oeditor.FindObjects("Name", name)
             if listnames:
                 name = _uname(name)
 
@@ -489,8 +525,8 @@ class Primitives3DLayout(object):
         vArg2.append("y:="), vArg2.append(self.arg_with_dim(y))
         vArg2.append("r:="), vArg2.append(self.arg_with_dim(radius))
         vArg1.append(vArg2)
-        self.oeditor.CreateCircle(vArg1)
-        if self.isoutsideDesktop:
+        self._oeditor.CreateCircle(vArg1)
+        if self.is_outside_desktop:
             self._geometries[name] = Geometries3DLayout(self, name)
             if netname:
                 self._geometries[name].set_net_name(netname)
@@ -523,12 +559,16 @@ class Primitives3DLayout(object):
         str
             Name of the rectangle created when successful.
 
+        References
+        ----------
+
+        >>> oEditor.CreateRectangle
         """
 
         if not name:
             name = _uname()
         else:
-            listnames = self.oeditor.FindObjects("Name", name)
+            listnames = self._oeditor.FindObjects("Name", name)
             if listnames:
                 name = _uname(name)
 
@@ -544,8 +584,8 @@ class Primitives3DLayout(object):
         vArg2.append("cr:="), vArg2.append(self.arg_with_dim(corner_radius))
         vArg2.append("ang="), vArg2.append(self.arg_with_dim(angle))
         vArg1.append(vArg2)
-        self.oeditor.CreateRectangle(vArg1)
-        if self.isoutsideDesktop:
+        self._oeditor.CreateRectangle(vArg1)
+        if self.is_outside_desktop:
             self._geometries[name] = Geometries3DLayout(self, name)
             if netname:
                 self._geometries[name].set_net_name(netname)
@@ -586,11 +626,15 @@ class Primitives3DLayout(object):
         str
             Name of the line created when successful.
 
+        References
+        ----------
+
+        >>> oEditor.CreateLine
         """
         if not name:
             name = _uname()
         else:
-            listnames = self.oeditor.FindObjects("Name", name)
+            listnames = self._oeditor.FindObjects("Name", name)
             if listnames:
                 name = _uname(name)
         arg = ["NAME:Contents", "lineGeometry:="]
@@ -616,8 +660,8 @@ class Primitives3DLayout(object):
             arg2.append("y:=")
             arg2.append(a[1])
         arg.append(arg2)
-        self.oeditor.CreateLine(arg)
-        if self.isoutsideDesktop:
+        self._oeditor.CreateLine(arg)
+        if self.is_outside_desktop:
             self._geometries[name] = Geometries3DLayout(self, name)
             if netname:
                 self._geometries[name].set_net_name(netname)
