@@ -1,67 +1,27 @@
 import random
 import warnings
-from collections import defaultdict
+import os
+import math
 
-from ..generic.general_methods import aedt_exception_handler, retry_ntimes
-from .Object3d import CircuitComponent
+from pyaedt.generic.general_methods import aedt_exception_handler, _retry_ntimes, generate_unique_name
+from pyaedt.modeler.Object3d import CircuitComponent
+from pyaedt.generic.constants import AEDT_UNITS
+from pyaedt.generic.TouchstoneParser import _parse_ports_name
 
 
 class CircuitComponents(object):
     """CircutComponents class.
 
-    This is the common class for managing all circuit components for Nexxim and Simplorer.
+    Manages all circuit components for Nexxim and Simplorer.
+
+    Examples
+    --------
+
+    >>> from pyaedt import Circuit
+    >>> aedtapp = Circuit()
+    >>> prim = aedtapp.modeler.schematic
     """
 
-    @property
-    def oeditor(self):
-        """Editor."""
-        return self.modeler.oeditor
-
-    @property
-    def _messenger(self):
-        """_messenger."""
-        return self._parent._messenger
-
-    @property
-    def version(self):
-        """Version."""
-        return self._parent._aedt_version
-
-    @property
-    def design_types(self):
-        """Design types."""
-        return self._parent._modeler
-
-    @property
-    def model_units(self):
-        """Model units."""
-        return self.modeler.model_units
-
-    @property
-    def o_model_manager(self):
-        """Model manager."""
-        return self.modeler.o_model_manager
-
-    @property
-    def o_definition_manager(self):
-        """Definition manager."""
-        return self._parent._oproject.GetDefinitionManager()
-
-    @property
-    def o_symbol_manager(self):
-        """Symbol manager."""
-        return self.o_definition_manager.GetManager("Symbol")
-
-    @property
-    def o_component_manager(self):
-        """Component manager."""
-        return self.o_definition_manager.GetManager("Component")
-
-    @property
-    def design_type(self):
-        """Design type."""
-        return self._parent.design_type
-
     @aedt_exception_handler
     def __getitem__(self, partname):
         """Retrieve a part.
@@ -76,7 +36,7 @@ class CircuitComponents(object):
         type
             Part object details.
         """
-        if type(partname) is int:
+        if isinstance(partname, int):
             return self.components[partname]
         for el in self.components:
             if self.components[el].name == partname or self.components[el].composed_name == partname or el == partname:
@@ -84,13 +44,103 @@ class CircuitComponents(object):
 
         return None
 
-    def __init__(self, parent, modeler):
-        self._parent = parent
-        self.modeler = modeler
+    def __init__(self, modeler):
+        self._app = modeler._app
+        self._modeler = modeler
+        self.logger = self._app.logger
+        self.o_model_manager = self._modeler.o_model_manager
+
+        self._o_definition_manager = self._app._oproject.GetDefinitionManager()
+        self._o_symbol_manager = self.o_definition_manager.GetManager("Symbol")
+        self._o_component_manager = self.o_definition_manager.GetManager("Component")
+        self._oeditor = self._modeler.oeditor
         self._currentId = 0
-        self.components = defaultdict(CircuitComponent)
+        self.components = {}
+        self.refresh_all_ids()
+        self.current_position = [0, 0]
+        self.increment_mils = [1000, 1000]
+        self.limits_mils = 20000
         pass
 
+    @property
+    def o_definition_manager(self):
+        """Aedt oDefinitionManager.
+
+        References
+        ----------
+
+        >>> oDefinitionManager = oProject.GetDefinitionManager()
+        """
+        return self._o_definition_manager
+
+    @property
+    def o_component_manager(self):
+        """Aedt oComponentManager.
+
+        References
+        ----------
+
+        >>> oComponentManager = oDefinitionManager.GetManager("Component")
+        """
+        return self._o_component_manager
+
+    @property
+    def o_symbol_manager(self):
+        """Aedt oSymbolManger.
+
+        References
+        ----------
+
+        >>> oSymbolManger = oDefinitionManager.GetManager("Symbol")
+        """
+        return self._o_symbol_manager
+
+    @property
+    def version(self):
+        """Version."""
+        return self._app._aedt_version
+
+    @property
+    def design_types(self):
+        """Design types."""
+        return self._app._modeler
+
+    @property
+    def model_units(self):
+        """Model units."""
+        return self._modeler.model_units
+
+    @property
+    def design_type(self):
+        """Design type."""
+        return self._app.design_type
+
+    @property
+    def nets(self):
+        """List of all schematic nets."""
+        nets_comp = self._oeditor.GetAllNets()
+        nets = []
+        for net in nets_comp:
+            v = net.split(";")
+            if v[0].replace("Wire@", "") not in nets:
+                nets.append(v[0].replace("Wire@", ""))
+        return nets
+
+    @aedt_exception_handler
+    def _get_location(self, location=None):
+        if not location:
+            xpos = self.current_position[0]
+            ypos = self.current_position[1]
+            self.current_position[1] += AEDT_UNITS["Length"]["mil"] * self.increment_mils[1]
+            if self.current_position[1] > self.limits_mils:
+                self.current_position[1] = 0
+                self.current_position[0] += AEDT_UNITS["Length"]["mil"] * self.increment_mils[0]
+        else:
+            xpos = location[0]
+            ypos = location[1]
+            self.current_position = location
+        return xpos, ypos
+
     @aedt_exception_handler
     def create_unique_id(self):
         """Create an unique ID.
@@ -121,9 +171,13 @@ class CircuitComponents(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.CreateWire
         """
         pointlist = [str(tuple(i)) for i in points_array]
-        self.oeditor.CreateWire(
+        self._oeditor.CreateWire(
             ["NAME:WireData", "Name:=", "", "Id:=", random.randint(20000, 23000), "Points:=", pointlist],
             ["NAME:Attributes", "Page:=", 1],
         )
@@ -134,110 +188,121 @@ class CircuitComponents(object):
         """Create an interface port.
 
         .. deprecated:: 0.4.0
-           Use :func:`Circuit.modeler.components.create_interface_port` instead.
+           Use :func:`Circuit.modeler.schematic.create_interface_port` instead.
         """
         warnings.warn("`create_iport` is deprecated. Use `create_interface_port` instead.", DeprecationWarning)
         return self.create_interface_port(name, posx, posy, angle)
 
     @aedt_exception_handler
-    def create_interface_port(self, name, posx=0.1, posy=0.1, angle=0):
+    def create_interface_port(self, name, location=[], angle=0):
         """Create an interface port.
 
         Parameters
         ----------
         name : str
             Name of the port.
-        posx : float, optional
-            Position on the X axis. The default is ``0.1``.
-        posy : float, optional
-            Position on the Y axis. The default is ``0.1``.
+        location : list, optional
+            Position on the X and Y axis. The default is ``None``.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
 
         Returns
         -------
-        type
-            Port object.
-        str
-            Port name.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateIPort
         """
+        if location:
+            posx, posy = location[0], location[1]
+        else:
+            posx, posy = self._get_location(location)
         id = self.create_unique_id()
         arg1 = ["NAME:IPortProps", "Name:=", name, "Id:=", id]
         arg2 = ["NAME:Attributes", "Page:=", 1, "X:=", posx, "Y:=", posy, "Angle:=", angle, "Flip:=", False]
-        id = self.oeditor.CreateIPort(arg1, arg2)
+        id = self._oeditor.CreateIPort(arg1, arg2)
 
         id = int(id.split(";")[1])
         self.add_id_to_component(id)
         # return id, self.components[id].composed_name
         for el in self.components:
             if name in self.components[el].composed_name:
-                return el, self.components[el].composed_name
+                return self.components[el]
+        return False
 
     @aedt_exception_handler
-    def create_page_port(self, name, posx=0.1, posy=0.1, angle=0):
+    def create_page_port(self, name, location=[], angle=0):
         """Create a page port.
 
         Parameters
         ----------
         name : str
             Name of the port.
-        posx : float, optional
-            Position on the X axis. The default is ``0.1``.
-        posy : float, optional
-            Position on the Y axis. The default is ``0.1``.
+        location : list, optional
+            Position on the X and Y axis. The default is ``None``.
         angle : optional
             Angle rotation in degrees. The default is ``0``.
 
         Returns
         -------
-        type
-            Port ID.
-        str
-            Port name.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreatePagePort
         """
+        if location:
+            xpos, ypos = location[0], location[1]
+        else:
+            xpos, ypos = self._get_location(location)
+
         id = self.create_unique_id()
-        id = self.oeditor.CreatePagePort(
+        id = self._oeditor.CreatePagePort(
             ["NAME:PagePortProps", "Name:=", name, "Id:=", id],
-            ["NAME:Attributes", "Page:=", 1, "X:=", posx, "Y:=", posy, "Angle:=", angle, "Flip:=", False],
+            ["NAME:Attributes", "Page:=", 1, "X:=", xpos, "Y:=", ypos, "Angle:=", angle, "Flip:=", False],
         )
         id = int(id.split(";")[1])
         # self.refresh_all_ids()
         self.add_id_to_component(id)
-        return id, self.components[id].composed_name
+        return self.components[id]
 
     @aedt_exception_handler
-    def create_gnd(self, posx, posy):
+    def create_gnd(self, location=[]):
         """Create a ground.
 
         Parameters
         ----------
-        posx : float, optional
-            Position on the X axis. The default is ``0.1``.
-        posy : float, optional
-            Position on the Y axis. The default is ``0.1``.
+        location : list, optional
+            Position on the X and Y axis. The default is ``None``.
 
         Returns
         -------
-        type
-            Ground object.
-        str
-            Ground name.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateGround
         """
+        xpos, ypos = self._get_location(location)
         id = self.create_unique_id()
 
-        name = self.oeditor.CreateGround(
+        name = self._oeditor.CreateGround(
             ["NAME:GroundProps", "Id:=", id],
-            ["NAME:Attributes", "Page:=", 1, "X:=", posx, "Y:=", posy, "Angle:=", 0, "Flip:=", False],
+            ["NAME:Attributes", "Page:=", 1, "X:=", xpos, "Y:=", ypos, "Angle:=", 0, "Flip:=", False],
         )
         id = int(name.split(";")[1])
         self.add_id_to_component(id)
         # return id, self.components[id].composed_name
         for el in self.components:
             if name in self.components[el].composed_name:
-                return el, self.components[el].composed_name
+                return self.components[el]
 
     @aedt_exception_handler
     def create_model_from_touchstone(self, touchstone_full_path, model_name=None):
@@ -252,14 +317,27 @@ class CircuitComponents(object):
 
         Returns
         -------
-        bool
-            ``True`` when successful, ``False`` when failed.
+        str
+            Model name when successfully created. ``False`` if something went wrong.
 
+        References
+        ----------
+
+        >>> oModelManager.Add
+        >>> oComponentManager.Add
         """
         if not model_name:
             model_name = os.path.splitext(os.path.basename(touchstone_full_path))[0]
-
+        if model_name in list(self.o_model_manager.GetNames()):
+            model_name = generate_unique_name(model_name, n=2)
         num_terminal = int(touchstone_full_path[-2:-1])
+        with open(touchstone_full_path, "r") as f:
+            port_names = _parse_ports_name(f)
+        image_subcircuit_path = os.path.normpath(
+            os.path.join(self._modeler._app.desktop_install_dir, "syslib", "Bitmaps", "nport.bmp")
+        )
+        if not port_names:
+            port_names = ["Port" + str(i + 1) for i in range(num_terminal)]
         arg = [
             "NAME:" + model_name,
             "Name:=",
@@ -275,7 +353,7 @@ class CircuitComponents(object):
             "Description:=",
             "",
             "ImageFile:=",
-            "",
+            image_subcircuit_path,
             "SymbolPinConfiguration:=",
             0,
             ["NAME:PortInfoBlk"],
@@ -289,7 +367,7 @@ class CircuitComponents(object):
             "sssmodel:=",
             False,
             "PortNames:=",
-            ["Port" + str(i + 1) for i in range(num_terminal)],
+            port_names,
             "domain:=",
             "frequency",
             "datamode:=",
@@ -423,9 +501,9 @@ class CircuitComponents(object):
         ]
         for i in range(num_terminal):
             arg.append("Terminal:=")
-            arg.append(["Port" + str(i + 1), "Port" + str(i + 1), "A", False, i + 6, 1, "", "Electrical", "0"])
+            arg.append([port_names[i], port_names[i], "A", False, i, 1, "", "Electrical", "0"])
         arg.append("CompExtID:=")
-        arg.append(num_terminal)
+        arg.append(5)
         arg.append(
             [
                 "NAME:Parameters",
@@ -461,41 +539,79 @@ class CircuitComponents(object):
         )
 
         self.o_component_manager.Add(arg)
+        return model_name
 
     @aedt_exception_handler
     def create_component_from_touchstonmodel(
         self,
-        modelname,
-        xpos=0.1,
-        ypos=0.1,
+        model_name,
+        location=[],
+        angle=0,
+    ):
+        """Create a component from a Touchstone model.
+
+        .. deprecated:: 0.4.14
+           Use :func:`create_touchsthone_component` instead.
+
+        Parameters
+        ----------
+        model_name : str
+            Name of the Touchstone model or full path to touchstone file.
+            If full touchstone is provided then, new model will be created.
+        location : list of float, optional
+            Position on the X  and Y axis.
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+
+        Returns
+        -------
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
+
+        """
+        return self.create_touchsthone_component(model_name, location, angle)
+
+    @aedt_exception_handler
+    def create_touchsthone_component(
+        self,
+        model_name,
+        location=[],
         angle=0,
     ):
         """Create a component from a Touchstone model.
 
         Parameters
         ----------
-        modelname : str
-            Name of the Touchstone model.
-        xpos : float, optional
-            Position on the X axis. The default is ``0.1``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0.1``.
+        model_name : str
+            Name of the Touchstone model or full path to touchstone file.
+            If full touchstone is provided then, new model will be created.
+        location : list of float, optional
+            Position on the X  and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
 
         Returns
         -------
-        bool
-            ``True`` when successful, ``False`` when failed.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oModelManager.Add
+        >>> oComponentManager.Add
+        >>> oEditor.CreateComponent
         """
+        xpos, ypos = self._get_location(location)
         id = self.create_unique_id()
-        arg1 = ["NAME:ComponentProps", "Name:=", modelname, "Id:=", str(id)]
+        if os.path.exists(model_name):
+            model_name = self.create_model_from_touchstone(model_name)
+        arg1 = ["NAME:ComponentProps", "Name:=", model_name, "Id:=", str(id)]
         arg2 = ["NAME:Attributes", "Page:=", 1, "X:=", xpos, "Y:=", ypos, "Angle:=", angle, "Flip:=", False]
-        id = retry_ntimes(10, self.oeditor.CreateComponent, arg1, arg2)
+        id = _retry_ntimes(10, self._oeditor.CreateComponent, arg1, arg2)
         id = int(id.split(";")[1])
         self.add_id_to_component(id)
-        return id, self.components[id].composed_name
+        return self.components[id]
 
     @aedt_exception_handler
     def create_component(
@@ -503,8 +619,7 @@ class CircuitComponents(object):
         inst_name=None,
         component_library="Resistors",
         component_name="RES_",
-        xpos=0.1,
-        ypos=0.1,
+        location=[],
         angle=0,
         use_instance_id_netlist=False,
         global_netlist_list=[],
@@ -519,10 +634,8 @@ class CircuitComponents(object):
             Name of the component library. The default is ``"Resistors"``.
         component_name : str, optional
             Name of component in the library. The default is ``"RES"``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0.1``.
-        yos : float, optional
-            Position on the Y axis. The default is ``0.1``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -533,11 +646,13 @@ class CircuitComponents(object):
 
         Returns
         -------
-        type
-            Component ID.
-        str
-            Component name.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
         id = self.create_unique_id()
         if component_library:
@@ -545,8 +660,10 @@ class CircuitComponents(object):
         else:
             name = component_name
         arg1 = ["NAME:ComponentProps", "Name:=", name, "Id:=", str(id)]
+        xpos, ypos = self._get_location(location)
+
         arg2 = ["NAME:Attributes", "Page:=", 1, "X:=", xpos, "Y:=", ypos, "Angle:=", angle, "Flip:=", False]
-        id = retry_ntimes(10, self.oeditor.CreateComponent, arg1, arg2)
+        id = _retry_ntimes(10, self._oeditor.CreateComponent, arg1, arg2)
         id = int(id.split(";")[1])
         # self.refresh_all_ids()
         self.add_id_to_component(id)
@@ -556,7 +673,7 @@ class CircuitComponents(object):
             self.enable_use_instance_name(component_library, component_name)
         elif global_netlist_list:
             self.enable_global_netlist(component_name, global_netlist_list)
-        return id, self.components[id].composed_name
+        return self.components[id]
 
     @aedt_exception_handler
     def disable_data_netlist(self, component_name):
@@ -572,6 +689,11 @@ class CircuitComponents(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oComponentManager.GetData
+        >>> oComponentManager.Edit
         """
         name = component_name
 
@@ -604,6 +726,11 @@ class CircuitComponents(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oComponentManager.GetData
+        >>> oComponentManager.Edit
         """
         name = component_name
 
@@ -615,7 +742,7 @@ class CircuitComponents(object):
                     nexxim_data = list(nexxim[nexxim.index(el) + 1])
                     nexxim_data[1] = "\n".join(global_netlist_list).replace("\\", "/")
                     nexxim[nexxim.index(el) + 1] = nexxim_data
-        retry_ntimes(
+        _retry_ntimes(
             10,
             self.o_component_manager.Edit,
             name,
@@ -639,6 +766,10 @@ class CircuitComponents(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oSymbolManager.Add
         """
 
         numpins = len(pin_lists)
@@ -687,7 +818,7 @@ class CircuitComponents(object):
             "InitialLevels:=",
             [0, 1],
         ]
-        oDefinitionEditor = self._parent._oproject.SetActiveDefinitionEditor("SymbolEditor", symbol_name)
+        oDefinitionEditor = self._app._oproject.SetActiveDefinitionEditor("SymbolEditor", symbol_name)
         id = 2
         oDefinitionEditor.CreateRectangle(
             [
@@ -731,7 +862,7 @@ class CircuitComponents(object):
             if i == (h + r):
                 yp = 0.00254 * (h + 2)
                 xp = 0.00762
-                angle = 3.14159265358979
+                angle = math.pi
             else:
                 yp -= 0.00254
             id += 2
@@ -770,6 +901,11 @@ class CircuitComponents(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oComponentManager.Add
         """
         arg = [
             "NAME:" + symbol_name,
@@ -837,7 +973,7 @@ class CircuitComponents(object):
         arg.append(1)
         arg2 = ["NAME:Parameters"]
         for el, val in zip(parameter_list, parameter_value):
-            if type(val) is str:
+            if isinstance(val, str):
                 arg2.append("TextValueProp:=")
                 arg2.append([el, "D", "", val])
             else:
@@ -896,6 +1032,12 @@ class CircuitComponents(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oComponentManager.GetData
+        >>> oComponentManager.Edit
         """
         if component_library:
             name = self.design_libray + "\\" + component_library + ":" + component_name
@@ -916,7 +1058,7 @@ class CircuitComponents(object):
                 elif el == "GRef:=":
                     nexxim_data = list(nexxim[nexxim.index(el) + 1])
                     nexxim[nexxim.index(el) + 1] = nexxim_data
-        retry_ntimes(
+        _retry_ntimes(
             10,
             self.o_component_manager.Edit,
             name,
@@ -926,18 +1068,27 @@ class CircuitComponents(object):
 
     @aedt_exception_handler
     def refresh_all_ids(self):
-        """Refresh all IDs and return the number of components."""
-        obj = self.oeditor.GetAllComponents()
+        """Refresh all IDs and return the number of components.
+
+        References
+        ----------
+
+        >>> oEditor.GetAllElements()"""
+        obj = self._oeditor.GetAllElements()
+        obj = [i for i in obj if "Wire" not in i[:4]]
         for el in obj:
             if not self.get_obj_id(el):
                 name = el.split(";")
-                o = CircuitComponent(self.oeditor, tabname=self.tab_name)
-                o.name = name[0]
-                o.id = int(name[1])
-                o.schematic_id = name[2]
-                o_update = self.update_object_properties(o)
-                objID = o.id
-                self.components[objID] = o_update
+                if len(name) > 1:
+                    o = CircuitComponent(self, tabname=self.tab_name)
+                    o.name = name[0]
+                    if len(name) == 2:
+                        o.schematic_id = name[1]
+                    else:
+                        o.id = int(name[1])
+                        o.schematic_id = name[2]
+                    objID = o.id
+                    self.components[objID] = o
         return len(self.components)
 
     @aedt_exception_handler
@@ -955,11 +1106,11 @@ class CircuitComponents(object):
             Number of components.
 
         """
-        obj = retry_ntimes(10, self.oeditor.GetAllElements)
+        obj = _retry_ntimes(10, self._oeditor.GetAllElements)
         for el in obj:
             name = el.split(";")
             if len(name) > 1 and str(id) == name[1]:
-                o = CircuitComponent(self.oeditor, tabname=self.tab_name)
+                o = CircuitComponent(self, tabname=self.tab_name)
                 o.name = name[0]
                 if len(name) > 2:
                     o.id = int(name[1])
@@ -968,9 +1119,8 @@ class CircuitComponents(object):
                 else:
                     o.schematic_id = int(name[1])
                     objID = o.schematic_id
-                o_update = self.update_object_properties(o)
+                self.components[objID] = o
 
-                self.components[objID] = o_update
         return len(self.components)
 
     @aedt_exception_handler
@@ -992,28 +1142,6 @@ class CircuitComponents(object):
                 return el
         return None
 
-    @aedt_exception_handler
-    def update_object_properties(self, o):
-        """Update the properties of an object.
-
-        Parameters
-        ----------
-        o :
-            Object to update.
-
-        Returns
-        -------
-        type
-            Object with properties.
-
-        """
-        name = o.composed_name
-        proparray = retry_ntimes(10, self.oeditor.GetProperties, "PassedParameterTab", name)
-        for j in proparray:
-            propval = retry_ntimes(10, self.oeditor.GetPropertyValue, "PassedParameterTab", name, j)
-            o._add_property(j, propval)
-        return o
-
     @aedt_exception_handler
     def get_pins(self, partid):
         """Retrieve one or more pins.
@@ -1028,12 +1156,18 @@ class CircuitComponents(object):
         type
             Pin with properties.
 
+        References
+        ----------
+
+        >>> oEditor.GetComponentPins
         """
-        if type(partid) is str:
-            pins = retry_ntimes(10, self.oeditor.GetComponentPins, partid)
+        if isinstance(partid, CircuitComponent):
+            pins = _retry_ntimes(10, self._oeditor.GetComponentPins, partid.composed_name)
+        elif isinstance(partid, str):
+            pins = _retry_ntimes(10, self._oeditor.GetComponentPins, partid)
             # pins = self.oeditor.GetComponentPins(partid)
         else:
-            pins = retry_ntimes(10, self.oeditor.GetComponentPins, self.components[partid].composed_name)
+            pins = _retry_ntimes(10, self._oeditor.GetComponentPins, self.components[partid].composed_name)
             # pins = self.oeditor.GetComponentPins(self.components[partid].composed_name)
         return list(pins)
 
@@ -1053,16 +1187,20 @@ class CircuitComponents(object):
         List
             List of axis values ``[x, y]``.
 
+        References
+        ----------
+
+        >>> oEditor.GetComponentPinLocation
         """
-        if type(partid) is str:
-            x = retry_ntimes(30, self.oeditor.GetComponentPinLocation, partid, pinname, True)
-            y = retry_ntimes(30, self.oeditor.GetComponentPinLocation, partid, pinname, False)
+        if isinstance(partid, str):
+            x = _retry_ntimes(30, self._oeditor.GetComponentPinLocation, partid, pinname, True)
+            y = _retry_ntimes(30, self._oeditor.GetComponentPinLocation, partid, pinname, False)
         else:
-            x = retry_ntimes(
-                30, self.oeditor.GetComponentPinLocation, self.components[partid].composed_name, pinname, True
+            x = _retry_ntimes(
+                30, self._oeditor.GetComponentPinLocation, self.components[partid].composed_name, pinname, True
             )
-            y = retry_ntimes(
-                30, self.oeditor.GetComponentPinLocation, self.components[partid].composed_name, pinname, False
+            y = _retry_ntimes(
+                30, self._oeditor.GetComponentPinLocation, self.components[partid].composed_name, pinname, False
             )
         return [x, y]
 
@@ -1083,7 +1221,7 @@ class CircuitComponents(object):
 
 
         """
-        if type(Value) is str:
+        if isinstance(Value, str):
             val = Value
         else:
             if sUnits is None:
