@@ -1,7 +1,9 @@
 import warnings
+import os
 
-from ..generic.general_methods import aedt_exception_handler, retry_ntimes
-from .PrimitivesCircuit import CircuitComponents
+from pyaedt.generic.general_methods import aedt_exception_handler
+from pyaedt.modeler.PrimitivesCircuit import CircuitComponents
+from pyaedt.modeler.Object3d import CircuitComponent
 
 
 class NexximComponents(CircuitComponents):
@@ -9,10 +11,14 @@ class NexximComponents(CircuitComponents):
 
     Parameters
     ----------
-    parent :
+    modeler : :class:`pyaedt.modeler.Circuit.ModelerNexxim`
         Inherited parent object.
-    modeler :
+    Examples
+    --------
 
+    >>> from pyaedt import Circuit
+    >>> aedtapp = Circuit()
+    >>> prim = aedtapp.modeler.schematic
     """
 
     @property
@@ -35,8 +41,8 @@ class NexximComponents(CircuitComponents):
 
         Returns
         -------
-        type
-            Part object details.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
         """
         if type(partname) is int:
             return self.components[partname]
@@ -46,19 +52,95 @@ class NexximComponents(CircuitComponents):
 
         return None
 
-    def __init__(self, parent, modeler):
-        CircuitComponents.__init__(self, parent, modeler)
-        self._parent = parent
-        self.modeler = modeler
+    def __init__(self, modeler):
+        CircuitComponents.__init__(self, modeler)
+        self._app = modeler._app
+        self._modeler = modeler
         self._currentId = 0
         pass
 
+    @aedt_exception_handler
+    def connect_components_in_series(self, components_to_connect):
+        """Connect schematic components in series.
+
+        Parameters
+        ----------
+        components_to_connect : list of :class:`pyaedt.modeler.Object3d.CircuitComponent`
+           List of Components to connect. It can be a list of objects or component names.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        Examples
+        --------
+        >>> from pyaedt import Circuit
+        >>> circuit = Circuit()
+        >>> myind = circuit.modeler.schematic.create_inductor(compname="L100", value=1e-9, location=[0,0])
+        >>> myres = circuit.modeler.schematic.create_resistor(compname="R100", value=50, location=[0.002, 0.05])
+        >>> circuit.modeler.schematic.connect_components_in_series([myind, myres])
+        """
+        comps = []
+        for component in components_to_connect:
+            if isinstance(component, CircuitComponent):
+                comps.append(component)
+            else:
+                for id, cmp in self.components.items():
+                    if component in [cmp.id, cmp.name, cmp.composed_name]:
+                        comps.append(cmp)
+                        break
+        i = 0
+        assert len(comps) > 1, "At least two components have to be passed."
+        while i < (len(comps) - 1):
+            comps[i].pins[-1].connect_to_component(comps[i + 1].pins[0])
+            i += 1
+        return True
+
+    @aedt_exception_handler
+    def connect_components_in_parallel(self, components_to_connect):
+        """Connect schematic components in parallel.
+
+        Parameters
+        ----------
+        components_to_connect : list of :class:`pyaedt.modeler.Object3d.CircuitComponent`
+           List of Components to connect. It can be a list of objects or component names.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        Examples
+        --------
+        >>> from pyaedt import Circuit
+        >>> circuit = Circuit()
+        >>> myind = circuit.modeler.schematic.create_inductor("L100", 1e-9)
+        >>> myres = circuit.modeler.schematic.create_resistor("R100", 50)
+        >>> circuit.modeler.schematic.connect_components_in_parallel([myind, myres.composed_name])
+        """
+        comps = []
+        for component in components_to_connect:
+            if isinstance(component, CircuitComponent):
+                comps.append(component)
+            else:
+                for id, cmp in self.components.items():
+                    if component in [cmp.id, cmp.name, cmp.composed_name]:
+                        comps.append(cmp)
+                        break
+        assert len(comps) > 1, "At least two components have to be passed."
+        comps[0].pins[0].connect_to_component([i.pins[0] for i in comps[1:]])
+        terminal_to_connect = [cmp for cmp in comps if len(cmp.pins) >= 2]
+        if len(terminal_to_connect) > 1:
+            terminal_to_connect[0].pins[1].connect_to_component([i.pins[1] for i in terminal_to_connect[1:]])
+        return True
+
     @aedt_exception_handler
     def create_3dlayout_subcircuit(self, sourcename):
         """Add a subcircuit from a HFSS 3DLayout.
 
         .. deprecated:: 0.4.0
-           Use :func:`Circuit.modeler.components.add_subcircuit_3dlayout` instead.
+           Use :func:`Circuit.modeler.schematic.add_subcircuit_3dlayout` instead.
         """
         warnings.warn(
             "`create_3dlayout_subcircuit` is deprecated. Use `add_subcircuit_3dlayout` instead.", DeprecationWarning
@@ -76,16 +158,23 @@ class NexximComponents(CircuitComponents):
 
         Returns
         -------
-        type
-            el, composed_name if succeeded or False
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oProject.CopyDesign
+        >>> oEditor.PasteDesign
         """
-        self._parent._oproject.CopyDesign(sourcename)
-        self.oeditor.PasteDesign(0, ["NAME:Attributes", "Page:=", 1, "X:=", 0, "Y:=", 0, "Angle:=", 0, "Flip:=", False])
+        self._app._oproject.CopyDesign(sourcename)
+        self._oeditor.PasteDesign(
+            0, ["NAME:Attributes", "Page:=", 1, "X:=", 0, "Y:=", 0, "Angle:=", 0, "Flip:=", False]
+        )
         self.refresh_all_ids()
         for el in self.components:
             if sourcename in self.components[el].composed_name:
-                return el, self.components[el].composed_name
+                return self.components[el]
         return False
 
     @aedt_exception_handler
@@ -112,6 +201,11 @@ class NexximComponents(CircuitComponents):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModelManager.Add
+        >>> oComponentManager.Add
         """
         id = self.create_unique_id()
         component_name = design_name + "_" + str(id)
@@ -332,7 +426,7 @@ class NexximComponents(CircuitComponents):
         )
 
         self.o_component_manager.Add(arg)
-        self._parent.odesign.AddCompInstance(component_name)
+        self._app._odesign.AddCompInstance(component_name)
         self.refresh_all_ids()
         for el in self.components:
             if component_name in self.components[el].composed_name:
@@ -340,7 +434,7 @@ class NexximComponents(CircuitComponents):
         return False
 
     @aedt_exception_handler
-    def create_resistor(self, compname=None, value=50, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
+    def create_resistor(self, compname=None, value=50, location=[], angle=0, use_instance_id_netlist=False):
         """Create a resistor.
 
         Parameters
@@ -349,10 +443,8 @@ class NexximComponents(CircuitComponents):
             Name of the resistor. The default is ``None``.
         value : float, optional
             Resistance in ohms. The default is ``50``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -361,21 +453,23 @@ class NexximComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the resistor.
-        str
-            Name of the resistor.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        cmpid, cmpname = self.create_component(
-            compname, xpos=xpos, ypos=ypos, angle=angle, use_instance_id_netlist=use_instance_id_netlist
+        cmpid = self.create_component(
+            compname, location=location, angle=angle, use_instance_id_netlist=use_instance_id_netlist
         )
 
-        self.components[cmpid].set_property("R", value)
-        return cmpid, cmpname
+        cmpid.set_property("R", value)
+        return cmpid
 
     @aedt_exception_handler
-    def create_inductor(self, compname=None, value=50, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
+    def create_inductor(self, compname=None, value=50, location=[], angle=0, use_instance_id_netlist=False):
         """Create an inductor.
 
         Parameters
@@ -384,10 +478,8 @@ class NexximComponents(CircuitComponents):
             Name of the inductor. The default is ``None``.
         value : float, optional
             Inductance value. The default is ``50``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the X axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -396,28 +488,29 @@ class NexximComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the inductor.
-        str
-            Name of the inductor.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        cmpid, cmpname = self.create_component(
+        cmpid = self.create_component(
             compname,
             component_library="Inductors",
             component_name="IND_",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
 
-        self.components[cmpid].set_property("L", value)
+        cmpid.set_property("L", value)
 
-        return cmpid, cmpname
+        return cmpid
 
     @aedt_exception_handler
-    def create_capacitor(self, compname=None, value=50, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
+    def create_capacitor(self, compname=None, value=50, location=[], angle=0, use_instance_id_netlist=False):
         """Create a capacitor.
 
         Parameters
@@ -426,10 +519,8 @@ class NexximComponents(CircuitComponents):
             Name of the capacitor. The default is ``None``.
         value : float, optional
             Capacitor value. The default is ``50``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -438,27 +529,28 @@ class NexximComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the capacitor.
-        str
-            Name of the capacitor.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        cmpid, cmpname = self.create_component(
+        cmpid = self.create_component(
             compname,
             component_library="Capacitors",
             component_name="CAP_",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
 
-        self.components[cmpid].set_property("C", value)
-        return cmpid, cmpname
+        cmpid.set_property("C", value)
+        return cmpid
 
     @aedt_exception_handler
-    def create_voltage_dc(self, compname=None, value=1, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
+    def create_voltage_dc(self, compname=None, value=1, location=[], angle=0, use_instance_id_netlist=False):
         """Create a voltage DC source.
 
         Parameters
@@ -467,9 +559,8 @@ class NexximComponents(CircuitComponents):
             Name of the voltage DC source. The default is ``None``.
         value : float, optional
             Voltage value. The default is ``50``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -478,29 +569,28 @@ class NexximComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the voltage DC source.
-        str
-            Name of the voltage DC source.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        cmpid, cmpname = self.create_component(
+        cmpid = self.create_component(
             compname,
             component_library="Independent Sources",
             component_name="V_DC",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
 
-        self.components[cmpid].set_property("DC", value)
-        return cmpid, cmpname
+        cmpid.set_property("DC", value)
+        return cmpid
 
     @aedt_exception_handler
-    def create_current_pulse(
-        self, compname=None, value_lists=[], xpos=0, ypos=0, angle=0, use_instance_id_netlist=False
-    ):
+    def create_current_pulse(self, compname=None, value_lists=[], location=[], angle=0, use_instance_id_netlist=False):
         """Create a current pulse.
 
         Parameters
@@ -509,10 +599,8 @@ class NexximComponents(CircuitComponents):
             Name of the current pulse. The default is ``None``.
         value_lists : list, optional
             List of values for the current pulse. The default is ``[]``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -521,43 +609,42 @@ class NexximComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the current pulse.
-        str
-            Name of the current pulse.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        cmpid, cmpname = self.create_component(
+        cmpid = self.create_component(
             compname,
             component_library="Independent Sources",
             component_name="I_PULSE",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
 
         if len(value_lists) > 0:
-            self.components[cmpid].set_property("I1", value_lists[0])
+            cmpid.set_property("I1", value_lists[0])
         if len(value_lists) > 1:
-            self.components[cmpid].set_property("I2", value_lists[1])
+            cmpid.set_property("I2", value_lists[1])
         if len(value_lists) > 2:
-            self.components[cmpid].set_property("TD", value_lists[2])
+            cmpid.set_property("TD", value_lists[2])
         if len(value_lists) > 3:
-            self.components[cmpid].set_property("TR", value_lists[3])
+            cmpid.set_property("TR", value_lists[3])
         if len(value_lists) > 4:
-            self.components[cmpid].set_property("TF", value_lists[4])
+            cmpid.set_property("TF", value_lists[4])
         if len(value_lists) > 5:
-            self.components[cmpid].set_property("PW", value_lists[5])
+            cmpid.set_property("PW", value_lists[5])
         if len(value_lists) > 6:
-            self.components[cmpid].set_property("PER", value_lists[6])
+            cmpid.set_property("PER", value_lists[6])
 
-        return cmpid, cmpname
+        return cmpid
 
     @aedt_exception_handler
-    def create_voltage_pulse(
-        self, compname=None, value_lists=[], xpos=0, ypos=0, angle=0, use_instance_id_netlist=False
-    ):
+    def create_voltage_pulse(self, compname=None, value_lists=[], location=[], angle=0, use_instance_id_netlist=False):
         """Create a voltage pulse.
 
         Parameters
@@ -566,10 +653,8 @@ class NexximComponents(CircuitComponents):
             Name of the voltage pulse. The default is ``None``.
         value_lists : list, optional
             List of values for the voltage pulse. The default is ``[]``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -578,41 +663,42 @@ class NexximComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the voltage pulse.
-        str
-            Name of the voltage pulse.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        cmpid, cmpname = self.create_component(
+        cmpid = self.create_component(
             compname,
             component_library="Independent Sources",
             component_name="V_PULSE",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
 
         if len(value_lists) > 0:
-            self.components[cmpid].set_property("V1", value_lists[0])
+            cmpid.set_property("V1", value_lists[0])
         if len(value_lists) > 1:
-            self.components[cmpid].set_property("V2", value_lists[1])
+            cmpid.set_property("V2", value_lists[1])
         if len(value_lists) > 2:
-            self.components[cmpid].set_property("TD", value_lists[2])
+            cmpid.set_property("TD", value_lists[2])
         if len(value_lists) > 3:
-            self.components[cmpid].set_property("TR", value_lists[3])
+            cmpid.set_property("TR", value_lists[3])
         if len(value_lists) > 4:
-            self.components[cmpid].set_property("TF", value_lists[4])
+            cmpid.set_property("TF", value_lists[4])
         if len(value_lists) > 5:
-            self.components[cmpid].set_property("PW", value_lists[5])
+            cmpid.set_property("PW", value_lists[5])
         if len(value_lists) > 6:
-            self.components[cmpid].set_property("PER", value_lists[6])
+            cmpid.set_property("PER", value_lists[6])
 
-        return cmpid, cmpname
+        return cmpid
 
     @aedt_exception_handler
-    def create_current_dc(self, compname=None, value=1, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
+    def create_current_dc(self, compname=None, value=1, location=[], angle=0, use_instance_id_netlist=False):
         """Create a current DC source.
 
         Parameters
@@ -621,10 +707,8 @@ class NexximComponents(CircuitComponents):
             Name of the current DC source. The default is ``None``.
         value : float, optional
             Current value. The default is ``1``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -633,28 +717,27 @@ class NexximComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the current DC source.
-        str
-            Name of the current DC source.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        cmpid, cmpname = self.create_component(
+        cmpid = self.create_component(
             compname,
             component_library="Independent Sources",
             component_name="I_DC",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
 
-        self.components[cmpid].set_property("DC", value)
-        return cmpid, cmpname
+        cmpid.set_property("DC", value)
+        return cmpid
 
-    def create_coupling_inductors(
-        self, compname, l1, l2, value=1, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False
-    ):
+    def create_coupling_inductors(self, compname, l1, l2, value=1, location=[], angle=0, use_instance_id_netlist=False):
         """Create a coupling inductor.
 
         Parameters
@@ -667,10 +750,8 @@ class NexximComponents(CircuitComponents):
             Value for the second inductor.
         value : float, optional
             Value for the coupling inductor. The default is ``1``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -679,31 +760,30 @@ class NexximComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the coupling inductor.
-        str
-            Name of the coupling inductor.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        cmpid, cmpname = self.create_component(
+        cmpid = self.create_component(
             compname,
             component_library="Inductors",
             component_name="K_IND",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
 
-        self.components[cmpid].set_property("Inductor1", l1)
-        self.components[cmpid].set_property("Inductor2", l2)
-        self.components[cmpid].set_property("CouplingFactor", value)
-        return cmpid, cmpname
+        cmpid.set_property("Inductor1", l1)
+        cmpid.set_property("Inductor2", l2)
+        cmpid.set_property("CouplingFactor", value)
+        return cmpid
 
     @aedt_exception_handler
-    def create_diode(
-        self, compname=None, model_name="required", xpos=0, ypos=0, angle=0, use_instance_id_netlist=False
-    ):
+    def create_diode(self, compname=None, model_name="required", location=[], angle=0, use_instance_id_netlist=False):
         """Create a diode.
 
         Parameters
@@ -712,10 +792,8 @@ class NexximComponents(CircuitComponents):
             Name of the diode. The default is ``None``.
         model_name : str, optional
             Name of the model. The default is ``"required"``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -724,27 +802,28 @@ class NexximComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the diode.
-        str
-            Name of the diode.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        cmpid, cmpname = self.create_component(
+        cmpid = self.create_component(
             compname,
             component_library="Diodes",
             component_name="DIODE_Level1",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
 
-        self.components[cmpid].set_property("MOD", model_name)
-        return cmpid, cmpname
+        cmpid.set_property("MOD", model_name)
+        return cmpid
 
     @aedt_exception_handler
-    def create_npn(self, compname=None, value=None, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
+    def create_npn(self, compname=None, value=None, location=[], angle=0, use_instance_id_netlist=False):
         """Create an NPN transistor.
 
         Parameters
@@ -753,10 +832,8 @@ class NexximComponents(CircuitComponents):
             Name of the NPN transistor. The default is ``None``.
         value : float, optional
             Value for the NPN transistor. The default is ``None``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -765,27 +842,28 @@ class NexximComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the NPN transistor.
-        str
-            Name of the NPN transistor.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        id, name = self.create_component(
+        id = self.create_component(
             compname,
             component_library="BJTs",
             component_name="Level01_NPN",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
         if value:
-            self.components[id].set_property("MOD", value)
-        return id, name
+            id.set_property("MOD", value)
+        return id
 
     @aedt_exception_handler
-    def create_pnp(self, compname=None, value=50, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
+    def create_pnp(self, compname=None, value=50, location=[], angle=0, use_instance_id_netlist=False):
         """Create a PNP transistor.
 
         Parameters
@@ -794,10 +872,8 @@ class NexximComponents(CircuitComponents):
             Name of the PNP transistor. The default is ``None``.
         value : float, optional
             Value for the PNP transistor. The default is ``None``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -806,25 +882,26 @@ class NexximComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the PNP transistor.
-        str
-            Name of the PNP transistor.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        id, name = self.create_component(
+        id = self.create_component(
             compname,
             component_library="BJTs",
             component_name="Level01_PNP",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
         if value:
-            self.components[id].set_property("MOD", value)
+            id.set_property("MOD", value)
 
-        return id, name
+        return id
 
     @aedt_exception_handler
     def create_new_component_from_symbol(
@@ -850,6 +927,11 @@ class NexximComponents(CircuitComponents):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModelManager.Add
+        >>> oComponentManager.Add
         """
         arg = [
             "NAME:" + symbol_name,
@@ -964,28 +1046,6 @@ class NexximComponents(CircuitComponents):
         self.o_component_manager.Add(arg)
         return True
 
-    @aedt_exception_handler
-    def update_object_properties(self, o):
-        """Update the properties of an object.
-
-        Parameters
-        ----------
-        o :
-            Object to update.
-
-        Returns
-        -------
-        :class:`pyaedt.modeler.Object3d.CircuitComponent`
-            Object with properties.
-
-        """
-        name = o.composed_name
-        proparray = self.oeditor.GetProperties("PassedParameterTab", name)
-        for j in proparray:
-            propval = retry_ntimes(10, self.oeditor.GetPropertyValue, "PassedParameterTab", name, j)
-            o._add_property(j, propval)
-        return o
-
     @aedt_exception_handler
     def get_comp_custom_settings(
         self, toolNum, dc=0, interp=0, extrap=1, conv=0, passivity=0, reciprocal="False", opt="", data_type=1
@@ -1054,9 +1114,9 @@ class NexximComponents(CircuitComponents):
         comp_name,
         pin_names,
         source_project_path,
-        source_project_name,
         source_design_name,
         solution_name="Setup1 : Sweep",
+        image_subcircuit_path=None,
     ):
         """Add a subcircuit HFSS link.
 
@@ -1068,28 +1128,52 @@ class NexximComponents(CircuitComponents):
             List of the pin names.
         source_project_path : str
             Path to the source project.
-        source_project_name : str
-            Name  of the source project.
         source_design_name : str
             Name of the design.
         solution_name : str, optional
             Name of the solution and sweep. The
             default is ``"Setup1 : Sweep"``.
+        image_subcircuit_path : str, optional
+            Path of the Picture used in Circuit.
+            Default is an HFSS Picture exported automatically.
 
         Returns
         -------
-        bool
-            ``True`` when successful, ``False`` when failed.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oModelManager.Add
+        >>> oComponentManager.Add
+        >>> oDesign.AddCompInstance
         """
         designer_customization = self.get_comp_custom_settings(1, 0, 0, 1, 0, 0, "False", "", 1)
         nexxim_customization = self.get_comp_custom_settings(2, 3, 1, 3, 0, 0, "False", "", 2)
         hspice_customization = self.get_comp_custom_settings(3, 1, 2, 3, 0, 0, "False", "", 3)
 
+        if image_subcircuit_path:
+            _, file_extension = os.path.splitext(image_subcircuit_path)
+            if file_extension != ".gif" or file_extension != ".bmp" or file_extension != ".jpg":
+                image_subcircuit_path = None
+                warnings.warn("Image extension is not valid. Use default image instead.")
+        if not image_subcircuit_path:
+            image_subcircuit_path = os.path.normpath(
+                os.path.join(self._modeler._app.desktop_install_dir, "syslib", "Bitmaps", "hfss.bmp")
+            )
+        filename = ""
+        comp_name_aux = source_design_name
+        WB_SystemID = source_design_name
+        if not self._app.project_file == source_project_path:
+            filename = source_project_path
+            comp_name_aux = comp_name
+            WB_SystemID = ""
+
         compInfo = [
-            "NAME:" + str(comp_name),
+            "NAME:" + str(comp_name_aux),
             "Name:=",
-            comp_name,
+            comp_name_aux,
             "ModTime:=",
             1591855779,
             "Library:=",
@@ -1101,7 +1185,7 @@ class NexximComponents(CircuitComponents):
             "Description:=",
             "",
             "ImageFile:=",
-            "",
+            image_subcircuit_path,
             "SymbolPinConfiguration:=",
             0,
             ["NAME:PortInfoBlk"],
@@ -1122,11 +1206,11 @@ class NexximComponents(CircuitComponents):
             "NoiseModelOption:=",
             "External",
             "WB_SystemID:=",
-            "",
+            WB_SystemID,
             "IsWBModel:=",
             False,
             "filename:=",
-            source_project_path,
+            filename,
             "numberofports:=",
             len(pin_names),
             "Simulate:=",
@@ -1244,7 +1328,7 @@ class NexximComponents(CircuitComponents):
                     "Connect:=",
                     True,
                     "ModelDefinitionName:=",
-                    comp_name,
+                    comp_name_aux,
                     "ShowRefPin2:=",
                     2,
                     "LenPropName:=",
@@ -1256,13 +1340,13 @@ class NexximComponents(CircuitComponents):
         )
 
         self.o_component_manager.Add(compInfo2)
-        self._parent.odesign.AddCompInstance(comp_name)
+        self._app._odesign.AddCompInstance(comp_name)
         self.refresh_all_ids()
         for el in self.components:
             item = comp_name
             item2 = self.components[el].composed_name
             if comp_name in self.components[el].composed_name:
-                return el, self.components[el].composed_name
+                return self.components[el]
         return False
 
     @aedt_exception_handler
@@ -1282,6 +1366,10 @@ class NexximComponents(CircuitComponents):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oProject.ChangeProperty
         """
         if option == "simulate":
             setting = "Simulate missing solutions"
@@ -1308,6 +1396,10 @@ class NexximComponents(CircuitComponents):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oProject.ChangeProperty
         """
         arg = ["NAME:Solution", "Value:=", solution_name]
         return self._edit_link_definition_hfss_subcircuit(component, arg)
@@ -1315,7 +1407,14 @@ class NexximComponents(CircuitComponents):
     @aedt_exception_handler
     def _edit_link_definition_hfss_subcircuit(self, component, edited_prop):
         """Generic function to set the link definition for an hfss subcircuit."""
-        complist = component.split(";")
+        if isinstance(component, str):
+            complist = component.split(";")
+        elif isinstance(component, CircuitComponent):
+            complist = component.composed_name.split(";")
+        elif isinstance(component, int):
+            complist = self.components[component].composed_name.split(";")
+        else:
+            raise AttributeError("Wrong Component Input")
         complist2 = complist[0].split("@")
         arg = ["NAME:AllTabs"]
         arg1 = ["NAME:Model"]
@@ -1326,7 +1425,7 @@ class NexximComponents(CircuitComponents):
         arg1.append(arg3)
         arg.append(arg1)
 
-        self._parent._oproject.ChangeProperty(arg)
+        self._app._oproject.ChangeProperty(arg)
         return True
 
     @aedt_exception_handler
@@ -1344,6 +1443,10 @@ class NexximComponents(CircuitComponents):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oComponentManager.UpdateDynamicLink
         """
         self.o_component_manager.UpdateDynamicLink(component_name)
         return True
@@ -1356,21 +1459,21 @@ class NexximComponents(CircuitComponents):
            Use :func:`Circuit.push_excitations` instead.
         """
         warnings.warn(
-            "`circuit.modeler.components.push_excitation` is deprecated. " "Use `circuit.push_excitation` instead.",
+            "`circuit.modeler.schematic.push_excitation` is deprecated. " "Use `circuit.push_excitation` instead.",
             DeprecationWarning,
         )
-        return self._parent._parent.push_excitations(instance_name, thevenin_calculation, setup_name)
+        return self._app.push_excitations(instance_name, thevenin_calculation, setup_name)
 
     @aedt_exception_handler
     def assign_sin_excitation2ports(self, ports, settings):
         """Assign a voltage sinusoidal excitation to circuit ports.
 
         .. deprecated:: 0.4.0
-           Use :func:`Circuit.modeler.components.assign_voltage_sinusoidal_excitation_to_ports` instead.
+           Use :func:`Circuit.modeler.schematic.assign_voltage_sinusoidal_excitation_to_ports` instead.
         """
         warnings.warn(
             "`assign_sin_excitation2ports` is deprecated. "
             "Use `assign_voltage_sinusoidal_excitation_to_ports` instead.",
             DeprecationWarning,
         )
-        return self._parent.assign_voltage_sinusoidal_excitation_to_ports(ports, settings)
+        return self._app.assign_voltage_sinusoidal_excitation_to_ports(ports, settings)
