@@ -1,8 +1,5 @@
-from collections import defaultdict
-
-from ..generic.general_methods import aedt_exception_handler
-from .Object3d import CircuitComponent
-from .PrimitivesCircuit import CircuitComponents
+from pyaedt.generic.general_methods import aedt_exception_handler
+from pyaedt.modeler.PrimitivesCircuit import CircuitComponents
 
 
 class SimplorerComponents(CircuitComponents):
@@ -16,6 +13,13 @@ class SimplorerComponents(CircuitComponents):
 
     modeler :
 
+    Examples
+    --------
+    Basic usage demonstrated with a Simplorer design:
+
+    >>> from pyaedt import Simplorer
+    >>> aedtapp = Simplorer()
+    >>> prim = aedtapp.modeler.schematic
     """
 
     @property
@@ -39,11 +43,11 @@ class SimplorerComponents(CircuitComponents):
 
         Returns
         -------
-        type
-            Part object details.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
         """
-        if type(partname) is int:
+        if isinstance(partname, int):
             return self.components[partname]
         for el in self.components:
             if self.components[el].name == partname or self.components[el].composed_name == partname or el == partname:
@@ -51,16 +55,15 @@ class SimplorerComponents(CircuitComponents):
 
         return None
 
-    def __init__(self, parent, modeler):
-        CircuitComponents.__init__(self, parent, modeler)
-        self._parent = parent
-        self.modeler = modeler
+    def __init__(self, modeler):
+        CircuitComponents.__init__(self, modeler)
+        self._app = modeler._app
+        self._modeler = modeler
         self._currentId = 0
-        self.components = defaultdict(CircuitComponent)
         pass
 
     @aedt_exception_handler
-    def create_resistor(self, compname=None, value=50, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
+    def create_resistor(self, compname=None, value=50, location=[], angle=0, use_instance_id_netlist=False):
         """Create a resistor.
 
         Parameters
@@ -69,10 +72,8 @@ class SimplorerComponents(CircuitComponents):
             Name of the resistor. The default is ``None``.
         value : float, optional
             Value for the resistor. The default is ``50``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -80,28 +81,29 @@ class SimplorerComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the resistor.
-        str
-            Name of the resistor.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        id, name = self.create_component(
+        id = self.create_component(
             compname,
             component_library="Basic Elements\\Circuit\\Passive Elements",
             component_name="R",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
 
-        self.components[id].set_property("R", value)
+        id.set_property("R", value)
 
-        return id, name
+        return id
 
     @aedt_exception_handler
-    def create_inductor(self, compname=None, value=50, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
+    def create_inductor(self, compname=None, value=50, location=[], angle=0, use_instance_id_netlist=False):
         """Create an inductor.
 
         Parameters
@@ -110,10 +112,8 @@ class SimplorerComponents(CircuitComponents):
             Name of the inductor. The default is ``None``.
         value : float, optional
             Value for the inductor. The default is ``50``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -121,26 +121,28 @@ class SimplorerComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the inductor.
-        str
-            Name of the inductor.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
+
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        id, name = self.create_component(
+        id = self.create_component(
             compname,
             component_library="Basic Elements\\Circuit\\Passive Elements",
             component_name="L",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
 
-        self.components[id].set_property("L", value)
-        return id, name
+        id.set_property("L", value)
+        return id
 
     @aedt_exception_handler
-    def create_capacitor(self, compname=None, value=50, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
+    def create_capacitor(self, compname=None, value=50, location=[], angle=0, use_instance_id_netlist=False):
         """Create a capacitor.
 
         Parameters
@@ -149,10 +151,8 @@ class SimplorerComponents(CircuitComponents):
             Name of the capacitor. The default is ``None``.
         value : float, optional
             Value for the capacitor. The default is ``50``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -160,40 +160,91 @@ class SimplorerComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the capacitor.
-        str
-            Name of the capacitor.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
+
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        id, name = self.create_component(
+        id = self.create_component(
             compname,
             component_library="Basic Elements\\Circuit\\Passive Elements",
             component_name="C",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
 
-        self.components[id].set_property("C", value)
-        return id, name
+        id.set_property("C", value)
+        id.set_property("UseInitialConditions", True)
+        return id
 
     @aedt_exception_handler
-    def create_diode(
-        self, compname=None, model_name="required", xpos=0, ypos=0, angle=0, use_instance_id_netlist=False
+    def create_voltage_source(
+        self, compname=None, type="E", amplitude=326, freq=50, location=[], angle=0, use_instance_id_netlist=False
     ):
+        """Create a voltage source.
+
+        Parameters
+        ----------
+        compname : str, optional
+            Name of the voltage source. The default is ``None``.
+        type  : str, optional
+            Type of the source. The default is ``E``.
+        amplitude : float, optional
+            Amplitude of the waveform if periodic. The default is ``326V``
+        freq : float, optional
+            Frequency of the periodic waveform. The default is ``50Hz``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
+        angle : float, optional
+            Angle of rotation in degrees. The default is ``0``.
+        use_instance_id_netlist : bool, optional
+            Whether to use the instance ID in the net list or not. The default is ``False``.
+
+        Returns
+        -------
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
+
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
+        """
+        id = self.create_component(
+            compname,
+            component_library="Basic Elements\\Circuit\\Sources",
+            component_name="E",
+            location=location,
+            angle=angle,
+            use_instance_id_netlist=use_instance_id_netlist,
+        )
+
+        id.set_property("Type", type)
+
+        if type == "E":
+            id.set_property("EMF", amplitude)
+        if type == "ESINE" or type == "EPULSE" or type == "ETRIANG":
+            id.set_property("AMPL", amplitude)
+            id.set_property("FREQ", freq)
+            id.set_property("TPERIO", "Tend+1")
+            id.set_property("PERIO", 1)
+
+        return id
+
+    @aedt_exception_handler
+    def create_diode(self, compname=None, location=[], angle=0, use_instance_id_netlist=False):
         """Create a diode.
 
         Parameters
         ----------
         compname : str, optional
             Name of the diode. The default is ``None``.
-        model_name : str, optional
-            Name of the model. The default is ``"required"``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -201,37 +252,34 @@ class SimplorerComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the diode.
-        str
-            Name of the diode.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        id, name = self.create_component(
+        id = self.create_component(
             compname,
             component_library="Basic Elements\\Circuit\\Semiconductors System Level",
             component_name="D",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
-        return id, name
+        return id
 
     @aedt_exception_handler
-    def create_npn(self, compname=None, value=None, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
+    def create_npn(self, compname=None, location=[], angle=0, use_instance_id_netlist=False):
         """Create an NPN transistor.
 
         Parameters
         ----------
         compname : str, optional
             Name of the NPN transistor. The default is ``None``.
-        value : float, optional
-            Value for the NPN transistor. The default is ``50``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -239,37 +287,34 @@ class SimplorerComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the NPN transistor.
-        str
-            Name of the NPN transistor.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        id, name = self.create_component(
+        id = self.create_component(
             compname,
             component_library="Basic Elements\\Circuit\\Semiconductors System Level",
             component_name="BJT",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
-        return id, name
+        return id
 
     @aedt_exception_handler
-    def create_pnp(self, compname=None, value=50, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
+    def create_pnp(self, compname=None, location=[], angle=0, use_instance_id_netlist=False):
         """Create a PNP transistor.
 
         Parameters
         ----------
         compname : str, optional
             Name of the PNP transistor. The default is ``None``.
-        value : float, optional
-            Value for the PNP transistor. The default is ``50``.
-        xpos : float, optional
-            Position on the X axis. The default is ``0``.
-        ypos : float, optional
-            Position on the Y axis. The default is ``0``.
+        location : list of float, optional
+            Position on the X axis and Y axis.
         angle : float, optional
             Angle rotation in degrees. The default is ``0``.
         use_instance_id_netlist : bool, optional
@@ -277,20 +322,21 @@ class SimplorerComponents(CircuitComponents):
 
         Returns
         -------
-        int
-            ID of the PNP transistor.
-        str
-            Name of the PNP transistor.
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateComponent
         """
-        id, name = self.create_component(
+        id = self.create_component(
             compname,
             component_library="Basic Elements\\Circuit\\Semiconductors System Level",
             component_name="BJT",
-            xpos=xpos,
-            ypos=ypos,
+            location=location,
             angle=angle,
             use_instance_id_netlist=use_instance_id_netlist,
         )
 
-        return id, name
+        return id
