@@ -1,6 +1,6 @@
 from collections import OrderedDict
-from ..generic.general_methods import aedt_exception_handler, generate_unique_name
-from ..generic.DataHandlers import dict2arg, arg2dict
+from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name
+from pyaedt.generic.DataHandlers import _dict2arg, _arg2dict
 import copy
 
 defaultparametricSetup = OrderedDict(
@@ -136,7 +136,7 @@ class CommonOptimetrics(object):
 
     Parameters
     ----------
-    parent :
+    p_app :
 
     name :
 
@@ -147,20 +147,9 @@ class CommonOptimetrics(object):
 
     """
 
-    @property
-    def omodule(self):
-        """Module.
-
-        Returns
-        -------
-        :class:`Optimetrics`
-            Optimetrics object.
-
-        """
-        return self._parent.odesign.GetModule("Optimetrics")
-
-    def __init__(self, parent, name, dictinputs, optimtype):
-        self._parent = parent
+    def __init__(self, p_app, name, dictinputs, optimtype):
+        self._app = p_app
+        self.omodule = self._app.ooptimetrics
         self.name = name
         self.soltype = optimtype
 
@@ -189,25 +178,26 @@ class CommonOptimetrics(object):
             if inputd.get("Sim. Setups"):
                 setups = inputd["Sim. Setups"]
                 for el in setups:
-                    if type(self._parent.design_properties["SolutionManager"]["ID Map"]["Setup"]) is list:
-                        for setup in self._parent.design_properties["SolutionManager"]["ID Map"]["Setup"]:
+                    if type(self._app.design_properties["SolutionManager"]["ID Map"]["Setup"]) is list:
+                        for setup in self._app.design_properties["SolutionManager"]["ID Map"]["Setup"]:
                             if setup["I"] == el:
                                 setups[setups.index(el)] = setup["I"]
                                 break
                     else:
-                        if self._parent.design_properties["SolutionManager"]["ID Map"]["Setup"]["I"] == el:
-                            setups[setups.index(el)] = self._parent.design_properties["SolutionManager"]["ID Map"][
+                        if self._app.design_properties["SolutionManager"]["ID Map"]["Setup"]["I"] == el:
+                            setups[setups.index(el)] = self._app.design_properties["SolutionManager"]["ID Map"][
                                 "Setup"
                             ]["N"]
                             break
             if inputd.get("Goals", None):
-                oparams = self.omodule.GetChildObject(self.name).GetCalculationInfo()
-                oparam = [i for i in oparams[0]]
-                calculation = ["NAME:Goal"]
-                calculation.extend(oparam)
-                arg1 = OrderedDict()
-                arg2dict(calculation, arg1)
-                self.props["Goals"] = arg1
+                if self._app._is_object_oriented_enabled():
+                    oparams = self.omodule.GetChildObject(self.name).GetCalculationInfo()
+                    oparam = [i for i in oparams[0]]
+                    calculation = ["NAME:Goal"]
+                    calculation.extend(oparam)
+                    arg1 = OrderedDict()
+                    _arg2dict(calculation, arg1)
+                    self.props["Goals"] = arg1
 
     @aedt_exception_handler
     def update(self, update_dictionary=None):
@@ -223,13 +213,17 @@ class CommonOptimetrics(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.EditSetup
         """
         if update_dictionary:
             for el in update_dictionary:
                 self.props[el] = update_dictionary[el]
 
         arg = ["NAME:" + self.name]
-        dict2arg(self.props, arg)
+        _dict2arg(self.props, arg)
 
         self.omodule.EditSetup(self.name, arg)
         return True
@@ -243,9 +237,13 @@ class CommonOptimetrics(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.InsertSetup
         """
         arg = ["NAME:" + self.name]
-        dict2arg(self.props, arg)
+        _dict2arg(self.props, arg)
         self.omodule.InsertSetup(self.soltype, arg)
         return True
 
@@ -286,7 +284,7 @@ class CommonOptimetrics(object):
         sweepdefinition = OrderedDict()
         sweepdefinition["ReportType"] = reporttype
         if not solution:
-            solution = self._parent.nominal_sweep
+            solution = self._app.nominal_sweep
 
         sweepdefinition["Solution"] = solution
         sweepdefinition["SimValueContext"] = OrderedDict({"Domain": domain})
@@ -364,7 +362,7 @@ class CommonOptimetrics(object):
         sweepdefinition = OrderedDict()
         sweepdefinition["ReportType"] = reporttype
         if not solution:
-            solution = self._parent.nominal_sweep
+            solution = self._app.nominal_sweep
         sweepdefinition["Solution"] = solution
         sweepdefinition["SimValueContext"] = OrderedDict({"Domain": domain})
         sweepdefinition["Calculation"] = calculation
@@ -417,10 +415,11 @@ class CommonOptimetrics(object):
 class DXSetups(object):
     """Sets up DesignXplorer optimizations.
 
-    Parameters
-    ----------
-    parent :
-
+    Examples
+    --------
+    >>> from pyaedt import Hfss
+    >>> app = Hfss()
+    >>> dx_setup = app.opti_designxplorer
     """
 
     class Setup(CommonOptimetrics, object):
@@ -428,7 +427,7 @@ class DXSetups(object):
 
         Parameters
         ----------
-        parent :
+        app :
         name :
         dictinputs :
             The default is ``None``.
@@ -437,8 +436,8 @@ class DXSetups(object):
 
         """
 
-        def __init__(self, parent, name, dictinputs=None):
-            CommonOptimetrics.__init__(self, parent, name, dictinputs=dictinputs, optimtype="OptiDesignExplorer")
+        def __init__(self, app, name, dictinputs=None):
+            CommonOptimetrics.__init__(self, app, name, dictinputs=dictinputs, optimtype="OptiDesignExplorer")
 
         @aedt_exception_handler
         def add_calculation(
@@ -473,6 +472,11 @@ class DXSetups(object):
             -------
             bool
                 ``True`` when successful, ``False`` when failed.
+
+            References
+            ----------
+
+            >>> oModule.EditSetup
             """
             return self._add_calculation(
                 reporttype=reporttype,
@@ -537,6 +541,10 @@ class DXSetups(object):
             bool
                 ``True`` when successful, ``False`` when failed.
 
+            References
+            ----------
+
+            >>> oModule.EditSetup
             """
             return self._add_goal(
                 optigoalname="CostFunctionGoals",
@@ -554,9 +562,9 @@ class DXSetups(object):
             )
 
     @property
-    def parent(self):
+    def p_app(self):
         """Parent."""
-        return self._parent
+        return self._app
 
     @property
     def optimodule(self):
@@ -566,20 +574,20 @@ class DXSetups(object):
         :class:`Optimetrics`
 
         """
-        return self.parent.odesign.GetModule("Optimetrics")
+        return self._app.ooptimetrics
 
-    def __init__(self, parent):
-        self._parent = parent
+    def __init__(self, p_app):
+        self._app = p_app
         self.setups = []
-        if self._parent.design_properties:
+        if self._app.design_properties:
             try:
-                setups_data = self._parent.design_properties["Optimetrics"]["OptimetricsSetups"]
+                setups_data = self._app.design_properties["Optimetrics"]["OptimetricsSetups"]
                 for data in setups_data:
                     if (
                         type(setups_data[data]) is OrderedDict
                         and setups_data[data]["SetupType"] == "OptiDesignExplorer"
                     ):
-                        self.setups.append(self.Setup(parent, data, setups_data[data]))
+                        self.setups.append(self.Setup(p_app, data, setups_data[data]))
             except:
                 pass
 
@@ -605,14 +613,18 @@ class DXSetups(object):
         -------
         :class:`Optimetrics`
 
+        References
+        ----------
+
+        >>> oModule.InsertSetup
         """
         if not setupname:
-            setupname = [self._parent.analysis_setup]
+            setupname = [self._app.analysis_setup]
         elif type(setupname) is not list:
             setupname = [setupname]
         if not parametricname:
             parametricname = generate_unique_name("DesignXplorer")
-        setup = self.Setup(self._parent, parametricname)
+        setup = self.Setup(self._app, parametricname)
         setup.props["Sim. Setups"] = setupname
         setup.props["Sweeps"] = []
         if not defaults_var_values:
@@ -620,9 +632,9 @@ class DXSetups(object):
                 sweepdefinition = OrderedDict()
                 sweepdefinition["Variable"] = v
                 if "$" in v:
-                    sweepdefinition["Data"] = self._parent.oproject.GetVariableValue(v)
+                    sweepdefinition["Data"] = self._app.oproject.GetVariableValue(v)
                 else:
-                    sweepdefinition["Data"] = self._parent.odesign.GetVariableValue(v)
+                    sweepdefinition["Data"] = self._app._odesign.GetVariableValue(v)
                 sweepdefinition["OffsetF1"] = False
                 sweepdefinition["Synchronize"] = 0
         else:
@@ -642,10 +654,11 @@ class DXSetups(object):
 class ParametericsSetups(object):
     """Sets up parametric analyses.
 
-    Parameters
-    ----------
-    parent :
-
+    Examples
+    --------
+    >>> from pyaedt import Hfss
+    >>> app = Hfss()
+    >>> parametric_setup = app.opti_parametric
     """
 
     class Setup(CommonOptimetrics, object):
@@ -654,7 +667,7 @@ class ParametericsSetups(object):
 
         Parameters
         ----------
-        parent : str
+        p_app : str
             Inherited AEDT object.
 
         name :
@@ -666,8 +679,8 @@ class ParametericsSetups(object):
 
         """
 
-        def __init__(self, parent, name, dictinputs=None):
-            CommonOptimetrics.__init__(self, parent, name, dictinputs=dictinputs, optimtype="OptiParametric")
+        def __init__(self, p_app, name, dictinputs=None):
+            CommonOptimetrics.__init__(self, p_app, name, dictinputs=dictinputs, optimtype="OptiParametric")
             pass
 
         @aedt_exception_handler
@@ -686,6 +699,10 @@ class ParametericsSetups(object):
             bool
                 ``True`` when successful, ``False`` when failed.
 
+            References
+            ----------
+
+            >>> oModule.EditSetup
             """
             if type(self.props["Sweeps"]["SweepDefinition"]) is not list:
                 self.props["Sweeps"]["SweepDefinition"] = [self.props["Sweeps"]["SweepDefinition"]]
@@ -732,6 +749,10 @@ class ParametericsSetups(object):
             bool
                 ``True`` when successful, ``False`` when failed.
 
+            References
+            ----------
+
+            >>> oModule.EditSetup
             """
             return self._add_calculation(
                 reporttype=reporttype,
@@ -744,9 +765,9 @@ class ParametericsSetups(object):
             )
 
     @property
-    def parent(self):
+    def p_app(self):
         """Parent."""
-        return self._parent
+        return self._app
 
     @property
     def optimodule(self):
@@ -757,18 +778,21 @@ class ParametericsSetups(object):
         :class:`Optimetrics`
 
         """
-        return self.parent.odesign.GetModule("Optimetrics")
+        return self._app.ooptimetrics
 
-    def __init__(self, parent):
-        self._parent = parent
+    def __init__(self, p_app):
+        self._app = p_app
         self.setups = []
-        if self._parent.design_properties:
+        if self._app.design_properties:
             try:
-                setups_data = self._parent.design_properties["Optimetrics"]["OptimetricsSetups"]
+                setups_data = self._app.design_properties["Optimetrics"]["OptimetricsSetups"]
 
                 for data in setups_data:
-                    if type(setups_data[data]) is OrderedDict and setups_data[data]["SetupType"] == "OptiParametric":
-                        self.setups.append(self.Setup(parent, data, setups_data[data]))
+                    if (
+                        isinstance(setups_data[data], (OrderedDict, dict))
+                        and setups_data[data]["SetupType"] == "OptiParametric"
+                    ):
+                        self.setups.append(self.Setup(p_app, data, setups_data[data]))
             except:
                 pass
 
@@ -795,14 +819,18 @@ class ParametericsSetups(object):
         :class:`pyaedt.modules.DesignXPloration.ParametericsSetups.Optimetrics`
             Optimetrics object.
 
+        References
+        ----------
+
+        >>> oModule.InsertSetup
         """
         if not setupname:
-            setupname = [self._parent.analysis_setup]
+            setupname = [self._app.analysis_setup]
         elif type(setupname) is not list:
             setupname = [setupname]
         if not parametricname:
             parametricname = generate_unique_name("Parametric")
-        setup = self.Setup(self._parent, parametricname)
+        setup = self.Setup(self._app, parametricname)
         setup.props["Sim. Setups"] = setupname
         sweepdefinition = OrderedDict()
         sweepdefinition["Variable"] = sweep_var
@@ -818,10 +846,11 @@ class ParametericsSetups(object):
 class SensitivitySetups(object):
     """Sets up sensitivity analyses.
 
-    Parameters
-    ----------
-    parent :
-
+    Examples
+    --------
+    >>> from pyaedt import Hfss
+    >>> app = Hfss()
+    >>> sensitivity_setups = app.opti_sensitivity
     """
 
     class Setup(CommonOptimetrics, object):
@@ -829,7 +858,7 @@ class SensitivitySetups(object):
 
         Parameters
         ----------
-        parent :
+        p_app :
 
         name :
 
@@ -840,8 +869,8 @@ class SensitivitySetups(object):
 
         """
 
-        def __init__(self, parent, name, dictinputs=None):
-            CommonOptimetrics.__init__(self, parent, name, dictinputs=dictinputs, optimtype="OptiSensitivity")
+        def __init__(self, p_app, name, dictinputs=None):
+            CommonOptimetrics.__init__(self, p_app, name, dictinputs=dictinputs, optimtype="OptiSensitivity")
 
         @aedt_exception_handler
         def add_calculation(
@@ -877,6 +906,10 @@ class SensitivitySetups(object):
             bool
                 ``True`` when successful, ``False`` when failed.
 
+            References
+            ----------
+
+            >>> oModule.EditSetup
             """
             return self._add_calculation(
                 reporttype=reporttype,
@@ -889,9 +922,9 @@ class SensitivitySetups(object):
             )
 
     @property
-    def parent(self):
+    def p_app(self):
         """Parent."""
-        return self._parent
+        return self._app
 
     @property
     def optimodule(self):
@@ -902,17 +935,20 @@ class SensitivitySetups(object):
         :class:`Optimetrics`
 
         """
-        return self.parent.odesign.GetModule("Optimetrics")
+        return self._app.ooptimetrics
 
-    def __init__(self, parent):
-        self._parent = parent
+    def __init__(self, p_app):
+        self._app = p_app
         self.setups = []
-        if self._parent.design_properties:
+        if self._app.design_properties:
             try:
-                setups_data = self._parent.design_properties["Optimetrics"]["OptimetricsSetups"]
+                setups_data = self._app.design_properties["Optimetrics"]["OptimetricsSetups"]
                 for data in setups_data:
-                    if type(setups_data[data]) is OrderedDict and setups_data[data]["SetupType"] == "OptiSensitivity":
-                        self.setups.append(self.Setup(parent, data, setups_data[data]))
+                    if (
+                        isinstance(setups_data[data], (OrderedDict, dict))
+                        and setups_data[data]["SetupType"] == "OptiSensitivity"
+                    ):
+                        self.setups.append(self.Setup(p_app, data, setups_data[data]))
             except:
                 pass
 
@@ -955,14 +991,18 @@ class SensitivitySetups(object):
         -------
         :class:`Sensitivity`
 
+        References
+        ----------
+
+        >>> oModule.InsertSetup
         """
         if not parametricname:
             parametricname = generate_unique_name("Sensitivity")
-        setup = self.Setup(self._parent, parametricname)
+        setup = self.Setup(self._app, parametricname)
         sweepdefinition = OrderedDict()
         sweepdefinition["ReportType"] = reporttype
         if not solution:
-            solution = self._parent.nominal_sweep
+            solution = self._app.nominal_sweep
         sweepdefinition["Solution"] = solution
         sweepdefinition["SimValueContext"] = OrderedDict({"Domain": domain})
         sweepdefinition["Calculation"] = calculation
@@ -979,10 +1019,11 @@ class SensitivitySetups(object):
 class StatisticalSetups(object):
     """Sets up statistical analyses.
 
-    Parameters
-    ----------
-    parent :
-
+    Examples
+    --------
+    >>> from pyaedt import Hfss
+    >>> app = Hfss()
+    >>> statistical_setups = app.opti_statistical
     """
 
     class Setup(CommonOptimetrics, object):
@@ -990,7 +1031,7 @@ class StatisticalSetups(object):
 
         Parameters
         ----------
-        parent :
+        p_app :
 
         name :
 
@@ -1001,8 +1042,8 @@ class StatisticalSetups(object):
 
         """
 
-        def __init__(self, parent, name, dictinputs=None):
-            CommonOptimetrics.__init__(self, parent, name, dictinputs=dictinputs, optimtype="OptiStatistical")
+        def __init__(self, p_app, name, dictinputs=None):
+            CommonOptimetrics.__init__(self, p_app, name, dictinputs=dictinputs, optimtype="OptiStatistical")
             pass
 
         @aedt_exception_handler
@@ -1039,6 +1080,10 @@ class StatisticalSetups(object):
             bool
                 ``True`` when successful, ``False`` when failed.
 
+            References
+            ----------
+
+            >>> oModule.EditSetup
             """
             return self._add_calculation(
                 reporttype=reporttype,
@@ -1051,9 +1096,9 @@ class StatisticalSetups(object):
             )
 
     @property
-    def parent(self):
+    def p_app(self):
         """Parent."""
-        return self._parent
+        return self._app
 
     @property
     def optimodule(self):
@@ -1064,17 +1109,20 @@ class StatisticalSetups(object):
         :class:`Optimetrics`
 
         """
-        return self.parent.odesign.GetModule("Optimetrics")
+        return self._app.ooptimetrics
 
-    def __init__(self, parent):
-        self._parent = parent
+    def __init__(self, p_app):
+        self._app = p_app
         self.setups = []
-        if self._parent.design_properties:
+        if self._app.design_properties:
             try:
-                setups_data = self._parent.design_properties["Optimetrics"]["OptimetricsSetups"]
+                setups_data = self._app.design_properties["Optimetrics"]["OptimetricsSetups"]
                 for data in setups_data:
-                    if type(setups_data[data]) is OrderedDict and setups_data[data]["SetupType"] == "OptiStatistical":
-                        self.setups.append(self.Setup(parent, data, setups_data[data]))
+                    if (
+                        isinstance(setups_data[data], (OrderedDict, dict))
+                        and setups_data[data]["SetupType"] == "OptiStatistical"
+                    ):
+                        self.setups.append(self.Setup(p_app, data, setups_data[data]))
             except:
                 pass
 
@@ -1117,14 +1165,18 @@ class StatisticalSetups(object):
         -------
         :class:`Statistical`
 
+        References
+        ----------
+
+        >>> oModule.InsertSetup
         """
         if not parametricname:
             parametricname = generate_unique_name("Statistical")
-        setup = self.Setup(self._parent, parametricname)
+        setup = self.Setup(self._app, parametricname)
         sweepdefinition = OrderedDict()
         sweepdefinition["ReportType"] = reporttype
         if not solution:
-            solution = self._parent.nominal_sweep
+            solution = self._app.nominal_sweep
 
         sweepdefinition["Solution"] = solution
         sweepdefinition["SimValueContext"] = OrderedDict({"Domain": domain})
@@ -1142,10 +1194,11 @@ class StatisticalSetups(object):
 class DOESetups(object):
     """Sets up DOEs (Designs of Experiments).
 
-    Parameters
-    ----------
-    parent :
-
+    Examples
+    --------
+    >>> from pyaedt import Hfss
+    >>> app = Hfss()
+    >>> doe_setups = app.opti_doe
     """
 
     class Setup(CommonOptimetrics, object):
@@ -1153,7 +1206,7 @@ class DOESetups(object):
 
         Parameters
         ----------
-        parent : str
+        p_app : str
             Inherited AEDT object.
         name :
 
@@ -1164,8 +1217,8 @@ class DOESetups(object):
 
         """
 
-        def __init__(self, parent, name, dictinputs=None):
-            CommonOptimetrics.__init__(self, parent, name, dictinputs=dictinputs, optimtype="OptiDXDOE")
+        def __init__(self, p_app, name, dictinputs=None):
+            CommonOptimetrics.__init__(self, p_app, name, dictinputs=dictinputs, optimtype="OptiDXDOE")
             pass
 
         @aedt_exception_handler
@@ -1202,6 +1255,10 @@ class DOESetups(object):
             bool
                 ``True`` when successful, ``False`` when failed.
 
+            References
+            ----------
+
+            >>> oModule.EditSetup
             """
             return self._add_calculation(
                 reporttype=reporttype,
@@ -1265,6 +1322,10 @@ class DOESetups(object):
             bool
                 ``True`` when successful, ``False`` when failed.
 
+            References
+            ----------
+
+            >>> oModule.EditSetup
             """
             return self._add_goal(
                 optigoalname="CostFunctionGoals",
@@ -1282,9 +1343,9 @@ class DOESetups(object):
             )
 
     @property
-    def parent(self):
+    def p_app(self):
         """Parent."""
-        return self._parent
+        return self._app
 
     @property
     def optimodule(self):
@@ -1295,17 +1356,20 @@ class DOESetups(object):
         :class:`Optimetrics`
 
         """
-        return self.parent.odesign.GetModule("Optimetrics")
+        return self._app.ooptimetrics
 
-    def __init__(self, parent):
-        self._parent = parent
+    def __init__(self, p_app):
+        self._app = p_app
         self.setups = []
-        if self._parent.design_properties:
+        if self._app.design_properties:
             try:
-                setups_data = self._parent.design_properties["Optimetrics"]["OptimetricsSetups"]
+                setups_data = self._app.design_properties["Optimetrics"]["OptimetricsSetups"]
                 for data in setups_data:
-                    if type(setups_data[data]) is OrderedDict and setups_data[data]["SetupType"] == "OptiDXDOE":
-                        self.setups.append(self.Setup(parent, data, setups_data[data]))
+                    if (
+                        isinstance(setups_data[data], (OrderedDict, dict))
+                        and setups_data[data]["SetupType"] == "OptiDXDOE"
+                    ):
+                        self.setups.append(self.Setup(p_app, data, setups_data[data]))
             except:
                 pass
 
@@ -1360,13 +1424,17 @@ class DOESetups(object):
         type
             DOE object.
 
+        References
+        ----------
+
+        >>> oModule.InsertSetup
         """
         if not solution:
-            solution = self._parent.nominal_sweep
+            solution = self._app.nominal_sweep
         setupname = [solution.split(" ")[0]]
         if not parametricname:
             parametricname = generate_unique_name("DesignOfExp")
-        setup = self.Setup(self._parent, parametricname)
+        setup = self.Setup(self._app, parametricname)
         setup.props["Sim. Setups"] = setupname
         sweepdefinition = OrderedDict()
         sweepdefinition["ReportType"] = reporttype
@@ -1392,10 +1460,11 @@ class DOESetups(object):
 class OptimizationSetups(object):
     """Sets up optimizations.
 
-    Parameters
-    ----------
-    parent :
-
+    Examples
+    --------
+    >>> from pyaedt import Hfss
+    >>> app = Hfss()
+    >>> optimization_setup = app.opti_optimization
     """
 
     class Setup(CommonOptimetrics, object):
@@ -1403,7 +1472,7 @@ class OptimizationSetups(object):
 
         Parameters
         ----------
-        parent : str
+        p_app : str
             Inherited AEDT object.
         name :
 
@@ -1412,8 +1481,8 @@ class OptimizationSetups(object):
 
         """
 
-        def __init__(self, parent, name, dictinputs=None):
-            CommonOptimetrics.__init__(self, parent, name, dictinputs=dictinputs, optimtype="OptiOptimization")
+        def __init__(self, p_app, name, dictinputs=None):
+            CommonOptimetrics.__init__(self, p_app, name, dictinputs=dictinputs, optimtype="OptiOptimization")
             pass
 
         @aedt_exception_handler
@@ -1468,6 +1537,10 @@ class OptimizationSetups(object):
             bool
                 ``True`` when successful, ``False`` when failed.
 
+            References
+            ----------
+
+            >>> oModule.EditSetup
             """
             return self._add_goal(
                 optigoalname="Goals",
@@ -1485,9 +1558,9 @@ class OptimizationSetups(object):
             )
 
     @property
-    def parent(self):
+    def p_app(self):
         """Parent."""
-        return self._parent
+        return self._app
 
     @property
     def optimodule(self):
@@ -1498,17 +1571,20 @@ class OptimizationSetups(object):
         :class:`Optimetrics`
 
         """
-        return self.parent.odesign.GetModule("Optimetrics")
+        return self._app.ooptimetrics
 
-    def __init__(self, parent):
-        self._parent = parent
+    def __init__(self, p_app):
+        self._app = p_app
         self.setups = []
-        if self._parent.design_properties:
+        if self._app.design_properties:
             try:
-                setups_data = self._parent.design_properties["Optimetrics"]["OptimetricsSetups"]
+                setups_data = self._app.design_properties["Optimetrics"]["OptimetricsSetups"]
                 for data in setups_data:
-                    if type(setups_data[data]) is OrderedDict and setups_data[data]["SetupType"] == "OptiOptimization":
-                        self.setups.append(self.Setup(parent, data, setups_data[data]))
+                    if (
+                        isinstance(setups_data[data], (OrderedDict, dict))
+                        and setups_data[data]["SetupType"] == "OptiOptimization"
+                    ):
+                        self.setups.append(self.Setup(p_app, data, setups_data[data]))
             except:
                 pass
 
@@ -1561,14 +1637,18 @@ class OptimizationSetups(object):
         type
             Optimization object.
 
+        References
+        ----------
+
+        >>> oModule.InsertSetup
         """
         if not parametricname:
             parametricname = generate_unique_name("Optimization")
-        setup = self.Setup(self._parent, parametricname)
+        setup = self.Setup(self._app, parametricname)
         sweepdefinition = OrderedDict()
         sweepdefinition["ReportType"] = reporttype
         if not solution:
-            solution = self._parent.nominal_sweep
+            solution = self._app.nominal_sweep
         sweepdefinition["Solution"] = solution
         sweepdefinition["SimValueContext"] = OrderedDict({"Domain": domain})
         sweepdefinition["Calculation"] = calculation
