@@ -4,8 +4,8 @@ This module contains these classes: `Layer` and `Layers`.
 This module provides all layer stackup functionalities for the Circuit and HFSS 3D Layout tools.
 """
 from __future__ import absolute_import
-from collections import defaultdict
-from ..generic.general_methods import aedt_exception_handler
+
+from pyaedt.generic.general_methods import aedt_exception_handler
 
 
 @aedt_exception_handler
@@ -82,46 +82,25 @@ class Layer(object):
 
     Parameters
     ----------
-    editor :
+    app : :class:`pyaedt.modules.LayerStackup.Layers`
 
     layertype : string, optional
         The default is ``"signal"``.
-    layerunits : str, optional
-        The default is ``"mm"``.
-    roughunit : str, optional
-        The default is ``"um"``.
     negative : bool, optional
         Whether the geometry on the layer is cut away
         from the layer. The default is ``False``.
+
+    Examples
+    --------
+    >>> from pyaedt import Hfss3dLayout
+    >>> app = Hfss3dLayout()
+    >>> layers = app.modeler.primitives.layers["Top"]
     """
 
-    @property
-    def visflag(self):
-        """Visibility flag for objects on the layer."""
-        visflag = 0
-        if not self.IsVisible:
-            visflag = 0
-        else:
-            if self.IsMeshBackgroundMaterial:
-                visflag += 64
-            if self.IsMeshOverlay:
-                visflag += 32
-            if self.IsVisibleShape:
-                visflag += 1
-            if self.IsVisiblePath:
-                visflag += 2
-            if self.IsVisiblePad:
-                visflag += 4
-            if self.IsVisibleHole:
-                visflag += 8
-            if self.IsVisibleComponent:
-                visflag += 16
-        return visflag
-
-    def __init__(self, editor, layertype="signal", layerunits="mm", roughunit="um", negative=False):
-        self.LengthUnit = layerunits
-        self.LengthUnitRough = roughunit
-        self.oeditor = editor
+    def __init__(self, app, layertype="signal", negative=False):
+        self.LengthUnit = app.LengthUnit
+        self.LengthUnitRough = app.LengthUnit
+        self._layers = app
         self.name = None
         self.type = layertype
         self.id = 0
@@ -168,6 +147,33 @@ class Layer(object):
         self.hfssSp = {"si": True, "dt": 0, "dtv": 0.1}
         self.planaremSp = {"ifg": False, "vly": False}
 
+    @property
+    def _oeditor(self):
+        return self._layers._oeditor
+
+    @property
+    def visflag(self):
+        """Visibility flag for objects on the layer."""
+        visflag = 0
+        if not self.IsVisible:
+            visflag = 0
+        else:
+            if self.IsMeshBackgroundMaterial:
+                visflag += 64
+            if self.IsMeshOverlay:
+                visflag += 32
+            if self.IsVisibleShape:
+                visflag += 1
+            if self.IsVisiblePath:
+                visflag += 2
+            if self.IsVisiblePad:
+                visflag += 4
+            if self.IsVisibleHole:
+                visflag += 8
+            if self.IsVisibleComponent:
+                visflag += 16
+        return visflag
+
     @aedt_exception_handler
     def set_layer_color(self, r, g, b):
         """Update the color of the layer.
@@ -186,6 +192,10 @@ class Layer(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oEditor.ChangeLayer
         """
         rgb = [r, g, b]
         self.color = _getIfromRGB(rgb)
@@ -200,10 +210,15 @@ class Layer(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oEditor.AddStackupLayer
         """
         self.remove_stackup_layer()
         if self.type == "signal":
-            self.oeditor.AddStackupLayer(
+            self._oeditor.AddStackupLayer(
                 [
                     "NAME:stackup layer",
                     "Name:=",
@@ -296,7 +311,7 @@ class Layer(object):
                 ]
             )
         else:
-            self.oeditor.AddStackupLayer(
+            self._oeditor.AddStackupLayer(
                 [
                     "NAME:stackup layer",
                     "Name:=",
@@ -334,7 +349,7 @@ class Layer(object):
                     ],
                 ]
             )
-        infos = self.oeditor.GetLayerInfo(self.name)
+        infos = self._oeditor.GetLayerInfo(self.name)
         infos = [i.split(": ") for i in infos]
         infosdict = {i[0]: i[1] for i in infos}
         self.id = int(infosdict["LayerId"])
@@ -355,7 +370,7 @@ class Layer(object):
         -------
 
         """
-        if type(value) is str:
+        if isinstance(value, str):
             val = value
         else:
             if units is None:
@@ -376,9 +391,14 @@ class Layer(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oEditor.ChangeLayer
         """
         if self.type == "signal":
-            self.oeditor.ChangeLayer(
+            self._oeditor.ChangeLayer(
                 [
                     "NAME:SLayer",
                     "Name:=",
@@ -475,7 +495,7 @@ class Layer(object):
                 ]
             )
         elif self.type == "dielectric":
-            self.oeditor.ChangeLayer(
+            self._oeditor.ChangeLayer(
                 [
                     "NAME:SLayer",
                     "Name:=",
@@ -529,9 +549,14 @@ class Layer(object):
         -------
         bool
             ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oEditor.RemoveLayer
         """
-        if self.name in self.oeditor.GetStackupLayerNames():
-            self.oeditor.RemoveLayer(self.name)
+        if self.name in self._oeditor.GetStackupLayerNames():
+            self._oeditor.RemoveLayer(self.name)
             return True
         return False
 
@@ -541,35 +566,40 @@ class Layers(object):
 
     Parameters
     ----------
-    parent :
-        Inherited AEDT object.
-
-    modeler :
+    modeler : :class:`pyaedt.modeler.Model3DLayout.Modeler3DLayout`
 
     roughnessunits : str, optional
        Units for the roughness of layers. The default is ``"um"``.
 
+    Examples
+    --------
+    >>> from pyaedt import Hfss3dLayout
+    >>> app = Hfss3dLayout()
+    >>> layers = app.modeler.primitives.layers
     """
 
-    @property
-    def _messenger(self):
-        """Messenger."""
-        return self._parent._messenger
+    def __init__(self, modeler, roughnessunits="um"):
+        self._modeler = modeler
+        self._app = self._modeler._app
+        self._currentId = 0
+        self.layers = {}
+        self.lengthUnitRough = roughnessunits
+        self.logger = self._app.logger
 
     @property
-    def modeler(self):
-        """Modeler."""
-        return self._modeler
+    def _oeditor(self):
+        """Editor.
 
-    @property
-    def oeditor(self):
-        """Editor."""
-        return self.modeler.oeditor
+        References
+        ----------
+
+        >>> oEditor = oDesign.SetActiveEditor("Layout")"""
+        return self._modeler._app._odesign.SetActiveEditor("Layout")
 
     @property
     def LengthUnit(self):
         """Length units."""
-        return self.modeler.model_units
+        return self._modeler.model_units
 
     @property
     def all_layers(self):
@@ -579,8 +609,13 @@ class Layers(object):
         -------
         list
            List of stackup layers.
+
+        References
+        ----------
+
+        >>> oEditor.GetStackupLayerNames()
         """
-        return self.oeditor.GetStackupLayerNames()
+        return self._oeditor.GetStackupLayerNames()
 
     @property
     def all_signal_layers(self):
@@ -621,13 +656,6 @@ class Layers(object):
                 die.append(layid)
         return die
 
-    def __init__(self, parent, modeler, roughnessunits="um"):
-        self._modeler = modeler
-        self._parent = parent
-        self._currentId = 0
-        self.layers = defaultdict(Layer)
-        self.lengthUnitRough = roughnessunits
-
     @aedt_exception_handler
     def layer_id(self, name):
         """Retrieve a layer ID.
@@ -656,11 +684,11 @@ class Layers(object):
         int
             Number of layers in the current stackup.
         """
-        layernames = self.oeditor.GetStackupLayerNames()
+        layernames = self._oeditor.GetStackupLayerNames()
         for el in layernames:
-            o = Layer(self.oeditor, "signal", self.LengthUnit, self.lengthUnitRough)
+            o = Layer(self, "signal")
             o.name = el
-            infos = self.oeditor.GetLayerInfo(el)
+            infos = self._oeditor.GetLayerInfo(el)
             infos = [i.split(": ") for i in infos]
             infosdict = {i[0].strip(): i[1].strip() for i in infos}
             if infosdict["Type"] == "metalizedsignal":
@@ -762,7 +790,7 @@ class Layers(object):
         :class:`pyaedt.modules.LayerStackup.Layer`
             Layer object.
         """
-        newlayer = Layer(self.oeditor, layertype, self.LengthUnit, self.lengthUnitRough, isnegative)
+        newlayer = Layer(self, layertype, isnegative)
         newlayer.name = layername
         newlayer.thickness = thickness
         newlayer.lowerelevation = elevation
