@@ -3,9 +3,9 @@ This module contains the `Mesh` class.
 """
 
 from __future__ import absolute_import
-from ..generic.general_methods import aedt_exception_handler, generate_unique_name, MethodNotSupportedError
+from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name, MethodNotSupportedError
 
-from ..generic.DataHandlers import dict2arg
+from pyaedt.generic.DataHandlers import _dict2arg
 from collections import OrderedDict
 
 meshers = {
@@ -15,6 +15,8 @@ meshers = {
     "Maxwell 2D": "MeshSetup",
     "Maxwell 3D": "MeshSetup",
     "Q3D Extractor": "MeshSetup",
+    "Mechanical": "MeshSetup",
+    "2D Extractor": "MeshSetup",
 }
 
 
@@ -23,7 +25,7 @@ class MeshOperation(object):
 
     Parameters
     ----------
-    parent :
+    meshicepak : :class:`pyaedt.modules.MeshIcepak.MeshIcepak`
 
     name:
 
@@ -33,8 +35,8 @@ class MeshOperation(object):
 
     """
 
-    def __init__(self, parent, name, props, meshoptype):
-        self._parent = parent
+    def __init__(self, meshicepak, name, props, meshoptype):
+        self._meshicepak = meshicepak
         self.name = name
         self.props = props
         self.type = meshoptype
@@ -44,7 +46,7 @@ class MeshOperation(object):
         """Retrieve arguments."""
         props = self.props
         arg = ["NAME:" + self.name]
-        dict2arg(props, arg)
+        _dict2arg(props, arg)
         return arg
 
     @aedt_exception_handler
@@ -53,32 +55,33 @@ class MeshOperation(object):
 
         Returns
         -------
-        type
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         if self.type == "SurfApproxBased":
-            self._parent.omeshmodule.AssignTrueSurfOp(self._get_args())
+            self._meshicepak.omeshmodule.AssignTrueSurfOp(self._get_args())
         elif self.type == "DefeatureBased":
-            self._parent.omeshmodule.AssignModelResolutionOp(self._get_args())
+            self._meshicepak.omeshmodule.AssignModelResolutionOp(self._get_args())
         elif self.type == "SurfaceRepPriority":
-            self._parent.omeshmodule.AssignSurfPriorityForTauOp(self._get_args())
+            self._meshicepak.omeshmodule.AssignSurfPriorityForTauOp(self._get_args())
         elif self.type == "LengthBased":
-            self._parent.omeshmodule.AssignLengthOp(self._get_args())
+            self._meshicepak.omeshmodule.AssignLengthOp(self._get_args())
         elif self.type == "SkinDepthBased":
-            self._parent.omeshmodule.AssignSkinDepthOp(self._get_args())
+            self._meshicepak.omeshmodule.AssignSkinDepthOp(self._get_args())
         elif self.type == "Curvilinear":
-            self._parent.omeshmodule.AssignApplyCurvlinearElementsOp(self._get_args())
+            self._meshicepak.omeshmodule.AssignApplyCurvlinearElementsOp(self._get_args())
         elif self.type == "RotationalLayerMesh":
-            self._parent.omeshmodule.AssignRotationalLayerOp(self._get_args())
+            self._meshicepak.omeshmodule.AssignRotationalLayerOp(self._get_args())
         elif self.type == "DensityControlBased":
-            self._parent.omeshmodule.AssignDensityControlOp(self._get_args())
+            self._meshicepak.omeshmodule.AssignDensityControlOp(self._get_args())
         elif self.type == "Icepak":
-            self._parent.omeshmodule.AssignMeshOperation(self._get_args())
+            self._meshicepak.omeshmodule.AssignMeshOperation(self._get_args())
         elif self.type == "CurvatureExtraction":
-            self._parent.omeshmodule.AssignCurvatureExtractionOp(self._get_args())
-
+            self._meshicepak.omeshmodule.AssignCurvatureExtractionOp(self._get_args())
         else:
             return False
+        return True
 
     @aedt_exception_handler
     def update(self):
@@ -89,27 +92,39 @@ class MeshOperation(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.EditTrueSurfOp
+        >>> oModule.EditModelResolutionOp
+        >>> oModule.EditSurfPriorityForTauOp
+        >>> oModule.EditLengthOp
+        >>> oModule.EditApplyCurvlinearElementsOp
+        >>> oModule.EditRotationalLayerOp
+        >>> oModule.EditDensityControlOp
+        >>> oModule.EditMeshOperation
+        >>> oModule.EditSBRCurvatureExtractionOp
         """
         if self.type == "SurfApproxBased":
-            self._parent.omeshmodule.EditTrueSurfOp(self.name, self._get_args())
+            self._meshicepak.omeshmodule.EditTrueSurfOp(self.name, self._get_args())
         elif self.type == "DefeatureBased":
-            self._parent.omeshmodule.EditModelResolutionOp(self.name, self._get_args())
+            self._meshicepak.omeshmodule.EditModelResolutionOp(self.name, self._get_args())
         elif self.type == "SurfaceRepPriority":
-            self._parent.omeshmodule.EditSurfPriorityForTauOp(self.name, self._get_args())
+            self._meshicepak.omeshmodule.EditSurfPriorityForTauOp(self.name, self._get_args())
         elif self.type == "LengthBased":
-            self._parent.omeshmodule.EditLengthOp(self.name, self._get_args())
+            self._meshicepak.omeshmodule.EditLengthOp(self.name, self._get_args())
         elif self.type == "SkinDepthBased":
-            self._parent.omeshmodule.EditSkinDepthOp(self.name, self._get_args())
+            self._meshicepak.omeshmodule.EditSkinDepthOp(self.name, self._get_args())
         elif self.type == "Curvilinear":
-            self._parent.omeshmodule.EditApplyCurvlinearElementsOp(self.name, self._get_args())
+            self._meshicepak.omeshmodule.EditApplyCurvlinearElementsOp(self.name, self._get_args())
         elif self.type == "RotationalLayerMesh":
-            self._parent.omeshmodule.EditRotationalLayerOp(self.name, self._get_args())
+            self._meshicepak.omeshmodule.EditRotationalLayerOp(self.name, self._get_args())
         elif self.type == "DensityControlBased":
-            self._parent.omeshmodule.EditDensityControlOp(self.name, self._get_args())
+            self._meshicepak.omeshmodule.EditDensityControlOp(self.name, self._get_args())
         elif self.type == "Icepak":
-            self._parent.omeshmodule.EditMeshOperation(self.name, self._get_args())
+            self._meshicepak.omeshmodule.EditMeshOperation(self.name, self._get_args())
         elif self.type == "CurvatureExtraction":
-            self._parent.omeshmodule.EditSBRCurvatureExtractionOp(self.name, self._get_args())
+            self._meshicepak.omeshmodule.EditSBRCurvatureExtractionOp(self.name, self._get_args())
         else:
             return False
         return True
@@ -123,11 +138,15 @@ class MeshOperation(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.DeleteOp
         """
-        self._parent.omeshmodule.DeleteOp([self.name])
-        for el in self._parent.meshoperations:
+        self._meshicepak.omeshmodule.DeleteOp([self.name])
+        for el in self._meshicepak.meshoperations:
             if el.name == self.name:
-                self._parent.meshoperations.remove(el)
+                self._meshicepak.meshoperations.remove(el)
         return True
 
 
@@ -138,12 +157,18 @@ class Mesh(object):
 
     Parameters
     ----------
-    parent :
+    app : :class:`pyaedt.application.Analysis3D.FieldAnalysis3D`
 
     """
 
-    def __init__(self, parent):
-        self._parent = parent
+    def __init__(self, app):
+        self._app = app
+
+        self._odesign = self._app.odesign
+        self.modeler = self._app.modeler
+        design_type = self._odesign.GetDesignType()
+        self.logger = self._app.logger
+        self._omeshmodule = self._odesign.GetModule(meshers[design_type])
         self.id = 0
         self.meshoperations = self._get_design_mesh_operations()
         self.globalmesh = self._get_design_global_mesh()
@@ -151,31 +176,20 @@ class Mesh(object):
 
     @property
     def omeshmodule(self):
-        """Mesh module."""
-        design_type = self.odesign.GetDesignType()
-        assert design_type in meshers, "Invalid design type {}".format(design_type)
-        return self.odesign.GetModule(meshers[design_type])
+        """Aedt Mesh Module.
 
-    @property
-    def _messenger(self):
-        """_messenger."""
-        return self._parent._messenger
+        References
+        ----------
 
-    @property
-    def odesign(self):
-        """Design."""
-        return self._parent._odesign
-
-    @property
-    def modeler(self):
-        """Modeler."""
-        return self._parent._modeler
+        >>> oDesign.GetModule("MeshSetup")
+        """
+        return self._omeshmodule
 
     @aedt_exception_handler
     def _get_design_global_mesh(self):
         """ """
         try:
-            return self._parent.design_properties["MeshSetup"]["MeshSettings"]
+            return self._app.design_properties["MeshSetup"]["MeshSettings"]
         except:
             return OrderedDict()
 
@@ -184,14 +198,14 @@ class Mesh(object):
         """ """
         meshops = []
         try:
-            for ds in self._parent.design_properties["MeshSetup"]["MeshOperations"]:
-                if type(self._parent.design_properties["MeshSetup"]["MeshOperations"][ds]) is OrderedDict:
+            for ds in self._app.design_properties["MeshSetup"]["MeshOperations"]:
+                if isinstance(self._app.design_properties["MeshSetup"]["MeshOperations"][ds], (OrderedDict, dict)):
                     meshops.append(
                         MeshOperation(
                             self,
                             ds,
-                            self._parent.design_properties["MeshSetup"]["MeshOperations"][ds],
-                            self._parent.design_properties["MeshSetup"]["MeshOperations"][ds]["Type"],
+                            self._app.design_properties["MeshSetup"]["MeshOperations"][ds],
+                            self._app.design_properties["MeshSetup"]["MeshOperations"][ds]["Type"],
                         )
                     )
         except:
@@ -216,6 +230,10 @@ class Mesh(object):
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
 
+        References
+        ----------
+
+        >>> oModule.AssignTrueSurfOp
         """
         names = self.modeler.convert_to_selections(names, True)
         if meshop_name:
@@ -224,10 +242,10 @@ class Mesh(object):
                     meshop_name = generate_unique_name(meshop_name)
         else:
             meshop_name = generate_unique_name("SurfApprox")
-        self._messenger.add_info_message("Assigning Mesh Level " + str(level) + " to " + str(names))
-        names = self._parent._modeler._convert_list_to_ids(names)
+        self.logger.info("Assigning Mesh Level " + str(level) + " to " + str(names))
+        names = self._app._modeler._convert_list_to_ids(names)
 
-        if type(names[0]) is int:
+        if isinstance(names[0], int):
             seltype = "Faces"
         else:
             seltype = "Objects"
@@ -266,6 +284,10 @@ class Mesh(object):
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
 
+        References
+        ----------
+
+        >>> oModule.AssignTrueSurfOp
         """
         names = self.modeler.convert_to_selections(names, True)
         if meshop_name:
@@ -329,6 +351,10 @@ class Mesh(object):
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
 
+        References
+        ----------
+
+        >>> oModule.AssignModelResolutionOp
         """
         names = self.modeler.convert_to_selections(names, True)
         if meshop_name:
@@ -338,8 +364,8 @@ class Mesh(object):
         else:
             meshop_name = generate_unique_name("ModelResolution")
         for name in names:
-            if type(name) is int:
-                self._messenger.add_error_message("Mesh Operation Applies to Objects only")
+            if isinstance(name, int):
+                self.logger.error("Mesh Operation Applies to Objects only")
                 return False
         if defeature_length is None:
             props = OrderedDict({"Objects": names, "UseAutoLength": True})
@@ -404,8 +430,12 @@ class Mesh(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.InitialMeshSettings
         """
-        if self._parent.design_type == "2D Extractor" or self._parent.design_type == "Maxwell 2D":
+        if self._app.design_type == "2D Extractor" or self._app.design_type == "Maxwell 2D":
             mesh_methods = ["Auto", "AnsoftClassic"]
         else:
             mesh_methods = ["Auto", "AnsoftTAU", "AnsoftClassic"]
@@ -422,7 +452,7 @@ class Mesh(object):
             "SliderMeshSettings:=",
             level,
         ]
-        if self._parent.design_type == "2D Extractor" or self._parent.design_type == "Maxwell 2D":
+        if self._app.design_type == "2D Extractor" or self._app.design_type == "Maxwell 2D":
             args = ["NAME:MeshSettings", surface_appr, modelres, "MeshMethod:=", method]
         else:
             args = [
@@ -439,7 +469,7 @@ class Mesh(object):
                 "UseFlexMeshingForTAUvolumeMesh:=",
                 useflexmesh,
             ]
-        if self._parent.design_type == "HFSS":
+        if self._app.design_type == "HFSS":
             args.append("UseAlternativeMeshMethodsAsFallBack:=")
             args.append(usefallback)
             args.append("AllowPhiForLayeredGeometry:=")
@@ -464,6 +494,10 @@ class Mesh(object):
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
 
+        References
+        ----------
+
+        >>> oModule.AssignSurfPriorityForTauOp
         """
         meshop_name = generate_unique_name("SurfaceRepPriority")
         props = OrderedDict({"Type": "SurfaceRepPriority", "Objects": object_lists, "SurfaceRepPriority": surfpriority})
@@ -486,8 +520,12 @@ class Mesh(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oDesign.GenerateMesh
         """
-        return self.odesign.GenerateMesh(name) == 0
+        return self._odesign.GenerateMesh(name) == 0
 
     @aedt_exception_handler
     def delete_mesh_operations(self, mesh_type=None):
@@ -504,6 +542,10 @@ class Mesh(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.DeleteOp
         """
         # Type "Area Based" not included since the delete command causes
         # desktop to crash
@@ -534,7 +576,7 @@ class Mesh(object):
             List of object names or face IDs.
         isinside : bool, optional
             Whether the length mesh is inside the selection. The default is ``True``.
-        maxlength : int, optional
+        maxlength : str, float, optional
             Maximum element length. The default is ``1``. When ``None``,
             this parameter is disabled.
         maxel : int, optional
@@ -548,6 +590,10 @@ class Mesh(object):
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
 
+        References
+        ----------
+
+        >>> oModule.AssignLengthOp
         """
         names = self.modeler.convert_to_selections(names, True)
         if meshop_name:
@@ -570,18 +616,18 @@ class Mesh(object):
             restrictel = True
             numel = str(maxel)
         if maxlength is None and maxel is None:
-            self._messenger.add_error_message("mesh not assigned due to incorrect settings")
+            self.logger.error("mesh not assigned due to incorrect settings")
             return
-        names = self._parent._modeler._convert_list_to_ids(names)
+        names = self._app._modeler._convert_list_to_ids(names)
 
-        if type(names[0]) is int and not isinside:
+        if isinstance(names[0], int) and not isinside:
             seltype = "Faces"
-        elif type(names[0]) is str:
+        elif isinstance(names[0], str):
             seltype = "Objects"
         else:
             seltype = None
         if seltype is None:
-            self._messenger.add_error_message("Error in Assignment")
+            self.logger.error("Error in Assignment")
             return
         props = OrderedDict(
             {
@@ -627,10 +673,14 @@ class Mesh(object):
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
 
+        References
+        ----------
+
+        >>> oModule.AssignSkinDepthOp
         """
         names = self.modeler.convert_to_selections(names, True)
 
-        if self._parent.design_type != "HFSS" and self._parent.design_type != "Maxwell 3D":
+        if self._app.design_type != "HFSS" and self._app.design_type != "Maxwell 3D":
             raise MethodNotSupportedError
         if meshop_name:
             for m in self.meshoperations:
@@ -644,16 +694,16 @@ class Mesh(object):
             maxelements = "1000"
         else:
             restrictlength = True
-        names = self._parent._modeler._convert_list_to_ids(names)
+        names = self._app._modeler._convert_list_to_ids(names)
 
-        if type(names[0]) is int:
+        if isinstance(names[0], int):
             seltype = "Faces"
-        elif type(names[0]) is str:
+        elif isinstance(names[0], str):
             seltype = "Objects"
         else:
             seltype = None
         if seltype is None:
-            self._messenger.add_error_message("Error in Assignment")
+            self.logger.error("Error in Assignment")
             return
 
         props = OrderedDict(
@@ -692,10 +742,14 @@ class Mesh(object):
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
 
+        References
+        ----------
+
+        >>> oModule.AssignApplyCurvlinearElementsOp
         """
         names = self.modeler.convert_to_selections(names, True)
 
-        if self._parent.design_type != "HFSS" and self._parent.design_type != "Maxwell 3D":
+        if self._app.design_type != "HFSS" and self._app.design_type != "Maxwell 3D":
             raise MethodNotSupportedError
         if meshop_name:
             for m in self.meshoperations:
@@ -703,16 +757,16 @@ class Mesh(object):
                     meshop_name = generate_unique_name(meshop_name)
         else:
             meshop_name = generate_unique_name("CurvilinearElements")
-        names = self._parent._modeler._convert_list_to_ids(names)
+        names = self._app._modeler._convert_list_to_ids(names)
 
-        if type(names[0]) is int:
+        if isinstance(names[0], int):
             seltype = "Faces"
-        elif type(names[0]) is str:
+        elif isinstance(names[0], str):
             seltype = "Objects"
         else:
             seltype = None
         if seltype is None:
-            self._messenger.add_error_message("Error in Assignment")
+            self.logger.error("Error in Assignment")
             return
         props = OrderedDict({"Type": "Curvilinear", seltype: names, "Apply": enable})
         mop = MeshOperation(self, meshop_name, props, "Curvilinear")
@@ -727,22 +781,26 @@ class Mesh(object):
          Parameters
          ----------
          names : list
-             List of objects or faces.
+            List of objects or faces.
          disable_for_faceted_surf : bool, optional
-             Whether curvature extraction is enabled for faceted surfaces.
-             The default is ``True``.
+            Whether curvature extraction is enabled for faceted surfaces.
+            The default is ``True``.
          meshop_name : str, optional
-             Name of the mesh operation. The default is ``None``.
+            Name of the mesh operation. The default is ``None``.
 
          Returns
          -------
         :class:`pyaedt.modules.Mesh.MeshOperation`
-             Mesh operation object.
+            Mesh operation object.
 
+        References
+        ----------
+
+        >>> oModule.AssignCurvatureExtractionOp
         """
         names = self.modeler.convert_to_selections(names, True)
 
-        if self._parent.solution_type != "SBR+":
+        if self._app.solution_type != "SBR+":
             raise MethodNotSupportedError
         if meshop_name:
             for m in self.meshoperations:
@@ -750,15 +808,15 @@ class Mesh(object):
                     meshop_name = generate_unique_name(meshop_name)
         else:
             meshop_name = generate_unique_name("CurvilinearElements")
-        names = self._parent._modeler._convert_list_to_ids(names)
-        if type(names[0]) is int:
+        names = self._app._modeler._convert_list_to_ids(names)
+        if isinstance(names[0], int):
             seltype = "Faces"
-        elif type(names[0]) is str:
+        elif isinstance(names[0], str):
             seltype = "Objects"
         else:
             seltype = None
         if seltype is None:
-            self._messenger.add_error_message("Error in Assignment")
+            self.logger.error("Error in Assignment")
             return
         props = OrderedDict(
             {"Type": "CurvatureExtraction", seltype: names, "DisableForFacetedSurfaces": disable_for_faceted_surf}
@@ -789,10 +847,14 @@ class Mesh(object):
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
 
+        References
+        ----------
+
+        >>> oModule.AssignRotationalLayerOp
         """
         names = self.modeler.convert_to_selections(names, True)
 
-        if self._parent.design_type != "Maxwell 3D":
+        if self._app.design_type != "Maxwell 3D":
             raise MethodNotSupportedError
         if meshop_name:
             for m in self.meshoperations:
@@ -833,10 +895,14 @@ class Mesh(object):
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
 
+        References
+        ----------
+
+        >>> oModule.AssignRotationalLayerOp
         """
         names = self.modeler.convert_to_selections(names, True)
 
-        if self._parent.design_type != "Maxwell 3D":
+        if self._app.design_type != "Maxwell 3D":
             raise MethodNotSupportedError
         if meshop_name:
             for m in self.meshoperations:
@@ -876,10 +942,14 @@ class Mesh(object):
         :class:`pyaedt.modules.Mesh.MeshOperation`
             Mesh operation object.
 
+        References
+        ----------
+
+        >>> oModule.AssignDensityControlOp
         """
         names = self.modeler.convert_to_selections(names, True)
 
-        if self._parent.design_type != "Maxwell 3D":
+        if self._app.design_type != "Maxwell 3D":
             raise MethodNotSupportedError
         if meshop_name:
             for m in self.meshoperations:
