@@ -1,5 +1,5 @@
-from ..generic.general_methods import aedt_exception_handler
-from ..generic.DataHandlers import dict2arg
+from pyaedt.generic.general_methods import aedt_exception_handler
+from pyaedt.generic.DataHandlers import _dict2arg
 from collections import OrderedDict
 
 meshlink = [("ImportMesh", False)]
@@ -1007,6 +1007,135 @@ HFSS3DLayout = [
 ]
 """HFSS 3D Layout setup properties and default values."""
 
+HFSS3DLayout_SweepDataList = []
+HFSS3DLayout_SIWAdvancedSettings = [
+    ("IncludeCoPlaneCoupling", True),
+    ("IncludeInterPlaneCoupling:=", False),
+    ("IncludeSplitPlaneCoupling:=", True),
+    ("IncludeFringeCoupling", True),
+    ("IncludeTraceCoupling", True),
+    ("XtalkThreshold", "-34"),
+    ("MaxCoupledLines", 12),
+    ("MinVoidArea", "2mm2"),
+    ("MinPadAreaToMesh", "1mm2"),
+    ("MinPlaneAreaToMesh", "6.25e-6mm2"),
+    ("SnapLengthThreshold", "2.5um"),
+    ("MeshAutoMatic", True),
+    ("MeshFrequency", "4GHz"),
+    ("ReturnCurrentDistribution", False),
+    ("IncludeVISources", False),
+    ("IncludeInfGnd", False),
+    ("InfGndLocation", "0mm"),
+    ("PerformERC", False),
+    ("IgnoreNonFunctionalPads", True),
+]
+HFSS3DLayout_SIWDCSettings = [
+    ("UseDCCustomSettings", False),
+    ("PlotJV", True),
+    ("ComputeInductance", False),
+    ("ContactRadius", "0.1mm"),
+    ("DCSliderPos", 1),
+]
+HFSS3DLayout_SIWDCAdvancedSettings = [
+    ("DcMinPlaneAreaToMesh", "0.25mm2"),
+    ("DcMinVoidAreaToMesh", "0.01mm2"),
+    ("MaxInitMeshEdgeLength", "2.5mm"),
+    ("PerformAdaptiveRefinement", True),
+    ("MaxNumPasses", 5),
+    ("MinNumPasses", 1),
+    ("PercentLocalRefinement", 20),
+    ("EnergyError", 2),
+    ("MeshBws", True),
+    ("RefineBws", False),
+    ("MeshVias", True),
+    ("RefineVias", False),
+    ("NumBwSides", 8),
+    ("NumViaSides", 8),
+]
+HFSS3DLayout_SIWDCIRSettings = [
+    ("IcepakTempFile", "D:/Program Files/AnsysEM/AnsysEM21.2/Win64/"),
+    ("SourceTermsToGround", []),
+    ("ExportDCThermalData", False),
+    ("ImportThermalData", False),
+    ("FullDCReportPath", ""),
+    ("ViaReportPath", ""),
+    ("PerPinResPath", ""),
+    ("DCReportConfigFile", ""),
+    ("DCReportShowActiveDevices", False),
+    ("PerPinUsePinFormat", False),
+    ("UseLoopResForPerPin", False),
+]
+
+HFSS3DLayout_SimulationSettings = [
+    ("Enabled", True),
+    ("UseSISettings", True),
+    ("UseCustomSettings", False),
+    ("SISliderPos", 1),
+    ("PISliderPos", 1),
+    ("SIWAdvancedSettings", HFSS3DLayout_SIWAdvancedSettings),
+    ("SIWDCSettings", HFSS3DLayout_SIWDCSettings),
+    ("SIWDCAdvancedSettings", HFSS3DLayout_SIWDCAdvancedSettings),
+    ("SIWDCIRSettings", HFSS3DLayout_SIWDCIRSettings),
+]
+
+HFSS3DLayout_ACSimulationSettings = [
+    ("Enabled", True),
+    ("UseSISettings", True),
+    ("UseCustomSettings", False),
+    ("SISliderPos", 1),
+    ("PISliderPos", 1),
+    ("SIWAdvancedSettings", HFSS3DLayout_SIWAdvancedSettings),
+    ("SIWDCSettings", HFSS3DLayout_SIWDCSettings),
+    ("SIWDCAdvancedSettings", HFSS3DLayout_SIWDCAdvancedSettings),
+]
+SiwaveDC3DLayout = [
+    ("Properties", HFSS3DLayout_Properties),
+    ("CustomSetup", False),
+    ("SolveSetupType", "SIwave"),
+    ("Color", ["R:=", 0, "G:=", 0, "B:=", 0]),
+    ("Position", 0),
+    ("SimSetupType", "kSIwave"),
+    ("SimulationSettings", HFSS3DLayout_SimulationSettings),
+    ("SweepDataList", HFSS3DLayout_SweepDataList),
+]
+
+SiwaveAC3DLayout = [
+    ("Properties", HFSS3DLayout_Properties),
+    ("CustomSetup", False),
+    ("SolveSetupType", "SIwaveDCIR"),
+    ("Position", 0),
+    ("SimSetupType", "kSIwaveDCIR"),
+    ("SimulationSettings", HFSS3DLayout_ACSimulationSettings),
+    ("SweepDataList", HFSS3DLayout_SweepDataList),
+]
+
+HFSS3DLayout_LNASimulationSettings = [
+    ("Enabled", True),
+    ("GroupDelay", False),
+    ("Perturbation", 0.1),
+    ("Noise", False),
+    ("Skip_DC", False),
+    ("AdditionalOptions", ""),
+    ("BaseOptionName", "(Default Options)"),
+    ("FilterText", ""),
+]
+LNA_Sweep = [
+    ("DataId", "Sweep0"),
+    ("Properties", HFSS3DLayout_Properties),
+    ("Sweep", SweepDefinition),
+    ("SolutionID", -1),
+]
+HFSS3DLayout_LNAData = [("LNA Sweep 1", LNA_Sweep)]
+LNA3DLayout = [
+    ("Properties", HFSS3DLayout_Properties),
+    ("CustomSetup", False),
+    ("SolveSetupType", "LNA"),
+    ("Position", 0),
+    ("SimSetupType", "kLNA"),
+    ("SimulationSettings", HFSS3DLayout_LNASimulationSettings),
+    ("SweepDataList", HFSS3DLayout_SweepDataList),
+    ("Data", HFSS3DLayout_LNAData),
+]
 MechTerm = [
     ("Enabled", True),
     ("MeshLink", meshlink),
@@ -1119,7 +1248,7 @@ class SweepHFSS(object):
         ----------
         rangetype : str
             Type of the subrange. Options are ``"LinearCount"``,
-            ``"LinearStep"``, ``"LogScale"``, and ``"SinglePoints"``.
+            ``"LinearStep"``, ``"LogScale"`` and ``"SinglePoints"``.
         start : float
             Starting frequency.
         end : float, optional
@@ -1137,6 +1266,17 @@ class SweepHFSS(object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        Examples
+        --------
+        Create a setup in an HFSS design and add multiple sweep ranges.
+
+        >>> setup = hfss.create_setup(setupname="MySetup")
+        >>> sweep = setup.add_sweep()
+        >>> sweep.change_type("Interpolating")
+        >>> sweep.change_range("LinearStep", 1.1, 2.1, 0.4, "GHz")
+        >>> sweep.add_subrange("LinearCount", 1, 1.5, 5, "MHz")
+        >>> sweep.add_subrange("LogScale", 1, 3, 10, "GHz")
+
         """
         if rangetype == "LinearCount" or rangetype == "LinearStep" or rangetype == "LogScale":
             if not end or not count:
@@ -1151,13 +1291,14 @@ class SweepHFSS(object):
             range["RangeEnd"] = str(end) + unit
             range["RangeStep"] = str(count) + unit
         elif rangetype == "LogScale":
-            range["RangeEnd"] = end
+            range["RangeEnd"] = str(end) + unit
             range["RangeCount"] = self.props["RangeCount"]
             range["RangeSamples"] = count
         elif rangetype == "SinglePoints":
             range["RangeEnd"] = str(start) + unit
             range["SaveSingleField"] = save_single_fields
         self.props["SweepRanges"]["Subrange"].append(range)
+        return True
 
     @aedt_exception_handler
     def create(self):
@@ -1204,7 +1345,7 @@ class SweepHFSS(object):
         if props is None:
             props = self.props
         arg = ["NAME:" + self.name]
-        dict2arg(props, arg)
+        _dict2arg(props, arg)
         return arg
 
 
@@ -1230,13 +1371,13 @@ class SweepHFSS3DLayout(object):
     """
 
     def __init__(
-            self,
-            oanalysis,
-            setupname,
-            sweepname,
-            sweeptype="Interpolating",
-            save_fields=True,
-            props=None,
+        self,
+        oanalysis,
+        setupname,
+        sweepname,
+        sweeptype="Interpolating",
+        save_fields=True,
+        props=None,
     ):
         self.oanalysis = oanalysis
         self.props = {}
@@ -1357,13 +1498,13 @@ class SweepHFSS3DLayout(object):
                 raise AttributeError("Parameters 'end' and 'count' must be present.")
 
         if rangetype == "LinearCount":
-            sweep_range = " LINC " + str(start)+unit + " " + str(end)+unit + " " + str(count)
+            sweep_range = " LINC " + str(start) + unit + " " + str(end) + unit + " " + str(count)
         elif rangetype == "LinearStep":
-            sweep_range = " LIN " + str(start)+unit + " " + str(end)+unit + " " + str(count)+unit
+            sweep_range = " LIN " + str(start) + unit + " " + str(end) + unit + " " + str(count) + unit
         elif rangetype == "LogScale":
-            sweep_range = " DEC " + str(start)+unit + " " + str(end)+unit + " " + str(count)+unit
+            sweep_range = " DEC " + str(start) + unit + " " + str(end) + unit + " " + str(count) + unit
         elif rangetype == "SinglePoint":
-            sweep_range = " " + str(start)+unit
+            sweep_range = " " + str(start) + unit
         else:
             raise AttributeError('Allowed rangetype are "LinearCount", "SinglePoint", "LinearStep", and "LogScale".')
         self.props["Sweeps"]["Data"] += sweep_range
@@ -1396,13 +1537,13 @@ class SweepHFSS3DLayout(object):
 
         """
         if rangetype == "LinearCount":
-            sweep_range = "LINC " + str(start)+unit + " " + str(end)+unit + " " + str(count)
+            sweep_range = "LINC " + str(start) + unit + " " + str(end) + unit + " " + str(count)
         elif rangetype == "LinearStep":
-            sweep_range = "LIN " + str(start)+unit + " " + str(end)+unit + " " + str(count)+unit
+            sweep_range = "LIN " + str(start) + unit + " " + str(end) + unit + " " + str(count) + unit
         elif rangetype == "LogScale":
-            sweep_range = "DEC " + str(start)+unit + " " + str(end)+unit + " " + str(count)+unit
+            sweep_range = "DEC " + str(start) + unit + " " + str(end) + unit + " " + str(count) + unit
         elif rangetype == "SinglePoint":
-            sweep_range = str(start)+unit
+            sweep_range = str(start) + unit
         else:
             raise AttributeError('Allowed rangetype are "LinearCount", "SinglePoint", "LinearStep", and "LogScale".')
         self.props["Sweeps"]["Data"] = sweep_range
@@ -1453,7 +1594,7 @@ class SweepHFSS3DLayout(object):
         if props is None:
             props = self.props
         arg = ["NAME:" + self.name]
-        dict2arg(props, arg)
+        _dict2arg(props, arg)
         return arg
 
 
@@ -1486,18 +1627,31 @@ class SweepQ3D(object):
             self.props = props
         else:
             self.props["Type"] = sweeptype
-            self.props["isenabled"] = True
-            self.props["RangeType"] = "LinearCount"
-            self.props["RangeStart"] = "2.5GHz"
-            self.props["RangeStep"] = "1GHz"
-            self.props["RangeEnd"] = "7.5GHz"
-            self.props["SaveSingleField"] = False
+            if sweeptype == "Discrete":
+                self.props["isenabled"] = True
+                self.props["RangeType"] = "LinearCount"
+                self.props["RangeStart"] = "2.5GHz"
+                self.props["RangeStep"] = "1GHz"
+                self.props["RangeEnd"] = "7.5GHz"
+                self.props["SaveSingleField"] = False
 
-            self.props["RangeSamples"] = 3
-            self.props["RangeCount"] = 401
-            self.props["SaveFields"] = True
-            self.props["SaveRadFields"] = True
-            self.props["SweepRanges"] = []
+                self.props["RangeSamples"] = 3
+                self.props["RangeCount"] = 401
+                self.props["SaveFields"] = False
+                self.props["SaveRadFields"] = False
+                self.props["SweepRanges"] = []
+            else:
+                self.props["IsEnabled"] = True
+                self.props["RangeType"] = "LinearStep"
+                self.props["RangeStart"] = "1GHz"
+                self.props["RangeStep"] = "1GHz"
+                self.props["RangeEnd"] = "20GHz"
+                self.props["SaveFields"] = False
+                self.props["SaveRadFields"] = False
+                self.props["InterpTolerance"] = 0.5
+                self.props["InterpMaxSolns"] = 50
+                self.props["InterpMinSolns"] = 0
+                self.props["InterpMinSubranges"] = 1
 
     @aedt_exception_handler
     def add_subrange(self, type, start, end, count):
@@ -1581,82 +1735,13 @@ class SweepQ3D(object):
         if props is None:
             props = self.props
         arg = ["NAME:" + self.name]
-        dict2arg(props, arg)
+        _dict2arg(props, arg)
         return arg
 
 
 class SetupKeys(object):
     """Provides setup keys."""
 
-    defaultSetups = {
-        "DrivenModal": 1,
-        "DrivenTerminal": 1,
-        "Eigenmode": 2,
-        "Transient Network": 3,
-        "SBR+": 4,
-        "Transient": 5,
-        "Magnetostatic": 6,
-        "EddyCurrent": 7,
-        "Electrostatic": 8,
-        "ElectroDCConduction": 9,
-        "ElectricTransient": 10,
-        "SteadyTemperatureAndFlow": 11,
-        "SteadyTemperatureOnly": 12,
-        "SteadyFlowOnly": 13,
-        "SteadyState": 11,
-        "Matrix": 14,
-        "NexximLNA": 15,
-        "NexximDC": 16,
-        "NexximTransient": 17,
-        "NexximQuickEye": 18,
-        "NexximVerifEye": 19,
-        "NexximAMI": 20,
-        "NexximOscillatorRSF": 21,
-        "NexximOscillator1T": 22,
-        "NexximOscillatorNT": 23,
-        "NexximHarmonicBalance1T": 24,
-        "NexximHarmonicBalanceNT": 25,
-        "NexximSystem": 26,
-        "NexximTVNoise": 27,
-        "HSPICE": 28,
-        "HFSS3DLayout": 29,
-        "Open": 30,
-        "Close": 31,
-        "Thermal": 32,
-        "Modal": 33,
-        "IRIM": 34,
-        "ORIM": 34,
-        "SRIM": 34,
-        "WRIM": 34,
-        "DFIG": 34,
-        "AFIM": 34,
-        "HM": 34,
-        "RFSM": 34,
-        "RASM": 34,
-        "RSM": 34,
-        "ISM": 34,
-        "APSM": 34,
-        "IBDM": 34,
-        "ABDM": 34,
-        "TPIM": 34,
-        "SPIM": 34,
-        "TPSM": 34,
-        "BLDC": 34,
-        "ASSM": 34,
-        "PMDC": 34,
-        "SRM": 34,
-        "LSSM": 34,
-        "UNIM": 34,
-        "DCM": 34,
-        "CPSM": 34,
-        "NSSM": 34,
-        "TR": 35,
-        "TransientTemperatureAndFlow": 36,
-        "TransientTemperatureOnly": 37,
-        "TransientFlowOnly": 38,
-        "Structural": 39,
-    }
-
     SetupTemplates = {
         0: HFSSDrivenAuto,
         1: HFSSDrivenDefault,
@@ -1698,6 +1783,9 @@ class SetupKeys(object):
         37: TransientTemperatureOnly,
         38: TransientFlowOnly,
         39: MechStructural,
+        40: SiwaveDC3DLayout,
+        41: SiwaveAC3DLayout,
+        42: LNA3DLayout,
     }
 
     SetupNames = [
@@ -1741,47 +1829,7 @@ class SetupKeys(object):
         "IcepakTransient",
         "IcepakTransient",
         "MechStructural",
+        "SiwaveDC3DLayout",
+        "SiwaveAC3DLayout",
+        "LNA3DLayout",
     ]
-
-    defaultAdaptive = {
-        "DrivenModal": "LastAdaptive",
-        "DrivenTerminal": "LastAdaptive",
-        "Eigenmode": "LastAdaptive",
-        "Transient Network": "Transient",
-        "SBR+": None,
-        "Transient": "Transient",
-        "Magnetostatic": "LastAdaptive",
-        "EddyCurrent": "LastAdaptive",
-        "Electrostatic": "LastAdaptive",
-        "ElectroDCConduction": "LastAdaptive",
-        "ElectricTransient": "Transient",
-        "SteadyTemperatureAndFlow": "SteadyState",
-        "SteadyTemperatureOnly": "SteadyState",
-        "SteadyFlowOnly": "SteadyState",
-        "SteadyState": "SteadyState",
-        "Matrix": "LastAdaptive",
-        "NexximLNA": None,
-        "NexximDC": None,
-        "NexximTransient": None,
-        "NexximQuickEye": None,
-        "NexximVerifEye": None,
-        "NexximAMI": None,
-        "NexximOscillatorRSF": None,
-        "NexximOscillator1T": None,
-        "NexximOscillatorNT": None,
-        "NexximHarmonicBalance1T": None,
-        "NexximHarmonicBalanceNT": None,
-        "NexximSystem": None,
-        "NexximTVNoise": None,
-        "HSPICE": None,
-        "HFSS3DLayout": None,
-        "2DMatrix": "LastAdaptive",
-        "MechThermal": "Solution",
-        "MechModal": "Solution",
-        "GRM": "LastAdaptive",
-        "TR": None,
-        "TransientTemperatureAndFlow": "SteadyState",
-        "TransientTemperatureOnly": "Transient",
-        "TransientFlowOnly": "Transient",
-        "Structural": "Solution",
-    }
