@@ -1,13 +1,14 @@
 """This module contains these classes: `Q2d`, `Q3d`, and `QExtractor`."""
 from __future__ import absolute_import
 
-from .application.Analysis2D import FieldAnalysis2D
-from .application.Analysis3D import FieldAnalysis3D
-from .generic.general_methods import aedt_exception_handler, generate_unique_name
+from pyaedt.application.Analysis2D import FieldAnalysis2D
+from pyaedt.application.Analysis3D import FieldAnalysis3D
+from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name
 from collections import OrderedDict
-from .modules.Boundary import BoundaryObject
-from .generic.DataHandlers import dict2arg
+from pyaedt.modules.Boundary import BoundaryObject
+from pyaedt.generic.DataHandlers import _dict2arg
 import os
+import warnings
 
 
 class QExtractor(FieldAnalysis3D, FieldAnalysis2D, object):
@@ -24,23 +25,6 @@ class QExtractor(FieldAnalysis3D, FieldAnalysis2D, object):
 
     """
 
-    @property
-    def odefinition_manager(self):
-        """Definition manager."""
-        return self.oproject.GetDefinitionManager()
-
-    @property
-    def omaterial_manager(self):
-        """Material manager."""
-        return self.odefinition_manager.GetManager("Material")
-
-    '''
-    @property
-    def oeditor(self):
-        ""Editor."""
-        return self.odesign.SetActiveEditor("3D Modeler")
-    '''
-
     @property
     def design_file(self):
         """Design file."""
@@ -48,17 +32,17 @@ class QExtractor(FieldAnalysis3D, FieldAnalysis2D, object):
         return design_file
 
     def __init__(
-            self,
-            Q3DType,
-            projectname=None,
-            designname=None,
-            solution_type=None,
-            setup_name=None,
-            specified_version=None,
-            non_graphical=False,
-            new_desktop_session=False,
-            close_on_exit=False,
-            student_version=False,
+        self,
+        Q3DType,
+        projectname=None,
+        designname=None,
+        solution_type=None,
+        setup_name=None,
+        specified_version=None,
+        non_graphical=False,
+        new_desktop_session=False,
+        close_on_exit=False,
+        student_version=False,
     ):
         if Q3DType == "Q3D Extractor":
             FieldAnalysis3D.__init__(
@@ -146,16 +130,16 @@ class Q3d(QExtractor, object):
     """
 
     def __init__(
-            self,
-            projectname=None,
-            designname=None,
-            solution_type=None,
-            setup_name=None,
-            specified_version=None,
-            non_graphical=False,
-            new_desktop_session=False,
-            close_on_exit=False,
-            student_version=False,
+        self,
+        projectname=None,
+        designname=None,
+        solution_type=None,
+        setup_name=None,
+        specified_version=None,
+        non_graphical=False,
+        new_desktop_session=False,
+        close_on_exit=False,
+        student_version=False,
     ):
         QExtractor.__init__(
             self,
@@ -180,6 +164,10 @@ class Q3d(QExtractor, object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.AutoIdentifyNets
         """
         self.oboundary.AutoIdentifyNets()
         return True
@@ -207,6 +195,10 @@ class Q3d(QExtractor, object):
         :class:`pyaedt.modules.Boundary.BoundaryObject`
             Source object.
 
+        References
+        ----------
+
+        >>> oModule.AssignSource
         """
         a = self.modeler._get_faceid_on_axis(object_name, axisdir)
 
@@ -244,6 +236,10 @@ class Q3d(QExtractor, object):
         :class:`pyaedt.modules.Boundary.BoundaryObject`
             Source object.
 
+        References
+        ----------
+
+        >>> oModule.AssignSource
         """
         if not sourcename:
             sourcename = generate_unique_name("Source")
@@ -284,6 +280,10 @@ class Q3d(QExtractor, object):
         :class:`pyaedt.modules.Boundary.BoundaryObject`
             Sink object.
 
+        References
+        ----------
+
+        >>> oModule.AssignSink
         """
         a = self.modeler._get_faceid_on_axis(object_name, axisdir)
 
@@ -321,6 +321,10 @@ class Q3d(QExtractor, object):
         :class:`pyaedt.modules.Boundary.BoundaryObject`
             Source object.
 
+        References
+        ----------
+
+        >>> oModule.AssignSink
         """
         if not sinkname:
             sinkname = generate_unique_name("Source")
@@ -364,6 +368,10 @@ class Q3d(QExtractor, object):
         bool
             ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.InsertSweep
         """
         if sweepname is None:
             sweepname = generate_unique_name("Sweep")
@@ -375,9 +383,7 @@ class Q3d(QExtractor, object):
                 setupdata = i
                 for sw in setupdata.sweeps:
                     if sweepname == sw.name:
-                        self._messenger.add_warning_message(
-                            "Sweep {} is already present. Rename and retry.".format(sweepname)
-                        )
+                        self.logger.warning("Sweep %s is already present. Rename and retry.", sweepname)
                         return False
                 sweepdata = setupdata.add_sweep(sweepname, "Discrete")
                 sweepdata.props["RangeStart"] = str(freqstart) + "GHz"
@@ -399,7 +405,7 @@ class Q3d(QExtractor, object):
 
     @aedt_exception_handler
     def create_discrete_sweep(
-            self, setupname, freqstart, freqstop=None, freqstep=None, units="GHz", sweepname=None, savefields=False
+        self, setupname, freqstart, freqstop=None, freqstep=None, units="GHz", sweepname=None, savefields=False
     ):
         """Create a discrete sweep with a single frequency value.
 
@@ -427,6 +433,11 @@ class Q3d(QExtractor, object):
         -------
         SweepQ3D
             Sweep option.
+
+        References
+        ----------
+
+        >>> oModule.InsertSweep
         """
         if sweepname is None:
             sweepname = generate_unique_name("Sweep")
@@ -438,9 +449,7 @@ class Q3d(QExtractor, object):
                 setupdata = i
                 for sw in setupdata.sweeps:
                     if sweepname == sw.name:
-                        self._messenger.add_warning_message(
-                            "Sweep {} already present. Please rename and retry".format(sweepname)
-                        )
+                        self.logger.warning("Sweep %s already present. Please rename and retry", sweepname)
                         return False
                 sweepdata = setupdata.add_sweep(sweepname, "Discrete")
                 sweepdata.props["RangeStart"] = str(freqstart) + "GHz"
@@ -531,16 +540,16 @@ class Q2d(QExtractor, object):
         return self.modeler.dimension
 
     def __init__(
-            self,
-            projectname=None,
-            designname=None,
-            solution_type=None,
-            setup_name=None,
-            specified_version=None,
-            non_graphical=False,
-            new_desktop_session=False,
-            close_on_exit=False,
-            student_version=False,
+        self,
+        projectname=None,
+        designname=None,
+        solution_type=None,
+        setup_name=None,
+        specified_version=None,
+        non_graphical=False,
+        new_desktop_session=False,
+        close_on_exit=False,
+        student_version=False,
     ):
         QExtractor.__init__(
             self,
@@ -577,20 +586,66 @@ class Q2d(QExtractor, object):
         pyaedt.modeler.Object3d.Object3d
             3D object.
 
+        References
+        ----------
+
+        >>> oEditor.CreateRectangle
         """
-        return self.modeler.primitives.create_rectangle(position, dimension_list=dimension_list, name=name,
-                                                        matname=matname)
+        return self.modeler.primitives.create_rectangle(
+            position, dimension_list=dimension_list, name=name, matname=matname
+        )
 
     def assign_single_signal_line(self, target_objects, name="", solve_option="SolveInside", thickness=None, unit="um"):
+        """Assign conductor type to sheets.
+
+        Parameters
+        ----------
+        target_objects : list
+            List of Object3D.
+        name : str
+            Name of the conductor.
+        solve_option : str, optional
+            Method for solving. Options are ``"SolveInside"``, ``"SolveOnBoundary"`` or ``"Automatic"``. The default is
+            ``"SolveInside"``.
+        thickness : float, optional
+            Conductor thickness. The default is ``None``, in which case the conductor thickness is obtained by dividing
+            the conductor's area by its perimeter (A/p). If multiple conductors are selected, the average conductor
+            thickness is used.
+        unit : str, optional
+            Thickness unit. The default is ``"um"``.
+
+        References
+        ----------
+
+        >>> oModule.AssignSingleSignalLine
+        >>> oModule.AssignSingleReferenceGround
+        """
+
+        warnings.warn(
+            "`assign_single_signal_line` is deprecated. Use `assign_single_conductor` instead.", DeprecationWarning
+        )
+        self.assign_single_conductor(target_objects, name, "SignalLine", solve_option, thickness, unit)
+
+    def assign_single_conductor(
+        self,
+        target_objects,
+        name="",
+        conductor_type="SignalLine",
+        solve_option="SolveInside",
+        thickness=None,
+        unit="um",
+    ):
         """
         Assign conductor type to sheets.
 
         Parameters
         ----------
-        name : str
-            Name of the conductor.
         target_objects : list
             List of Object3D.
+        name : str
+            Name of the conductor.
+        conductor_type : str
+            Type of conductor. Options are ``"SignalLine"``, ``"ReferenceGround"``. The default is SignalLine.
         solve_option : str, optional
             Method for solving. Options are ``"SolveInside"``, ``"SolveOnBoundary"`` or ``"Automatic"``. The default is
             ``"SolveInside"``.
@@ -602,8 +657,14 @@ class Q2d(QExtractor, object):
             Thickness unit. The default is ``"um"``.
         Returns
         -------
-        None.
+        bool
+            ``True`` when successful, ``False`` when failed.
 
+        References
+        ----------
+
+        >>> oModule.AssignSingleSignalLine
+        >>> oModule.AssignSingleReferenceGround
         """
         if not name:
             name = generate_unique_name(name)
@@ -624,15 +685,18 @@ class Q2d(QExtractor, object):
                 t_list.append(t_obj.faces[0].area / perimeter)
             thickness = sum(t_list) / len(t_list)
 
-        props = OrderedDict({"Objects": obj_names,
-                             "SolveOption": solve_option,
-                             "Thickness": str(thickness) + unit
-                             }
-                            )
+        props = OrderedDict({"Objects": obj_names, "SolveOption": solve_option, "Thickness": str(thickness) + unit})
 
         arg = ["NAME:" + name]
-        dict2arg(props, arg)
-        self.oboundary.AssignSingleSignalLine(arg)
+        _dict2arg(props, arg)
+        if conductor_type == "SignalLine":
+            self.oboundary.AssignSingleSignalLine(arg)
+        elif conductor_type == "ReferenceGround":
+            self.oboundary.AssignSingleReferenceGround(arg)
+        else:
+            return False
+
+        return True
 
     def assign_huray_finitecond_to_edges(self, edges, radius, ratio, unit="um", name=""):
         """
@@ -649,7 +713,13 @@ class Q2d(QExtractor, object):
 
         Returns
         -------
+        :class:`pyaedt.modules.Boundary.BoundaryObject`
+            Source object.
 
+        References
+        ----------
+
+        >>> oMdoule.AssignFiniteCond
         """
         if not name:
             name = generate_unique_name(name)
@@ -661,11 +731,10 @@ class Q2d(QExtractor, object):
 
         a = self.modeler._convert_list_to_ids(edges, convert_objects_ids_to_name=False)
 
-        props = OrderedDict(
-            {"Edges": a, "UseCoating": False, "Radius": ra, "Ratio": str(ratio)}
-        )
+        props = OrderedDict({"Edges": a, "UseCoating": False, "Radius": ra, "Ratio": str(ratio)})
 
         bound = BoundaryObject(self, name, props, "FiniteCond")
         if bound.create():
             self.boundaries.append(bound)
             return bound
+        return False
