@@ -6,14 +6,13 @@ automatically initialized by an app to the latest installed AEDT version.
 
 """
 from __future__ import absolute_import
-from .generic.general_methods import aedt_exception_handler
+from pyaedt.generic.general_methods import aedt_exception_handler, is_ironpython, _pythonver
 import os
 import sys
 import pkgutil
 import time
 
-from .misc import list_installed_ansysem
-from pyaedt import is_ironpython, _pythonver
+from pyaedt.misc import list_installed_ansysem
 
 if is_ironpython:
     import clr  # IronPython C:\Program Files\AnsysEM\AnsysEM19.4\Win64\common\IronPython\ipy64.exe
@@ -35,12 +34,6 @@ elif os.name == "nt":
         raise Exception("Error. No win32com.client or Python.NET modules found. They need to be installed.")
 
 
-# if _pythonver == 3:
-#     from .MessageManager import AEDTMessageManager
-# else:
-#     from MessageManager import AEDTMessageManager
-
-
 class Siwave:
     """Initializes SIwave based on the inputs provided and manages SIwave release and closing.
 
@@ -117,7 +110,7 @@ class Siwave:
                 # but doesn't return the wrapper of oApp
                 print("Launching Siwave with Module win32com")
 
-                self._main.oSiwave = win32com.client.Dispatch("Siwave.Application.2021.1")
+                self._main.oSiwave = win32com.client.Dispatch("Siwave.Application.2021.2")
 
             self._main.AEDTVersion = version_key
             self.oSiwave = self._main.oSiwave
@@ -128,9 +121,9 @@ class Siwave:
         pass
         # self.logger = logging.getLogger(__name__)
         # if not self.logger.handlers:
-        #     project_dir = self._main.oSiwave.GetProjectDirectory()
+        #     output_dir = self._main.oSiwave.GetProjectDirectory()
         #     logging.basicConfig(
-        #         filename=os.path.join(project_dir, "pyaedt.log"),
+        #         filename=os.path.join(output_dir, "pyaedt.log"),
         #         level=logging.DEBUG,
         #         format='%(asctime)s:%(name)s:%(levelname)-8s:%(message)s',
         #         datefmt='%Y/%m/%d %H.%M.%S')
@@ -139,9 +132,6 @@ class Siwave:
         # info_msg1 = 'Started external COM connection with module {0}'.format(_com)
         # info_msg2 = 'Python version {0}'.format(sys.version)
         # info_msg3 = 'Exe path: {0}'.format(sys.executable)
-        # self._main.oMessenger.add_info_message(info_msg1, 'Global')
-        # self._main.oMessenger.add_info_messge(info_msg2, 'Global')
-        # self._main.oMessenger.add_info_message(info_msg3, 'Global')
 
     @property
     def project_name(self):
